Class: DockerEngineAPI::Models::Container::HostConfig

Inherits:
Internal::Type::BaseModel show all
Defined in:
lib/docker_engine_api/models/container.rb

Overview

See Also:

Defined Under Namespace

Modules: CgroupnsMode, Isolation Classes: BlkioDeviceReadBp, BlkioDeviceReadIOp, BlkioDeviceWriteBp, BlkioDeviceWriteIOp, BlkioWeightDevice, Device, DeviceRequest, LogConfig, Mount, PortBinding, RestartPolicy, Ulimit

Instance Attribute Summary collapse

Class Method Summary collapse

Instance Method Summary collapse

Methods inherited from Internal::Type::BaseModel

==, #==, #[], coerce, #deconstruct_keys, #deep_to_h, dump, fields, hash, #hash, inherited, inspect, #inspect, known_fields, optional, recursively_to_h, required, #to_h, #to_json, #to_s, to_sorbet_type, #to_yaml

Methods included from Internal::Type::Converter

#coerce, coerce, #dump, dump, inspect, #inspect, meta_info, new_coerce_state, type_info

Methods included from Internal::Util::SorbetRuntimeSupport

#const_missing, #define_sorbet_constant!, #sorbet_constant_defined?, #to_sorbet_type, to_sorbet_type

Constructor Details

#initialize(host_ip: nil, host_port: nil) ⇒ Object

PortBinding represents a binding between a host IP address and a host port.

Parameters:

  • host_ip (String) (defaults to: nil)

    Host IP address that the container’s port is mapped to.

  • host_port (String) (defaults to: nil)

    Host port number that the container’s port is mapped to.



# File 'lib/docker_engine_api/models/container.rb', line 1050

Instance Attribute Details

#annotationsHash{Symbol=>String}?

Arbitrary non-identifying metadata attached to container and provided to the runtime when the container is started.

Returns:

  • (Hash{Symbol=>String}, nil)


304
# File 'lib/docker_engine_api/models/container.rb', line 304

optional :annotations, DockerEngineAPI::Internal::Type::HashOf[String], api_name: :Annotations

#auto_removeBoolean?

Automatically remove the container when the container’s process exits. This has no effect if RestartPolicy is set.

Returns:

  • (Boolean, nil)


311
# File 'lib/docker_engine_api/models/container.rb', line 311

optional :auto_remove, DockerEngineAPI::Internal::Type::Boolean, api_name: :AutoRemove

#bindsArray<String>?

A list of volume bindings for this container. Each volume binding is a string in one of these forms:

  • host-src:container-dest[:options] to bind-mount a host path into the container. Both host-src, and container-dest must be an absolute path.

  • volume-name:container-dest[:options] to bind-mount a volume managed by a volume driver into the container. container-dest must be an absolute path.

options is an optional, comma-delimited list of:

  • nocopy disables automatic copying of data from the container path to the volume. The nocopy flag only applies to named volumes.

  • ‘[ro|rw]` mounts a volume read-only or read-write, respectively. If omitted or set to rw, volumes are mounted read-write.

  • ‘[z|Z]` applies SELinux labels to allow or deny multiple containers to read and write to the same volume.

    • z: a shared content label is applied to the content. This label indicates that multiple containers can share the volume content, for both reading and writing.

    • Z: a _private unshared_ label is applied to the content. This label indicates that only the current container can use a private volume. Labeling systems such as SELinux require proper labels to be placed on volume content that is mounted into a container. Without a label, the security system can prevent a container’s processes from using the content. By default, the labels set by the host operating system are not modified.

  • ‘[[r]shared|slave|private]` specifies mount [propagation behavior](www.kernel.org/doc/Documentation/filesystems/sharedsubtree.txt). This only applies to bind-mounted volumes, not internal volumes or named volumes. Mount propagation requires the source mount point (the location where the source directory is mounted in the host operating system) to have the correct propagation properties. For shared volumes, the source mount point must be set to shared. For slave volumes, the mount must be set to either shared or slave.

Returns:

  • (Array<String>, nil)


349
# File 'lib/docker_engine_api/models/container.rb', line 349

optional :binds, DockerEngineAPI::Internal::Type::ArrayOf[String], api_name: :Binds

#blkio_device_read_bpsArray<DockerEngineAPI::Models::Container::HostConfig::BlkioDeviceReadBp>?

Limit read rate (bytes per second) from a device, in the form:

“‘

“device_path”, “Rate”: rate

“‘



359
360
361
362
363
# File 'lib/docker_engine_api/models/container.rb', line 359

optional :blkio_device_read_bps,
-> {
  DockerEngineAPI::Internal::Type::ArrayOf[DockerEngineAPI::Container::HostConfig::BlkioDeviceReadBp]
},
api_name: :BlkioDeviceReadBps

#blkio_device_read_i_opsArray<DockerEngineAPI::Models::Container::HostConfig::BlkioDeviceReadIOp>?

Limit read rate (IO per second) from a device, in the form:

“‘

“device_path”, “Rate”: rate

“‘



373
374
375
376
377
# File 'lib/docker_engine_api/models/container.rb', line 373

optional :blkio_device_read_i_ops,
-> {
  DockerEngineAPI::Internal::Type::ArrayOf[DockerEngineAPI::Container::HostConfig::BlkioDeviceReadIOp]
},
api_name: :BlkioDeviceReadIOps

#blkio_device_write_bpsArray<DockerEngineAPI::Models::Container::HostConfig::BlkioDeviceWriteBp>?

Limit write rate (bytes per second) to a device, in the form:

“‘

“device_path”, “Rate”: rate

“‘



387
388
389
390
391
# File 'lib/docker_engine_api/models/container.rb', line 387

optional :blkio_device_write_bps,
-> {
  DockerEngineAPI::Internal::Type::ArrayOf[DockerEngineAPI::Container::HostConfig::BlkioDeviceWriteBp]
},
api_name: :BlkioDeviceWriteBps

#blkio_device_write_i_opsArray<DockerEngineAPI::Models::Container::HostConfig::BlkioDeviceWriteIOp>?

Limit write rate (IO per second) to a device, in the form:

“‘

“device_path”, “Rate”: rate

“‘



401
402
403
404
405
# File 'lib/docker_engine_api/models/container.rb', line 401

optional :blkio_device_write_i_ops,
-> {
  DockerEngineAPI::Internal::Type::ArrayOf[DockerEngineAPI::Container::HostConfig::BlkioDeviceWriteIOp]
},
api_name: :BlkioDeviceWriteIOps

#blkio_weightInteger?

Block IO weight (relative weight).

Returns:

  • (Integer, nil)


411
# File 'lib/docker_engine_api/models/container.rb', line 411

optional :blkio_weight, Integer, api_name: :BlkioWeight

#blkio_weight_deviceArray<DockerEngineAPI::Models::Container::HostConfig::BlkioWeightDevice>?

Block IO weight (relative device weight) in the form:

“‘

“device_path”, “Weight”: weight

“‘



421
422
423
424
425
# File 'lib/docker_engine_api/models/container.rb', line 421

optional :blkio_weight_device,
-> {
  DockerEngineAPI::Internal::Type::ArrayOf[DockerEngineAPI::Container::HostConfig::BlkioWeightDevice]
},
api_name: :BlkioWeightDevice

#cap_addArray<String>?

A list of kernel capabilities to add to the container. Conflicts with option ‘Capabilities’.

Returns:

  • (Array<String>, nil)


432
# File 'lib/docker_engine_api/models/container.rb', line 432

optional :cap_add, DockerEngineAPI::Internal::Type::ArrayOf[String], api_name: :CapAdd

#cap_dropArray<String>?

A list of kernel capabilities to drop from the container. Conflicts with option ‘Capabilities’.

Returns:

  • (Array<String>, nil)


439
# File 'lib/docker_engine_api/models/container.rb', line 439

optional :cap_drop, DockerEngineAPI::Internal::Type::ArrayOf[String], api_name: :CapDrop

#cgroupString?

Cgroup to use for the container.

Returns:

  • (String, nil)


445
# File 'lib/docker_engine_api/models/container.rb', line 445

optional :cgroup, String, api_name: :Cgroup

#cgroup_parentString?

Path to cgroups under which the container’s cgroup is created. If the path is not absolute, the path is considered to be relative to the cgroups path of the init process. Cgroups are created if they do not already exist.

Returns:

  • (String, nil)


467
# File 'lib/docker_engine_api/models/container.rb', line 467

optional :cgroup_parent, String, api_name: :CgroupParent

#cgroupns_modeSymbol, ...

cgroup namespace mode for the container. Possible values are:

  • ‘“private”`: the container runs in its own private cgroup namespace

  • ‘“host”`: use the host system’s cgroup namespace

If not specified, the daemon default is used, which can either be ‘“private”` or `“host”`, depending on daemon version, kernel support and configuration.



457
458
459
# File 'lib/docker_engine_api/models/container.rb', line 457

optional :cgroupns_mode,
enum: -> { DockerEngineAPI::Container::HostConfig::CgroupnsMode },
api_name: :CgroupnsMode

#console_sizeArray<Integer>?

Initial console size, as an ‘[height, width]` array.

Returns:

  • (Array<Integer>, nil)


473
474
475
476
# File 'lib/docker_engine_api/models/container.rb', line 473

optional :console_size,
DockerEngineAPI::Internal::Type::ArrayOf[Integer],
api_name: :ConsoleSize,
nil?: true

#container_id_fileString?

Path to a file where the container ID is written

Returns:

  • (String, nil)


482
# File 'lib/docker_engine_api/models/container.rb', line 482

optional :container_id_file, String, api_name: :ContainerIDFile

#cpu_countInteger?

The number of usable CPUs (Windows only).

On Windows Server containers, the processor resource controls are mutually exclusive. The order of precedence is CPUCount first, then CPUShares, and CPUPercent last.

Returns:

  • (Integer, nil)


492
# File 'lib/docker_engine_api/models/container.rb', line 492

optional :cpu_count, Integer, api_name: :CpuCount

#cpu_percentInteger?

The usable percentage of the available CPUs (Windows only).

On Windows Server containers, the processor resource controls are mutually exclusive. The order of precedence is CPUCount first, then CPUShares, and CPUPercent last.

Returns:

  • (Integer, nil)


502
# File 'lib/docker_engine_api/models/container.rb', line 502

optional :cpu_percent, Integer, api_name: :CpuPercent

#cpu_periodInteger?

The length of a CPU period in microseconds.

Returns:

  • (Integer, nil)


508
# File 'lib/docker_engine_api/models/container.rb', line 508

optional :cpu_period, Integer, api_name: :CpuPeriod

#cpu_quotaInteger?

Microseconds of CPU time that the container can get in a CPU period.

Returns:

  • (Integer, nil)


514
# File 'lib/docker_engine_api/models/container.rb', line 514

optional :cpu_quota, Integer, api_name: :CpuQuota

#cpu_realtime_periodInteger?

The length of a CPU real-time period in microseconds. Set to 0 to allocate no time allocated to real-time tasks.

Returns:

  • (Integer, nil)


521
# File 'lib/docker_engine_api/models/container.rb', line 521

optional :cpu_realtime_period, Integer, api_name: :CpuRealtimePeriod

#cpu_realtime_runtimeInteger?

The length of a CPU real-time runtime in microseconds. Set to 0 to allocate no time allocated to real-time tasks.

Returns:

  • (Integer, nil)


528
# File 'lib/docker_engine_api/models/container.rb', line 528

optional :cpu_realtime_runtime, Integer, api_name: :CpuRealtimeRuntime

#cpu_sharesInteger?

An integer value representing this container’s relative CPU weight versus other containers.

Returns:

  • (Integer, nil)


548
# File 'lib/docker_engine_api/models/container.rb', line 548

optional :cpu_shares, Integer, api_name: :CpuShares

#cpuset_cpusString?

CPUs in which to allow execution (e.g., 0-3, ‘0,1`).

Returns:

  • (String, nil)


534
# File 'lib/docker_engine_api/models/container.rb', line 534

optional :cpuset_cpus, String, api_name: :CpusetCpus

#cpuset_memsString?

Memory nodes (MEMs) in which to allow execution (0-3, 0,1). Only effective on NUMA systems.

Returns:

  • (String, nil)


541
# File 'lib/docker_engine_api/models/container.rb', line 541

optional :cpuset_mems, String, api_name: :CpusetMems

#device_cgroup_rulesArray<String>?

a list of cgroup rules to apply to the container

Returns:

  • (Array<String>, nil)


554
555
556
# File 'lib/docker_engine_api/models/container.rb', line 554

optional :device_cgroup_rules,
DockerEngineAPI::Internal::Type::ArrayOf[String],
api_name: :DeviceCgroupRules

#device_requestsArray<DockerEngineAPI::Models::Container::HostConfig::DeviceRequest>?

A list of requests for devices to be sent to device drivers.



562
563
564
565
566
# File 'lib/docker_engine_api/models/container.rb', line 562

optional :device_requests,
-> {
  DockerEngineAPI::Internal::Type::ArrayOf[DockerEngineAPI::Container::HostConfig::DeviceRequest]
},
api_name: :DeviceRequests

#devicesArray<DockerEngineAPI::Models::Container::HostConfig::Device>?

A list of devices to add to the container.



572
573
574
575
576
# File 'lib/docker_engine_api/models/container.rb', line 572

optional :devices,
-> {
  DockerEngineAPI::Internal::Type::ArrayOf[DockerEngineAPI::Container::HostConfig::Device]
},
api_name: :Devices

#dnsArray<String>?

A list of DNS servers for the container to use.

Returns:

  • (Array<String>, nil)


582
# File 'lib/docker_engine_api/models/container.rb', line 582

optional :dns, DockerEngineAPI::Internal::Type::ArrayOf[String], api_name: :Dns

#dns_optionsArray<String>?

A list of DNS options.

Returns:

  • (Array<String>, nil)


588
# File 'lib/docker_engine_api/models/container.rb', line 588

optional :dns_options, DockerEngineAPI::Internal::Type::ArrayOf[String], api_name: :DnsOptions

#dns_searchArray<String>?

A list of DNS search domains.

Returns:

  • (Array<String>, nil)


594
# File 'lib/docker_engine_api/models/container.rb', line 594

optional :dns_search, DockerEngineAPI::Internal::Type::ArrayOf[String], api_name: :DnsSearch

#extra_hostsArray<String>?

A list of hostnames/IP mappings to add to the container’s /etc/hosts file. Specified in the form ‘[“hostname:IP”]`.

Returns:

  • (Array<String>, nil)


601
# File 'lib/docker_engine_api/models/container.rb', line 601

optional :extra_hosts, DockerEngineAPI::Internal::Type::ArrayOf[String], api_name: :ExtraHosts

#group_addArray<String>?

A list of additional groups that the container process will run as.

Returns:

  • (Array<String>, nil)


607
# File 'lib/docker_engine_api/models/container.rb', line 607

optional :group_add, DockerEngineAPI::Internal::Type::ArrayOf[String], api_name: :GroupAdd

#initBoolean?

Run an init inside the container that forwards signals and reaps processes. This field is omitted if empty, and the default (as configured on the daemon) is used.

Returns:

  • (Boolean, nil)


615
# File 'lib/docker_engine_api/models/container.rb', line 615

optional :init, DockerEngineAPI::Internal::Type::Boolean, api_name: :Init, nil?: true

#io_maximum_bandwidthInteger?

Maximum IO in bytes per second for the container system drive (Windows only).

Returns:

  • (Integer, nil)


621
# File 'lib/docker_engine_api/models/container.rb', line 621

optional :io_maximum_bandwidth, Integer, api_name: :IOMaximumBandwidth

#io_maximum_i_opsInteger?

Maximum IOps for the container system drive (Windows only)

Returns:

  • (Integer, nil)


627
# File 'lib/docker_engine_api/models/container.rb', line 627

optional :io_maximum_i_ops, Integer, api_name: :IOMaximumIOps

#ipc_modeString?

IPC sharing mode for the container. Possible values are:

  • ‘“none”`: own private IPC namespace, with /dev/shm not mounted

  • ‘“private”`: own private IPC namespace

  • ‘“shareable”`: own private IPC namespace, with a possibility to share it with other containers

  • ‘“container:<name|id>”`: join another (shareable) container’s IPC namespace

  • ‘“host”`: use the host system’s IPC namespace

If not specified, daemon default is used, which can either be ‘“private”` or `“shareable”`, depending on daemon version and configuration.

Returns:

  • (String, nil)


643
# File 'lib/docker_engine_api/models/container.rb', line 643

optional :ipc_mode, String, api_name: :IpcMode

#isolationSymbol, ...

Isolation technology of the container. (Windows only)



649
650
651
652
653
# File 'lib/docker_engine_api/models/container.rb', line 649

optional :isolation,
enum: -> {
  DockerEngineAPI::Container::HostConfig::Isolation
},
api_name: :Isolation

A list of links for the container in the form container_name:alias.

Returns:

  • (Array<String>, nil)


659
# File 'lib/docker_engine_api/models/container.rb', line 659

optional :links, DockerEngineAPI::Internal::Type::ArrayOf[String], api_name: :Links

#log_configDockerEngineAPI::Models::Container::HostConfig::LogConfig?

The logging configuration for this container



665
# File 'lib/docker_engine_api/models/container.rb', line 665

optional :log_config, -> { DockerEngineAPI::Container::HostConfig::LogConfig }, api_name: :LogConfig

#masked_pathsArray<String>?

The list of paths to be masked inside the container (this overrides the default set of paths).

Returns:

  • (Array<String>, nil)


672
# File 'lib/docker_engine_api/models/container.rb', line 672

optional :masked_paths, DockerEngineAPI::Internal::Type::ArrayOf[String], api_name: :MaskedPaths

#memoryInteger?

Memory limit in bytes.

Returns:

  • (Integer, nil)


678
# File 'lib/docker_engine_api/models/container.rb', line 678

optional :memory, Integer, api_name: :Memory

#memory_reservationInteger?

Memory soft limit in bytes.

Returns:

  • (Integer, nil)


684
# File 'lib/docker_engine_api/models/container.rb', line 684

optional :memory_reservation, Integer, api_name: :MemoryReservation

#memory_swapInteger?

Total memory limit (memory + swap). Set as -1 to enable unlimited swap.

Returns:

  • (Integer, nil)


690
# File 'lib/docker_engine_api/models/container.rb', line 690

optional :memory_swap, Integer, api_name: :MemorySwap

#memory_swappinessInteger?

Tune a container’s memory swappiness behavior. Accepts an integer between 0 and 100.

Returns:

  • (Integer, nil)


697
# File 'lib/docker_engine_api/models/container.rb', line 697

optional :memory_swappiness, Integer, api_name: :MemorySwappiness

#mountsArray<DockerEngineAPI::Models::Container::HostConfig::Mount>?

Specification for mounts to be added to the container.



703
704
705
706
707
# File 'lib/docker_engine_api/models/container.rb', line 703

optional :mounts,
-> {
  DockerEngineAPI::Internal::Type::ArrayOf[DockerEngineAPI::Container::HostConfig::Mount]
},
api_name: :Mounts

#nano_cpusInteger?

CPU quota in units of 10<sup>-9</sup> CPUs.

Returns:

  • (Integer, nil)


713
# File 'lib/docker_engine_api/models/container.rb', line 713

optional :nano_cpus, Integer, api_name: :NanoCpus

#network_modeString?

Network mode to use for this container. Supported standard values are: bridge, host, none, and ‘container:<name|id>`. Any other value is taken as a custom network’s name to which this container should connect to.

Returns:

  • (String, nil)


721
# File 'lib/docker_engine_api/models/container.rb', line 721

optional :network_mode, String, api_name: :NetworkMode

#oom_kill_disableBoolean?

Disable OOM Killer for the container.

Returns:

  • (Boolean, nil)


727
# File 'lib/docker_engine_api/models/container.rb', line 727

optional :oom_kill_disable, DockerEngineAPI::Internal::Type::Boolean, api_name: :OomKillDisable

#oom_score_adjInteger?

An integer value containing the score given to the container in order to tune OOM killer preferences.

Returns:

  • (Integer, nil)


734
# File 'lib/docker_engine_api/models/container.rb', line 734

optional :oom_score_adj, Integer, api_name: :OomScoreAdj

#pid_modeString?

Set the PID (Process) Namespace mode for the container. It can be either:

  • ‘“container:<name|id>”`: joins another container’s PID namespace

  • ‘“host”`: use the host’s PID namespace inside the container

Returns:

  • (String, nil)


743
# File 'lib/docker_engine_api/models/container.rb', line 743

optional :pid_mode, String, api_name: :PidMode

#pids_limitInteger?

Tune a container’s PIDs limit. Set 0 or -1 for unlimited, or null to not change.

Returns:

  • (Integer, nil)


750
# File 'lib/docker_engine_api/models/container.rb', line 750

optional :pids_limit, Integer, api_name: :PidsLimit, nil?: true

#port_bindingsHash{Symbol=>Array<DockerEngineAPI::Models::Container::HostConfig::PortBinding>}?

PortMap describes the mapping of container ports to host ports, using the container’s port-number and protocol as key in the format ‘<port>/<protocol>`, for example, 80/udp.

If a container’s port is mapped for multiple protocols, separate entries are added to the mapping table.



761
762
763
764
765
# File 'lib/docker_engine_api/models/container.rb', line 761

optional :port_bindings,
-> {
  DockerEngineAPI::Internal::Type::HashOf[DockerEngineAPI::Internal::Type::ArrayOf[DockerEngineAPI::Container::HostConfig::PortBinding]]
},
api_name: :PortBindings

#privilegedBoolean?

Gives the container full access to the host.

Returns:

  • (Boolean, nil)


771
# File 'lib/docker_engine_api/models/container.rb', line 771

optional :privileged, DockerEngineAPI::Internal::Type::Boolean, api_name: :Privileged

#publish_all_portsBoolean?

Allocates an ephemeral host port for all of a container’s exposed ports.

Ports are de-allocated when the container stops and allocated when the container starts. The allocated port might be changed when restarting the container.

The port is selected from the ephemeral port range that depends on the kernel. For example, on Linux the range is defined by /proc/sys/net/ipv4/ip_local_port_range.

Returns:

  • (Boolean, nil)


784
# File 'lib/docker_engine_api/models/container.rb', line 784

optional :publish_all_ports, DockerEngineAPI::Internal::Type::Boolean, api_name: :PublishAllPorts

#readonly_pathsArray<String>?

The list of paths to be set as read-only inside the container (this overrides the default set of paths).

Returns:

  • (Array<String>, nil)


791
# File 'lib/docker_engine_api/models/container.rb', line 791

optional :readonly_paths, DockerEngineAPI::Internal::Type::ArrayOf[String], api_name: :ReadonlyPaths

#readonly_rootfsBoolean?

Mount the container’s root filesystem as read only.

Returns:

  • (Boolean, nil)


797
# File 'lib/docker_engine_api/models/container.rb', line 797

optional :readonly_rootfs, DockerEngineAPI::Internal::Type::Boolean, api_name: :ReadonlyRootfs

#restart_policyDockerEngineAPI::Models::Container::HostConfig::RestartPolicy?

The behavior to apply when the container exits. The default is not to restart.

An ever increasing delay (double the previous delay, starting at 100ms) is added before each restart to prevent flooding the server.



806
807
808
# File 'lib/docker_engine_api/models/container.rb', line 806

optional :restart_policy,
-> { DockerEngineAPI::Container::HostConfig::RestartPolicy },
api_name: :RestartPolicy

#runtimeString?

Runtime to use with this container.

Returns:

  • (String, nil)


814
# File 'lib/docker_engine_api/models/container.rb', line 814

optional :runtime, String, api_name: :Runtime, nil?: true

#security_optArray<String>?

A list of string values to customize labels for MLS systems, such as SELinux.

Returns:

  • (Array<String>, nil)


820
# File 'lib/docker_engine_api/models/container.rb', line 820

optional :security_opt, DockerEngineAPI::Internal::Type::ArrayOf[String], api_name: :SecurityOpt

#shm_sizeInteger?

Size of /dev/shm in bytes. If omitted, the system uses 64MB.

Returns:

  • (Integer, nil)


826
# File 'lib/docker_engine_api/models/container.rb', line 826

optional :shm_size, Integer, api_name: :ShmSize

#storage_optHash{Symbol=>String}?

Storage driver options for this container, in the form ‘“120G”`.

Returns:

  • (Hash{Symbol=>String}, nil)


832
# File 'lib/docker_engine_api/models/container.rb', line 832

optional :storage_opt, DockerEngineAPI::Internal::Type::HashOf[String], api_name: :StorageOpt

#sysctlsHash{Symbol=>String}?

A list of kernel parameters (sysctls) to set in the container.

This field is omitted if not set.

Returns:

  • (Hash{Symbol=>String}, nil)


840
# File 'lib/docker_engine_api/models/container.rb', line 840

optional :sysctls, DockerEngineAPI::Internal::Type::HashOf[String], api_name: :Sysctls, nil?: true

#tmpfsHash{Symbol=>String}?

A map of container directories which should be replaced by tmpfs mounts, and their corresponding mount options. For example:

“‘ { “/run”: “rw,noexec,nosuid,size=65536k” } “`

Returns:

  • (Hash{Symbol=>String}, nil)


851
# File 'lib/docker_engine_api/models/container.rb', line 851

optional :tmpfs, DockerEngineAPI::Internal::Type::HashOf[String], api_name: :Tmpfs

#ulimitsArray<DockerEngineAPI::Models::Container::HostConfig::Ulimit>?

A list of resource limits to set in the container. For example:

“‘ “nofile”, “Soft”: 1024, “Hard”: 2048 “`



861
862
863
864
865
# File 'lib/docker_engine_api/models/container.rb', line 861

optional :ulimits,
-> {
  DockerEngineAPI::Internal::Type::ArrayOf[DockerEngineAPI::Container::HostConfig::Ulimit]
},
api_name: :Ulimits

#userns_modeString?

Sets the usernamespace mode for the container when usernamespace remapping option is enabled.

Returns:

  • (String, nil)


872
# File 'lib/docker_engine_api/models/container.rb', line 872

optional :userns_mode, String, api_name: :UsernsMode

#uts_modeString?

UTS namespace to use for the container.

Returns:

  • (String, nil)


878
# File 'lib/docker_engine_api/models/container.rb', line 878

optional :uts_mode, String, api_name: :UTSMode

#volume_driverString?

Driver that this container uses to mount volumes.

Returns:

  • (String, nil)


884
# File 'lib/docker_engine_api/models/container.rb', line 884

optional :volume_driver, String, api_name: :VolumeDriver

#volumes_fromArray<String>?

A list of volumes to inherit from another container, specified in the form ‘<container name>`.

Returns:

  • (Array<String>, nil)


891
# File 'lib/docker_engine_api/models/container.rb', line 891

optional :volumes_from, DockerEngineAPI::Internal::Type::ArrayOf[String], api_name: :VolumesFrom

Class Method Details

.valuesArray<Symbol>

Returns:

  • (Array<Symbol>)


# File 'lib/docker_engine_api/models/container.rb', line 1144