Module: DockerEngineAPI::Models::Container::HostConfig::CgroupnsMode

Extended by:
Internal::Type::Enum
Defined in:
lib/docker_engine_api/models/container.rb

Overview

cgroup namespace mode for the container. Possible values are:

  • "private": the container runs in its own private cgroup namespace
  • "host": use the host system's cgroup namespace

If not specified, the daemon default is used, which can either be "private" or "host", depending on daemon version, kernel support and configuration.

See Also:

Constant Summary collapse

PRIVATE =
:private
HOST =
:host

Method Summary

Methods included from Internal::Type::Enum

==, ===, coerce, dump, hash, inspect, to_sorbet_type, values

Methods included from Internal::Util::SorbetRuntimeSupport

#const_missing, #define_sorbet_constant!, #sorbet_constant_defined?, #to_sorbet_type, to_sorbet_type

Methods included from Internal::Type::Converter

#coerce, coerce, #dump, dump, inspect, #inspect, meta_info, new_coerce_state, type_info