Class: DockerEngineAPI::Models::Container::HostConfig::LogConfig
- Inherits:
-
Internal::Type::BaseModel
- Object
- Internal::Type::BaseModel
- DockerEngineAPI::Models::Container::HostConfig::LogConfig
- Defined in:
- lib/docker_engine_api/models/container.rb
Overview
Defined Under Namespace
Modules: Type
Instance Attribute Summary collapse
-
#config ⇒ Hash{Symbol=>String}?
Driver-specific configuration options for the logging driver.
-
#type ⇒ Symbol, ...
Name of the logging driver used for the container or “none” if logging is disabled.
Instance Method Summary collapse
-
#initialize(config: nil, type: nil) ⇒ Object
constructor
Some parameter documentations has been truncated, see LogConfig for more details.
Methods inherited from Internal::Type::BaseModel
==, #==, #[], coerce, #deconstruct_keys, #deep_to_h, dump, fields, hash, #hash, inherited, inspect, #inspect, known_fields, optional, recursively_to_h, required, #to_h, #to_json, #to_s, to_sorbet_type, #to_yaml
Methods included from Internal::Type::Converter
#coerce, coerce, #dump, dump, inspect, #inspect, meta_info, new_coerce_state, type_info
Methods included from Internal::Util::SorbetRuntimeSupport
#const_missing, #define_sorbet_constant!, #sorbet_constant_defined?, #to_sorbet_type, to_sorbet_type
Constructor Details
#initialize(config: nil, type: nil) ⇒ Object
Some parameter documentations has been truncated, see DockerEngineAPI::Models::Container::HostConfig::LogConfig for more details.
The logging configuration for this container
|
|
# File 'lib/docker_engine_api/models/container.rb', line 1265
|
Instance Attribute Details
#config ⇒ Hash{Symbol=>String}?
Driver-specific configuration options for the logging driver.
1252 |
# File 'lib/docker_engine_api/models/container.rb', line 1252 optional :config, DockerEngineAPI::Internal::Type::HashOf[String], api_name: :Config |
#type ⇒ Symbol, ...
Name of the logging driver used for the container or “none” if logging is disabled.
1259 1260 1261 1262 1263 |
# File 'lib/docker_engine_api/models/container.rb', line 1259 optional :type, enum: -> { DockerEngineAPI::Container::HostConfig::LogConfig::Type }, api_name: :Type |