Class: DockerEngineAPI::Models::Container::HostConfig::Mount
- Inherits:
-
Internal::Type::BaseModel
- Object
- Internal::Type::BaseModel
- DockerEngineAPI::Models::Container::HostConfig::Mount
- Defined in:
- lib/docker_engine_api/models/container.rb
Defined Under Namespace
Modules: Type Classes: BindOptions, ImageOptions, TmpfsOptions, VolumeOptions
Instance Attribute Summary collapse
-
#bind_options ⇒ DockerEngineAPI::Models::Container::HostConfig::Mount::BindOptions?
Optional configuration for the
bindtype. -
#consistency ⇒ String?
The consistency requirement for the mount:
default,consistent,cached, ordelegated. -
#image_options ⇒ DockerEngineAPI::Models::Container::HostConfig::Mount::ImageOptions?
Optional configuration for the
imagetype. -
#read_only ⇒ Boolean?
Whether the mount should be read-only.
-
#source ⇒ String?
Mount source (e.g. a volume name, a host path).
-
#target ⇒ String?
Container path.
-
#tmpfs_options ⇒ DockerEngineAPI::Models::Container::HostConfig::Mount::TmpfsOptions?
Optional configuration for the
tmpfstype. -
#type ⇒ Symbol, ...
The mount type.
-
#volume_options ⇒ DockerEngineAPI::Models::Container::HostConfig::Mount::VolumeOptions?
Optional configuration for the
volumetype.
Class Method Summary collapse
Instance Method Summary collapse
-
#initialize(mode: nil, options: nil, size_bytes: nil) ⇒ Object
constructor
Some parameter documentations has been truncated, see TmpfsOptions for more details.
Methods inherited from Internal::Type::BaseModel
==, #==, #[], coerce, #deconstruct_keys, #deep_to_h, dump, fields, hash, #hash, inherited, inspect, #inspect, known_fields, optional, recursively_to_h, required, #to_h, #to_json, #to_s, to_sorbet_type, #to_yaml
Methods included from Internal::Type::Converter
#coerce, coerce, #dump, dump, inspect, #inspect, meta_info, new_coerce_state, type_info
Methods included from Internal::Util::SorbetRuntimeSupport
#const_missing, #define_sorbet_constant!, #sorbet_constant_defined?, #to_sorbet_type, to_sorbet_type
Constructor Details
#initialize(mode: nil, options: nil, size_bytes: nil) ⇒ Object
Some parameter documentations has been truncated, see TmpfsOptions for more details.
Optional configuration for the tmpfs type.
|
|
# File 'lib/docker_engine_api/models/container.rb', line 1374
|
Instance Attribute Details
#bind_options ⇒ DockerEngineAPI::Models::Container::HostConfig::Mount::BindOptions?
Optional configuration for the bind type.
1303 1304 1305 |
# File 'lib/docker_engine_api/models/container.rb', line 1303 optional :bind_options, -> { DockerEngineAPI::Container::HostConfig::Mount::BindOptions }, api_name: :BindOptions |
#consistency ⇒ String?
The consistency requirement for the mount: default, consistent, cached, or
delegated.
1312 |
# File 'lib/docker_engine_api/models/container.rb', line 1312 optional :consistency, String, api_name: :Consistency |
#image_options ⇒ DockerEngineAPI::Models::Container::HostConfig::Mount::ImageOptions?
Optional configuration for the image type.
1318 1319 1320 |
# File 'lib/docker_engine_api/models/container.rb', line 1318 optional :image_options, -> { DockerEngineAPI::Container::HostConfig::Mount::ImageOptions }, api_name: :ImageOptions |
#read_only ⇒ Boolean?
Whether the mount should be read-only.
1326 |
# File 'lib/docker_engine_api/models/container.rb', line 1326 optional :read_only, DockerEngineAPI::Internal::Type::Boolean, api_name: :ReadOnly |
#source ⇒ String?
Mount source (e.g. a volume name, a host path). The source cannot be specified
when using Type=tmpfs. For Type=bind, the source path must either exist, or
the CreateMountpoint must be set to true to create the source path on the
host if missing.
For Type=npipe, the pipe must exist prior to creating the container.
1337 |
# File 'lib/docker_engine_api/models/container.rb', line 1337 optional :source, String, api_name: :Source |
#target ⇒ String?
Container path.
1343 |
# File 'lib/docker_engine_api/models/container.rb', line 1343 optional :target, String, api_name: :Target |
#tmpfs_options ⇒ DockerEngineAPI::Models::Container::HostConfig::Mount::TmpfsOptions?
Optional configuration for the tmpfs type.
1349 1350 1351 |
# File 'lib/docker_engine_api/models/container.rb', line 1349 optional :tmpfs_options, -> { DockerEngineAPI::Container::HostConfig::Mount::TmpfsOptions }, api_name: :TmpfsOptions |
#type ⇒ Symbol, ...
The mount type. Available types:
binda mount of a file or directory from the host into the container.clustera Swarm cluster volume.imagean OCI image.npipea named pipe from the host into the container.tmpfsatmpfs.volumea docker volume with the givenName.
1364 |
# File 'lib/docker_engine_api/models/container.rb', line 1364 optional :type, enum: -> { DockerEngineAPI::Container::HostConfig::Mount::Type }, api_name: :Type |
#volume_options ⇒ DockerEngineAPI::Models::Container::HostConfig::Mount::VolumeOptions?
Optional configuration for the volume type.
1370 1371 1372 |
# File 'lib/docker_engine_api/models/container.rb', line 1370 optional :volume_options, -> { DockerEngineAPI::Container::HostConfig::Mount::VolumeOptions }, api_name: :VolumeOptions |
Class Method Details
.values ⇒ Array<Symbol>
|
|
# File 'lib/docker_engine_api/models/container.rb', line 1469
|