Class: DockerEngineAPI::Models::Container::HostConfig::Mount::BindOptions

Inherits:
Internal::Type::BaseModel show all
Defined in:
lib/docker_engine_api/models/container.rb

Overview

See Also:

Defined Under Namespace

Modules: Propagation

Instance Attribute Summary collapse

Instance Method Summary collapse

Methods inherited from Internal::Type::BaseModel

==, #==, #[], coerce, #deconstruct_keys, #deep_to_h, dump, fields, hash, #hash, inherited, inspect, #inspect, known_fields, optional, recursively_to_h, required, #to_h, #to_json, #to_s, to_sorbet_type, #to_yaml

Methods included from Internal::Type::Converter

#coerce, coerce, #dump, dump, inspect, #inspect, meta_info, new_coerce_state, type_info

Methods included from Internal::Util::SorbetRuntimeSupport

#const_missing, #define_sorbet_constant!, #sorbet_constant_defined?, #to_sorbet_type, to_sorbet_type

Constructor Details

#initialize(create_mountpoint: nil, non_recursive: nil, propagation: nil, read_only_force_recursive: nil, read_only_non_recursive: nil) ⇒ Object

Some parameter documentations has been truncated, see DockerEngineAPI::Models::Container::HostConfig::Mount::BindOptions for more details.

Optional configuration for the bind type.

Parameters:

  • create_mountpoint (Boolean) (defaults to: nil)

    Create mount point on host if missing

  • non_recursive (Boolean) (defaults to: nil)

    Disable recursive bind mount.

  • propagation (Symbol, DockerEngineAPI::Models::Container::HostConfig::Mount::BindOptions::Propagation) (defaults to: nil)

    A propagation mode with the value [r]private, [r]shared, or [r]slave.

  • read_only_force_recursive (Boolean) (defaults to: nil)

    Raise an error if the mount cannot be made recursively read-only.

  • read_only_non_recursive (Boolean) (defaults to: nil)

    Make the mount non-recursively read-only, but still leave the mount recursive



# File 'lib/docker_engine_api/models/container.rb', line 1439

Instance Attribute Details

#create_mountpointBoolean?

Create mount point on host if missing

Returns:

  • (Boolean, nil)


1402
# File 'lib/docker_engine_api/models/container.rb', line 1402

optional :create_mountpoint, DockerEngineAPI::Internal::Type::Boolean, api_name: :CreateMountpoint

#non_recursiveBoolean?

Disable recursive bind mount.

Returns:

  • (Boolean, nil)


1408
# File 'lib/docker_engine_api/models/container.rb', line 1408

optional :non_recursive, DockerEngineAPI::Internal::Type::Boolean, api_name: :NonRecursive

#propagationSymbol, ...

A propagation mode with the value [r]private, [r]shared, or [r]slave.



1414
1415
1416
# File 'lib/docker_engine_api/models/container.rb', line 1414

optional :propagation,
enum: -> { DockerEngineAPI::Container::HostConfig::Mount::BindOptions::Propagation },
api_name: :Propagation

#read_only_force_recursiveBoolean?

Raise an error if the mount cannot be made recursively read-only.

Returns:

  • (Boolean, nil)


1422
1423
1424
# File 'lib/docker_engine_api/models/container.rb', line 1422

optional :read_only_force_recursive,
DockerEngineAPI::Internal::Type::Boolean,
api_name: :ReadOnlyForceRecursive

#read_only_non_recursiveBoolean?

Make the mount non-recursively read-only, but still leave the mount recursive (unless NonRecursive is set to true in conjunction).

Added in v1.44, before that version all read-only mounts were non-recursive by default. To match the previous behaviour this will default to true for clients on versions prior to v1.44.

Returns:

  • (Boolean, nil)


1435
1436
1437
# File 'lib/docker_engine_api/models/container.rb', line 1435

optional :read_only_non_recursive,
DockerEngineAPI::Internal::Type::Boolean,
api_name: :ReadOnlyNonRecursive