Class: DockerEngineAPI::Models::Container::HostConfig::Mount::TmpfsOptions

Inherits:
Internal::Type::BaseModel show all
Defined in:
lib/docker_engine_api/models/container.rb

Overview

See Also:

Instance Attribute Summary collapse

Method Summary

Methods inherited from Internal::Type::BaseModel

#==, ==, #[], coerce, #deconstruct_keys, #deep_to_h, dump, fields, hash, #hash, inherited, #initialize, inspect, #inspect, known_fields, optional, recursively_to_h, required, #to_h, #to_json, #to_s, to_sorbet_type, #to_yaml

Methods included from Internal::Type::Converter

#coerce, coerce, #dump, dump, inspect, #inspect, meta_info, new_coerce_state, type_info

Methods included from Internal::Util::SorbetRuntimeSupport

#const_missing, #define_sorbet_constant!, #sorbet_constant_defined?, #to_sorbet_type, to_sorbet_type

Constructor Details

This class inherits a constructor from DockerEngineAPI::Internal::Type::BaseModel

Instance Attribute Details

#modeInteger?

The permission mode for the tmpfs mount in an integer. The value must not be in octal format (e.g. 755) but rather the decimal representation of the octal value (e.g. 493).

Returns:

  • (Integer, nil)


1496
# File 'lib/docker_engine_api/models/container.rb', line 1496

optional :mode, Integer, api_name: :Mode

#optionsArray<Array<String>>?

The options to be passed to the tmpfs mount. An array of arrays. Flag options should be provided as 1-length arrays. Other types should be provided as as 2-length arrays, where the first item is the key and the second the value.

Returns:

  • (Array<Array<String>>, nil)


1504
1505
1506
# File 'lib/docker_engine_api/models/container.rb', line 1504

optional :options,
DockerEngineAPI::Internal::Type::ArrayOf[DockerEngineAPI::Internal::Type::ArrayOf[String]],
api_name: :Options

#size_bytesInteger?

The size for the tmpfs mount in bytes.

Returns:

  • (Integer, nil)


1512
# File 'lib/docker_engine_api/models/container.rb', line 1512

optional :size_bytes, Integer, api_name: :SizeBytes