Class: DockerEngineAPI::Models::Container::State::Health::Log

Inherits:
Internal::Type::BaseModel show all
Defined in:
lib/docker_engine_api/models/container.rb

Instance Attribute Summary collapse

Instance Method Summary collapse

Methods inherited from Internal::Type::BaseModel

==, #==, #[], coerce, #deconstruct_keys, #deep_to_h, dump, fields, hash, #hash, inherited, inspect, #inspect, known_fields, optional, recursively_to_h, required, #to_h, #to_json, #to_s, to_sorbet_type, #to_yaml

Methods included from Internal::Type::Converter

#coerce, coerce, #dump, dump, inspect, #inspect, meta_info, new_coerce_state, type_info

Methods included from Internal::Util::SorbetRuntimeSupport

#const_missing, #define_sorbet_constant!, #sorbet_constant_defined?, #to_sorbet_type, to_sorbet_type

Constructor Details

#initialize(failing_streak: nil, log: nil, status: nil) ⇒ Object

Some parameter documentations has been truncated, see DockerEngineAPI::Models::Container::State::Health for more details.

Health stores information about the container’s healthcheck results.



2374
2375
2376
2377
2378
2379
2380
2381
2382
2383
2384
2385
2386
2387
2388
2389
2390
2391
2392
2393
2394
2395
2396
2397
2398
2399
2400
2401
2402
2403
2404
2405
2406
2407
2408
2409
2410
2411
2412
2413
2414
2415
2416
2417
2418
2419
# File 'lib/docker_engine_api/models/container.rb', line 2374

class Log < DockerEngineAPI::Internal::Type::BaseModel
  # @!attribute end_
  #   Date and time at which this check ended in
  #   [RFC 3339](https://www.ietf.org/rfc/rfc3339.txt) format with nano-seconds.
  #
  #   @return [String, nil]
  optional :end_, String, api_name: :End

  # @!attribute exit_code
  #   ExitCode meanings:
  #
  #   - `0` healthy
  #   - `1` unhealthy
  #   - `2` reserved (considered unhealthy)
  #   - other values: error running probe
  #
  #   @return [Integer, nil]
  optional :exit_code, Integer, api_name: :ExitCode

  # @!attribute output
  #   Output from last check
  #
  #   @return [String, nil]
  optional :output, String, api_name: :Output

  # @!attribute start
  #   Date and time at which this check started in
  #   [RFC 3339](https://www.ietf.org/rfc/rfc3339.txt) format with nano-seconds.
  #
  #   @return [Time, nil]
  optional :start, Time, api_name: :Start

  # @!method initialize(end_: nil, exit_code: nil, output: nil, start: nil)
  #   Some parameter documentations has been truncated, see
  #   {DockerEngineAPI::Models::Container::State::Health::Log} for more details.
  #
  #   HealthcheckResult stores information about a single run of a healthcheck probe
  #
  #   @param end_ [String] Date and time at which this check ended in
  #
  #   @param exit_code [Integer] ExitCode meanings:
  #
  #   @param output [String] Output from last check
  #
  #   @param start [Time] Date and time at which this check started in
end

Instance Attribute Details

#end_String?

Date and time at which this check ended in [RFC 3339](www.ietf.org/rfc/rfc3339.txt) format with nano-seconds.



2380
# File 'lib/docker_engine_api/models/container.rb', line 2380

optional :end_, String, api_name: :End

#exit_codeInteger?

ExitCode meanings:

  • 0 healthy

  • 1 unhealthy

  • 2 reserved (considered unhealthy)

  • other values: error running probe



2391
# File 'lib/docker_engine_api/models/container.rb', line 2391

optional :exit_code, Integer, api_name: :ExitCode

#outputString?

Output from last check



2397
# File 'lib/docker_engine_api/models/container.rb', line 2397

optional :output, String, api_name: :Output

#startTime?

Date and time at which this check started in [RFC 3339](www.ietf.org/rfc/rfc3339.txt) format with nano-seconds.



2404
# File 'lib/docker_engine_api/models/container.rb', line 2404

optional :start, Time, api_name: :Start