Class: DockerEngineAPI::Models::ContainerCreateParams::Config::HostConfig::DeviceRequest
- Inherits:
-
Internal::Type::BaseModel
- Object
- Internal::Type::BaseModel
- DockerEngineAPI::Models::ContainerCreateParams::Config::HostConfig::DeviceRequest
- Defined in:
- lib/docker_engine_api/models/container_create_params.rb
Instance Attribute Summary collapse
-
#capabilities ⇒ Array<Array<String>>?
A list of capabilities; an OR list of AND lists of capabilities.
- #count ⇒ Integer?
- #device_ids ⇒ Array<String>?
-
#driver ⇒ String?
The name of the device driver to use for this request.
-
#options ⇒ Hash{Symbol=>String}?
Driver-specific options, specified as a key/value pairs.
Method Summary
Methods inherited from Internal::Type::BaseModel
#==, ==, #[], coerce, #deconstruct_keys, #deep_to_h, dump, fields, hash, #hash, inherited, #initialize, inspect, #inspect, known_fields, optional, recursively_to_h, required, #to_h, #to_json, #to_s, to_sorbet_type, #to_yaml
Methods included from Internal::Type::Converter
#coerce, coerce, #dump, dump, inspect, #inspect, meta_info, new_coerce_state, type_info
Methods included from Internal::Util::SorbetRuntimeSupport
#const_missing, #define_sorbet_constant!, #sorbet_constant_defined?, #to_sorbet_type, to_sorbet_type
Constructor Details
This class inherits a constructor from DockerEngineAPI::Internal::Type::BaseModel
Instance Attribute Details
#capabilities ⇒ Array<Array<String>>?
A list of capabilities; an OR list of AND lists of capabilities.
Note that if a driver is specified the capabilities have no effect on selecting a driver as the driver name is used directly.
Note that if no driver is specified the capabilities are used to select a driver with the required capabilities.
948 949 950 |
# File 'lib/docker_engine_api/models/container_create_params.rb', line 948 optional :capabilities, DockerEngineAPI::Internal::Type::ArrayOf[DockerEngineAPI::Internal::Type::ArrayOf[String]], api_name: :Capabilities |
#count ⇒ Integer?
955 |
# File 'lib/docker_engine_api/models/container_create_params.rb', line 955 optional :count, Integer, api_name: :Count |
#device_ids ⇒ Array<String>?
960 |
# File 'lib/docker_engine_api/models/container_create_params.rb', line 960 optional :device_ids, DockerEngineAPI::Internal::Type::ArrayOf[String], api_name: :DeviceIDs |
#driver ⇒ String?
The name of the device driver to use for this request.
Note that if this is specified the capabilities are ignored when selecting a device driver.
969 |
# File 'lib/docker_engine_api/models/container_create_params.rb', line 969 optional :driver, String, api_name: :Driver |
#options ⇒ Hash{Symbol=>String}?
Driver-specific options, specified as a key/value pairs. These options are passed directly to the driver.
976 |
# File 'lib/docker_engine_api/models/container_create_params.rb', line 976 optional :options, DockerEngineAPI::Internal::Type::HashOf[String], api_name: :Options |