Class: DockerEngineAPI::Models::ContainerCreateParams::Config::HostConfig::Mount::TmpfsOptions
- Inherits:
-
Internal::Type::BaseModel
- Object
- Internal::Type::BaseModel
- DockerEngineAPI::Models::ContainerCreateParams::Config::HostConfig::Mount::TmpfsOptions
- Defined in:
- lib/docker_engine_api/models/container_create_params.rb
Overview
Instance Attribute Summary collapse
-
#mode ⇒ Integer?
The permission mode for the tmpfs mount in an integer.
-
#options ⇒ Array<Array<String>>?
The options to be passed to the tmpfs mount.
-
#size_bytes ⇒ Integer?
The size for the tmpfs mount in bytes.
Method Summary
Methods inherited from Internal::Type::BaseModel
#==, ==, #[], coerce, #deconstruct_keys, #deep_to_h, dump, fields, hash, #hash, inherited, #initialize, inspect, #inspect, known_fields, optional, recursively_to_h, required, #to_h, #to_json, #to_s, to_sorbet_type, #to_yaml
Methods included from Internal::Type::Converter
#coerce, coerce, #dump, dump, inspect, #inspect, meta_info, new_coerce_state, type_info
Methods included from Internal::Util::SorbetRuntimeSupport
#const_missing, #define_sorbet_constant!, #sorbet_constant_defined?, #to_sorbet_type, to_sorbet_type
Constructor Details
This class inherits a constructor from DockerEngineAPI::Internal::Type::BaseModel
Instance Attribute Details
#mode ⇒ Integer?
The permission mode for the tmpfs mount in an integer. The value must not be in octal format (e.g. 755) but rather the decimal representation of the octal value (e.g. 493).
1291 |
# File 'lib/docker_engine_api/models/container_create_params.rb', line 1291 optional :mode, Integer, api_name: :Mode |
#options ⇒ Array<Array<String>>?
The options to be passed to the tmpfs mount. An array of arrays. Flag options should be provided as 1-length arrays. Other types should be provided as as 2-length arrays, where the first item is the key and the second the value.
1299 1300 1301 |
# File 'lib/docker_engine_api/models/container_create_params.rb', line 1299 optional :options, DockerEngineAPI::Internal::Type::ArrayOf[DockerEngineAPI::Internal::Type::ArrayOf[String]], api_name: :Options |
#size_bytes ⇒ Integer?
The size for the tmpfs mount in bytes.
1307 |
# File 'lib/docker_engine_api/models/container_create_params.rb', line 1307 optional :size_bytes, Integer, api_name: :SizeBytes |