Class: DockerEngineAPI::Models::ContainerCreateParams::Config::NetworkingConfig::EndpointsConfig

Inherits:
Internal::Type::BaseModel show all
Defined in:
lib/docker_engine_api/models/container_create_params.rb

Defined Under Namespace

Classes: IpamConfig

Instance Attribute Summary collapse

Instance Method Summary collapse

Methods inherited from Internal::Type::BaseModel

==, #==, #[], coerce, #deconstruct_keys, #deep_to_h, dump, fields, hash, #hash, inherited, inspect, #inspect, known_fields, optional, recursively_to_h, required, #to_h, #to_json, #to_s, to_sorbet_type, #to_yaml

Methods included from Internal::Type::Converter

#coerce, coerce, #dump, dump, inspect, #inspect, meta_info, new_coerce_state, type_info

Methods included from Internal::Util::SorbetRuntimeSupport

#const_missing, #define_sorbet_constant!, #sorbet_constant_defined?, #to_sorbet_type, to_sorbet_type

Constructor Details

#initialize(aliases: nil, dns_names: nil, driver_opts: nil, endpoint_id: nil, gateway: nil, global_i_pv6_address: nil, global_i_pv6_prefix_len: nil, gw_priority: nil, ip_address: nil, ipam_config: nil, ip_prefix_len: nil, i_pv6_gateway: nil, links: nil, mac_address: nil, network_id: nil) ⇒ Object

Some parameter documentations has been truncated, see DockerEngineAPI::Models::ContainerCreateParams::Config::NetworkingConfig::EndpointsConfig for more details.

Configuration for a network endpoint.

Parameters:

  • aliases (Array<String>) (defaults to: nil)
  • dns_names (Array<String>) (defaults to: nil)

    List of all DNS names an endpoint has on a specific network. This

  • driver_opts (Hash{Symbol=>String}, nil) (defaults to: nil)

    DriverOpts is a mapping of driver options and values. These options

  • endpoint_id (String) (defaults to: nil)

    Unique ID for the service endpoint in a Sandbox.

  • gateway (String) (defaults to: nil)

    Gateway address for this network.

  • global_i_pv6_address (String) (defaults to: nil)

    Global IPv6 address.

  • global_i_pv6_prefix_len (Integer) (defaults to: nil)

    Mask length of the global IPv6 address.

  • gw_priority (Integer) (defaults to: nil)

    This property determines which endpoint will provide the default

  • ip_address (String) (defaults to: nil)

    IPv4 address.

  • ipam_config (DockerEngineAPI::Models::ContainerCreateParams::Config::NetworkingConfig::EndpointsConfig::IpamConfig, nil) (defaults to: nil)

    EndpointIPAMConfig represents an endpoint’s IPAM configuration.

  • ip_prefix_len (Integer) (defaults to: nil)

    Mask length of the IPv4 address.

  • i_pv6_gateway (String) (defaults to: nil)

    IPv6 gateway address.

  • links (Array<String>) (defaults to: nil)
  • mac_address (String) (defaults to: nil)

    MAC address for the endpoint on this network. The network driver might ignore th

  • network_id (String) (defaults to: nil)

    Unique ID of the network.



1544
1545
1546
1547
1548
1549
1550
1551
1552
1553
1554
1555
1556
1557
1558
1559
1560
1561
1562
1563
1564
1565
1566
1567
1568
1569
1570
1571
1572
1573
1574
1575
1576
1577
1578
1579
1580
1581
1582
1583
1584
1585
1586
1587
1588
1589
1590
1591
1592
1593
1594
1595
1596
1597
1598
1599
1600
1601
1602
1603
1604
1605
1606
1607
1608
1609
1610
1611
1612
1613
1614
1615
1616
1617
1618
1619
1620
1621
1622
1623
1624
1625
1626
1627
1628
1629
1630
1631
1632
1633
1634
1635
1636
1637
1638
1639
1640
1641
1642
1643
1644
1645
1646
1647
1648
1649
1650
1651
1652
1653
1654
1655
1656
1657
1658
1659
1660
1661
1662
1663
1664
1665
1666
1667
1668
1669
1670
1671
1672
1673
1674
1675
1676
1677
1678
1679
1680
1681
1682
1683
1684
1685
1686
1687
1688
1689
1690
1691
1692
1693
1694
1695
1696
1697
1698
1699
1700
1701
1702
1703
1704
1705
1706
1707
1708
1709
1710
1711
1712
1713
1714
1715
# File 'lib/docker_engine_api/models/container_create_params.rb', line 1544

class EndpointsConfig < DockerEngineAPI::Internal::Type::BaseModel
  # @!attribute aliases
  #
  #   @return [Array<String>, nil]
  optional :aliases, DockerEngineAPI::Internal::Type::ArrayOf[String], api_name: :Aliases

  # @!attribute dns_names
  #   List of all DNS names an endpoint has on a specific network. This list is based
  #   on the container name, network aliases, container short ID, and hostname.
  #
  #   These DNS names are non-fully qualified but can contain several dots. You can
  #   get fully qualified DNS names by appending `.<network-name>`. For instance, if
  #   container name is `my.ctr` and the network is named `testnet`, `DNSNames` will
  #   contain `my.ctr` and the FQDN will be `my.ctr.testnet`.
  #
  #   @return [Array<String>, nil]
  optional :dns_names, DockerEngineAPI::Internal::Type::ArrayOf[String], api_name: :DNSNames

  # @!attribute driver_opts
  #   DriverOpts is a mapping of driver options and values. These options are passed
  #   directly to the driver and are driver specific.
  #
  #   @return [Hash{Symbol=>String}, nil]
  optional :driver_opts,
           DockerEngineAPI::Internal::Type::HashOf[String],
           api_name: :DriverOpts,
           nil?: true

  # @!attribute endpoint_id
  #   Unique ID for the service endpoint in a Sandbox.
  #
  #   @return [String, nil]
  optional :endpoint_id, String, api_name: :EndpointID

  # @!attribute gateway
  #   Gateway address for this network.
  #
  #   @return [String, nil]
  optional :gateway, String, api_name: :Gateway

  # @!attribute global_i_pv6_address
  #   Global IPv6 address.
  #
  #   @return [String, nil]
  optional :global_i_pv6_address, String, api_name: :GlobalIPv6Address

  # @!attribute global_i_pv6_prefix_len
  #   Mask length of the global IPv6 address.
  #
  #   @return [Integer, nil]
  optional :global_i_pv6_prefix_len, Integer, api_name: :GlobalIPv6PrefixLen

  # @!attribute gw_priority
  #   This property determines which endpoint will provide the default gateway for a
  #   container. The endpoint with the highest priority will be used. If multiple
  #   endpoints have the same priority, endpoints are lexicographically sorted based
  #   on their network name, and the one that sorts first is picked.
  #
  #   @return [Integer, nil]
  optional :gw_priority, Integer, api_name: :GwPriority

  # @!attribute ip_address
  #   IPv4 address.
  #
  #   @return [String, nil]
  optional :ip_address, String, api_name: :IPAddress

  # @!attribute ipam_config
  #   EndpointIPAMConfig represents an endpoint's IPAM configuration.
  #
  #   @return [DockerEngineAPI::Models::ContainerCreateParams::Config::NetworkingConfig::EndpointsConfig::IpamConfig, nil]
  optional :ipam_config,
           -> {
             DockerEngineAPI::ContainerCreateParams::Config::NetworkingConfig::EndpointsConfig::IpamConfig
           },
           api_name: :IPAMConfig,
           nil?: true

  # @!attribute ip_prefix_len
  #   Mask length of the IPv4 address.
  #
  #   @return [Integer, nil]
  optional :ip_prefix_len, Integer, api_name: :IPPrefixLen

  # @!attribute i_pv6_gateway
  #   IPv6 gateway address.
  #
  #   @return [String, nil]
  optional :i_pv6_gateway, String, api_name: :IPv6Gateway

  # @!attribute links
  #
  #   @return [Array<String>, nil]
  optional :links, DockerEngineAPI::Internal::Type::ArrayOf[String], api_name: :Links

  # @!attribute mac_address
  #   MAC address for the endpoint on this network. The network driver might ignore
  #   this parameter.
  #
  #   @return [String, nil]
  optional :mac_address, String, api_name: :MacAddress

  # @!attribute network_id
  #   Unique ID of the network.
  #
  #   @return [String, nil]
  optional :network_id, String, api_name: :NetworkID

  # @!method initialize(aliases: nil, dns_names: nil, driver_opts: nil, endpoint_id: nil, gateway: nil, global_i_pv6_address: nil, global_i_pv6_prefix_len: nil, gw_priority: nil, ip_address: nil, ipam_config: nil, ip_prefix_len: nil, i_pv6_gateway: nil, links: nil, mac_address: nil, network_id: nil)
  #   Some parameter documentations has been truncated, see
  #   {DockerEngineAPI::Models::ContainerCreateParams::Config::NetworkingConfig::EndpointsConfig}
  #   for more details.
  #
  #   Configuration for a network endpoint.
  #
  #   @param aliases [Array<String>]
  #
  #   @param dns_names [Array<String>] List of all DNS names an endpoint has on a specific network. This
  #
  #   @param driver_opts [Hash{Symbol=>String}, nil] DriverOpts is a mapping of driver options and values. These options
  #
  #   @param endpoint_id [String] Unique ID for the service endpoint in a Sandbox.
  #
  #   @param gateway [String] Gateway address for this network.
  #
  #   @param global_i_pv6_address [String] Global IPv6 address.
  #
  #   @param global_i_pv6_prefix_len [Integer] Mask length of the global IPv6 address.
  #
  #   @param gw_priority [Integer] This property determines which endpoint will provide the default
  #
  #   @param ip_address [String] IPv4 address.
  #
  #   @param ipam_config [DockerEngineAPI::Models::ContainerCreateParams::Config::NetworkingConfig::EndpointsConfig::IpamConfig, nil] EndpointIPAMConfig represents an endpoint's IPAM configuration.
  #
  #   @param ip_prefix_len [Integer] Mask length of the IPv4 address.
  #
  #   @param i_pv6_gateway [String] IPv6 gateway address.
  #
  #   @param links [Array<String>]
  #
  #   @param mac_address [String] MAC address for the endpoint on this network. The network driver might ignore th
  #
  #   @param network_id [String] Unique ID of the network.

  # @see DockerEngineAPI::Models::ContainerCreateParams::Config::NetworkingConfig::EndpointsConfig#ipam_config
  class IpamConfig < DockerEngineAPI::Internal::Type::BaseModel
    # @!attribute i_pv4_address
    #
    #   @return [String, nil]
    optional :i_pv4_address, String, api_name: :IPv4Address

    # @!attribute i_pv6_address
    #
    #   @return [String, nil]
    optional :i_pv6_address, String, api_name: :IPv6Address

    # @!attribute link_local_ips
    #
    #   @return [Array<String>, nil]
    optional :link_local_ips,
             DockerEngineAPI::Internal::Type::ArrayOf[String],
             api_name: :LinkLocalIPs

    # @!method initialize(i_pv4_address: nil, i_pv6_address: nil, link_local_ips: nil)
    #   EndpointIPAMConfig represents an endpoint's IPAM configuration.
    #
    #   @param i_pv4_address [String]
    #   @param i_pv6_address [String]
    #   @param link_local_ips [Array<String>]
  end
end

Instance Attribute Details

#aliasesArray<String>?

Returns:

  • (Array<String>, nil)


1548
# File 'lib/docker_engine_api/models/container_create_params.rb', line 1548

optional :aliases, DockerEngineAPI::Internal::Type::ArrayOf[String], api_name: :Aliases

#dns_namesArray<String>?

List of all DNS names an endpoint has on a specific network. This list is based on the container name, network aliases, container short ID, and hostname.

These DNS names are non-fully qualified but can contain several dots. You can get fully qualified DNS names by appending ‘.<network-name>`. For instance, if container name is my.ctr and the network is named testnet, DNSNames will contain my.ctr and the FQDN will be my.ctr.testnet.

Returns:

  • (Array<String>, nil)


1560
# File 'lib/docker_engine_api/models/container_create_params.rb', line 1560

optional :dns_names, DockerEngineAPI::Internal::Type::ArrayOf[String], api_name: :DNSNames

#driver_optsHash{Symbol=>String}?

DriverOpts is a mapping of driver options and values. These options are passed directly to the driver and are driver specific.

Returns:

  • (Hash{Symbol=>String}, nil)


1567
1568
1569
1570
# File 'lib/docker_engine_api/models/container_create_params.rb', line 1567

optional :driver_opts,
DockerEngineAPI::Internal::Type::HashOf[String],
api_name: :DriverOpts,
nil?: true

#endpoint_idString?

Unique ID for the service endpoint in a Sandbox.

Returns:

  • (String, nil)


1576
# File 'lib/docker_engine_api/models/container_create_params.rb', line 1576

optional :endpoint_id, String, api_name: :EndpointID

#gatewayString?

Gateway address for this network.

Returns:

  • (String, nil)


1582
# File 'lib/docker_engine_api/models/container_create_params.rb', line 1582

optional :gateway, String, api_name: :Gateway

#global_i_pv6_addressString?

Global IPv6 address.

Returns:

  • (String, nil)


1588
# File 'lib/docker_engine_api/models/container_create_params.rb', line 1588

optional :global_i_pv6_address, String, api_name: :GlobalIPv6Address

#global_i_pv6_prefix_lenInteger?

Mask length of the global IPv6 address.

Returns:

  • (Integer, nil)


1594
# File 'lib/docker_engine_api/models/container_create_params.rb', line 1594

optional :global_i_pv6_prefix_len, Integer, api_name: :GlobalIPv6PrefixLen

#gw_priorityInteger?

This property determines which endpoint will provide the default gateway for a container. The endpoint with the highest priority will be used. If multiple endpoints have the same priority, endpoints are lexicographically sorted based on their network name, and the one that sorts first is picked.

Returns:

  • (Integer, nil)


1603
# File 'lib/docker_engine_api/models/container_create_params.rb', line 1603

optional :gw_priority, Integer, api_name: :GwPriority

#i_pv6_gatewayString?

IPv6 gateway address.

Returns:

  • (String, nil)


1632
# File 'lib/docker_engine_api/models/container_create_params.rb', line 1632

optional :i_pv6_gateway, String, api_name: :IPv6Gateway

#ip_addressString?

IPv4 address.

Returns:

  • (String, nil)


1609
# File 'lib/docker_engine_api/models/container_create_params.rb', line 1609

optional :ip_address, String, api_name: :IPAddress

#ip_prefix_lenInteger?

Mask length of the IPv4 address.

Returns:

  • (Integer, nil)


1626
# File 'lib/docker_engine_api/models/container_create_params.rb', line 1626

optional :ip_prefix_len, Integer, api_name: :IPPrefixLen

#ipam_configDockerEngineAPI::Models::ContainerCreateParams::Config::NetworkingConfig::EndpointsConfig::IpamConfig?

EndpointIPAMConfig represents an endpoint’s IPAM configuration.



1615
1616
1617
1618
1619
1620
# File 'lib/docker_engine_api/models/container_create_params.rb', line 1615

optional :ipam_config,
-> {
  DockerEngineAPI::ContainerCreateParams::Config::NetworkingConfig::EndpointsConfig::IpamConfig
},
api_name: :IPAMConfig,
nil?: true

Returns:

  • (Array<String>, nil)


1637
# File 'lib/docker_engine_api/models/container_create_params.rb', line 1637

optional :links, DockerEngineAPI::Internal::Type::ArrayOf[String], api_name: :Links

#mac_addressString?

MAC address for the endpoint on this network. The network driver might ignore this parameter.

Returns:

  • (String, nil)


1644
# File 'lib/docker_engine_api/models/container_create_params.rb', line 1644

optional :mac_address, String, api_name: :MacAddress

#network_idString?

Unique ID of the network.

Returns:

  • (String, nil)


1650
# File 'lib/docker_engine_api/models/container_create_params.rb', line 1650

optional :network_id, String, api_name: :NetworkID