Class: DockerEngineAPI::Models::ContainerExecParams

Inherits:
Internal::Type::BaseModel show all
Extended by:
Internal::Type::RequestParameters::Converter
Includes:
Internal::Type::RequestParameters
Defined in:
lib/docker_engine_api/models/container_exec_params.rb

Overview

Instance Attribute Summary collapse

Attributes included from Internal::Type::RequestParameters

#request_options

Instance Method Summary collapse

Methods included from Internal::Type::RequestParameters::Converter

dump_request

Methods included from Internal::Type::RequestParameters

included

Methods inherited from Internal::Type::BaseModel

==, #==, #[], coerce, #deconstruct_keys, #deep_to_h, dump, fields, hash, #hash, inherited, inspect, #inspect, known_fields, optional, recursively_to_h, required, #to_h, #to_json, #to_s, to_sorbet_type, #to_yaml

Methods included from Internal::Type::Converter

#coerce, coerce, #dump, dump, inspect, #inspect, meta_info, new_coerce_state, type_info

Methods included from Internal::Util::SorbetRuntimeSupport

#const_missing, #define_sorbet_constant!, #sorbet_constant_defined?, #to_sorbet_type, to_sorbet_type

Constructor Details

#initialize(attach_stderr: nil, attach_stdin: nil, attach_stdout: nil, cmd: nil, console_size: nil, detach_keys: nil, env: nil, privileged: nil, tty: nil, user: nil, working_dir: nil, request_options: {}) ⇒ Object

Some parameter documentations has been truncated, see DockerEngineAPI::Models::ContainerExecParams for more details.

Parameters:

  • attach_stderr (Boolean) (defaults to: nil)

    Attach to stderr of the exec command.

  • attach_stdin (Boolean) (defaults to: nil)

    Attach to stdin of the exec command.

  • attach_stdout (Boolean) (defaults to: nil)

    Attach to stdout of the exec command.

  • cmd (Array<String>) (defaults to: nil)

    Command to run, as a string or array of strings.

  • console_size (Array<Integer>, nil) (defaults to: nil)

    Initial console size, as an ‘[height, width]` array.

  • detach_keys (String) (defaults to: nil)

    Override the key sequence for detaching a container. Format is

  • env (Array<String>) (defaults to: nil)

    A list of environment variables in the form ‘[“VAR=value”, …]`.

  • privileged (Boolean) (defaults to: nil)

    Runs the exec process with extended privileges.

  • tty (Boolean) (defaults to: nil)

    Allocate a pseudo-TTY.

  • user (String) (defaults to: nil)

    The user, and optionally, group to run the exec process inside

  • working_dir (String) (defaults to: nil)

    The working directory for the exec process inside the container.

  • request_options (DockerEngineAPI::RequestOptions, Hash{Symbol=>Object}) (defaults to: {})


# File 'lib/docker_engine_api/models/container_exec_params.rb', line 82


Instance Attribute Details

#attach_stderrBoolean?

Attach to stderr of the exec command.

Returns:

  • (Boolean, nil)


14
# File 'lib/docker_engine_api/models/container_exec_params.rb', line 14

optional :attach_stderr, DockerEngineAPI::Internal::Type::Boolean, api_name: :AttachStderr

#attach_stdinBoolean?

Attach to stdin of the exec command.

Returns:

  • (Boolean, nil)


20
# File 'lib/docker_engine_api/models/container_exec_params.rb', line 20

optional :attach_stdin, DockerEngineAPI::Internal::Type::Boolean, api_name: :AttachStdin

#attach_stdoutBoolean?

Attach to stdout of the exec command.

Returns:

  • (Boolean, nil)


26
# File 'lib/docker_engine_api/models/container_exec_params.rb', line 26

optional :attach_stdout, DockerEngineAPI::Internal::Type::Boolean, api_name: :AttachStdout

#cmdArray<String>?

Command to run, as a string or array of strings.

Returns:

  • (Array<String>, nil)


32
# File 'lib/docker_engine_api/models/container_exec_params.rb', line 32

optional :cmd, DockerEngineAPI::Internal::Type::ArrayOf[String], api_name: :Cmd

#console_sizeArray<Integer>?

Initial console size, as an ‘[height, width]` array.

Returns:

  • (Array<Integer>, nil)


38
39
40
41
# File 'lib/docker_engine_api/models/container_exec_params.rb', line 38

optional :console_size,
DockerEngineAPI::Internal::Type::ArrayOf[Integer],
api_name: :ConsoleSize,
nil?: true

#detach_keysString?

Override the key sequence for detaching a container. Format is a single character [a-Z] or ‘ctrl-<value>` where `<value>` is one of: a-z, `@`, `^`, [, `,` or _.

Returns:

  • (String, nil)


49
# File 'lib/docker_engine_api/models/container_exec_params.rb', line 49

optional :detach_keys, String, api_name: :DetachKeys

#envArray<String>?

A list of environment variables in the form ‘[“VAR=value”, …]`.

Returns:

  • (Array<String>, nil)


55
# File 'lib/docker_engine_api/models/container_exec_params.rb', line 55

optional :env, DockerEngineAPI::Internal::Type::ArrayOf[String], api_name: :Env

#privilegedBoolean?

Runs the exec process with extended privileges.

Returns:

  • (Boolean, nil)


61
# File 'lib/docker_engine_api/models/container_exec_params.rb', line 61

optional :privileged, DockerEngineAPI::Internal::Type::Boolean, api_name: :Privileged

#ttyBoolean?

Allocate a pseudo-TTY.

Returns:

  • (Boolean, nil)


67
# File 'lib/docker_engine_api/models/container_exec_params.rb', line 67

optional :tty, DockerEngineAPI::Internal::Type::Boolean, api_name: :Tty

#userString?

The user, and optionally, group to run the exec process inside the container. Format is one of: user, user:group, uid, or uid:gid.

Returns:

  • (String, nil)


74
# File 'lib/docker_engine_api/models/container_exec_params.rb', line 74

optional :user, String, api_name: :User

#working_dirString?

The working directory for the exec process inside the container.

Returns:

  • (String, nil)


80
# File 'lib/docker_engine_api/models/container_exec_params.rb', line 80

optional :working_dir, String, api_name: :WorkingDir