Class: DockerEngineAPI::Models::ContainerPruneParams
- Inherits:
-
Internal::Type::BaseModel
- Object
- Internal::Type::BaseModel
- DockerEngineAPI::Models::ContainerPruneParams
- Extended by:
- Internal::Type::RequestParameters::Converter
- Includes:
- Internal::Type::RequestParameters
- Defined in:
- lib/docker_engine_api/models/container_prune_params.rb
Overview
Instance Attribute Summary collapse
-
#filters ⇒ String?
Filters to process on the prune list, encoded as JSON (a
map[string][]string).
Attributes included from Internal::Type::RequestParameters
Instance Method Summary collapse
-
#initialize(filters: nil, request_options: {}) ⇒ Object
constructor
Some parameter documentations has been truncated, see ContainerPruneParams for more details.
Methods included from Internal::Type::RequestParameters::Converter
Methods included from Internal::Type::RequestParameters
Methods inherited from Internal::Type::BaseModel
==, #==, #[], coerce, #deconstruct_keys, #deep_to_h, dump, fields, hash, #hash, inherited, inspect, #inspect, known_fields, optional, recursively_to_h, required, #to_h, #to_json, #to_s, to_sorbet_type, #to_yaml
Methods included from Internal::Type::Converter
#coerce, coerce, #dump, dump, inspect, #inspect, meta_info, new_coerce_state, type_info
Methods included from Internal::Util::SorbetRuntimeSupport
#const_missing, #define_sorbet_constant!, #sorbet_constant_defined?, #to_sorbet_type, to_sorbet_type
Constructor Details
#initialize(filters: nil, request_options: {}) ⇒ Object
Some parameter documentations has been truncated, see DockerEngineAPI::Models::ContainerPruneParams for more details.
|
|
# File 'lib/docker_engine_api/models/container_prune_params.rb', line 26
|
Instance Attribute Details
#filters ⇒ String?
Filters to process on the prune list, encoded as JSON (a map[string][]string).
Available filters:
-
‘until=<timestamp>` Prune containers created before this timestamp. The `<timestamp>` can be Unix timestamps, date formatted timestamps, or Go duration strings (e.g.
10m,1h30m) computed relative to the daemon machine’s time. -
label(‘label=<key>`, `label=<key>=<value>`, `label!=<key>`, or `label!=<key>=<value>`) Prune containers with (or without, in case `label!=…` is used) the specified labels.
24 |
# File 'lib/docker_engine_api/models/container_prune_params.rb', line 24 optional :filters, String |