Module: DockerEngineAPI::Models::CreateRequest::ClusterVolumeSpec::AccessMode::Scope
- Extended by:
- Internal::Type::Enum
- Defined in:
- lib/docker_engine_api/models/create_request.rb
Overview
The set of nodes this volume can be used on at one time.
-
singleThe volume may only be scheduled to one node at a time. -
multithe volume may be scheduled to any supported number of nodes at a time.
Constant Summary collapse
- SINGLE =
:single- MULTI =
:multi
Method Summary
Methods included from Internal::Type::Enum
==, ===, coerce, dump, hash, inspect, to_sorbet_type, values
Methods included from Internal::Util::SorbetRuntimeSupport
#const_missing, #define_sorbet_constant!, #sorbet_constant_defined?, #to_sorbet_type, to_sorbet_type
Methods included from Internal::Type::Converter
#coerce, coerce, #dump, dump, inspect, #inspect, meta_info, new_coerce_state, type_info