Module: DockerEngineAPI::Models::CreateRequest::ClusterVolumeSpec::AccessMode::Sharing

Extended by:
Internal::Type::Enum
Defined in:
lib/docker_engine_api/models/create_request.rb

Overview

The number and way that different tasks can use this volume at one time.

  • none The volume may only be used by one task at a time.

  • readonly The volume may be used by any number of tasks, but they all must mount the volume as readonly

  • onewriter The volume may be used by any number of tasks, but only one may mount it as read/write.

  • all The volume may have any number of readers and writers.

See Also:

Constant Summary collapse

NONE =
:none
READONLY =
:readonly
ONEWRITER =
:onewriter
ALL =
:all

Class Method Summary collapse

Methods included from Internal::Type::Enum

==, ===, coerce, dump, hash, inspect, to_sorbet_type, values

Methods included from Internal::Util::SorbetRuntimeSupport

#const_missing, #define_sorbet_constant!, #sorbet_constant_defined?, #to_sorbet_type, to_sorbet_type

Methods included from Internal::Type::Converter

#coerce, coerce, #dump, dump, inspect, #inspect, meta_info, new_coerce_state, type_info

Class Method Details

.valuesArray<Symbol>

Returns:

  • (Array<Symbol>)


# File 'lib/docker_engine_api/models/create_request.rb', line 341