Class: DockerEngineAPI::Models::Image::Manifest::ImageData

Inherits:
Internal::Type::BaseModel show all
Defined in:
lib/docker_engine_api/models/image.rb

Overview

See Also:

Defined Under Namespace

Classes: Platform, Size

Instance Attribute Summary collapse

Instance Method Summary collapse

Methods inherited from Internal::Type::BaseModel

==, #==, #[], coerce, #deconstruct_keys, #deep_to_h, dump, fields, hash, #hash, inherited, inspect, #inspect, known_fields, optional, recursively_to_h, required, #to_h, #to_json, #to_s, to_sorbet_type, #to_yaml

Methods included from Internal::Type::Converter

#coerce, coerce, #dump, dump, inspect, #inspect, meta_info, new_coerce_state, type_info

Methods included from Internal::Util::SorbetRuntimeSupport

#const_missing, #define_sorbet_constant!, #sorbet_constant_defined?, #to_sorbet_type, to_sorbet_type

Constructor Details

#initialize(architecture: nil, os: nil, os_features: nil, os_version: nil, variant: nil) ⇒ Object

Some parameter documentations has been truncated, see Platform for more details.

Describes the platform which the image in the manifest runs on, as defined in the OCI Image Index Specification.

Parameters:

  • architecture (String) (defaults to: nil) —

    The CPU architecture, for example amd64 or ppc64.

  • os (String) (defaults to: nil) —

    The operating system, for example linux or windows.

  • os_features (Array<String>) (defaults to: nil) —

    Optional field specifying an array of strings, each listing a required

  • os_version (String) (defaults to: nil) —

    Optional field specifying the operating system version, for example on

  • variant (String) (defaults to: nil) —

    Optional field specifying a variant of the CPU, for example v7 to



# File 'lib/docker_engine_api/models/image.rb', line 1264

Instance Attribute Details

#containers ⇒ Array<String>

The IDs of the containers that are using this image.

Returns:

  • (Array<String>)


1246
# File 'lib/docker_engine_api/models/image.rb', line 1246

required :containers, DockerEngineAPI::Internal::Type::ArrayOf[String], api_name: :Containers

#platform ⇒ DockerEngineAPI::Models::Image::Manifest::ImageData::Platform?

Describes the platform which the image in the manifest runs on, as defined in the OCI Image Index Specification.



1254
1255
1256
1257
# File 'lib/docker_engine_api/models/image.rb', line 1254

required :platform,
-> { DockerEngineAPI::Image::Manifest::ImageData::Platform },
api_name: :Platform,
nil?: true

#size ⇒ DockerEngineAPI::Models::Image::Manifest::ImageData::Size



1262
# File 'lib/docker_engine_api/models/image.rb', line 1262

required :size, -> { DockerEngineAPI::Image::Manifest::ImageData::Size }, api_name: :Size