Class: DockerEngineAPI::Models::Image::Manifest::ImageData::Size
- Inherits:
-
Internal::Type::BaseModel
- Object
- Internal::Type::BaseModel
- DockerEngineAPI::Models::Image::Manifest::ImageData::Size
- Defined in:
- lib/docker_engine_api/models/image.rb
Overview
Instance Attribute Summary collapse
-
#unpacked ⇒ Integer
Unpacked is the size (in bytes) of the locally unpacked (uncompressed) image content that’s directly usable by the containers running this image.
Method Summary
Methods inherited from Internal::Type::BaseModel
#==, ==, #[], coerce, #deconstruct_keys, #deep_to_h, dump, fields, hash, #hash, inherited, #initialize, inspect, #inspect, known_fields, optional, recursively_to_h, required, #to_h, #to_json, #to_s, to_sorbet_type, #to_yaml
Methods included from Internal::Type::Converter
#coerce, coerce, #dump, dump, inspect, #inspect, meta_info, new_coerce_state, type_info
Methods included from Internal::Util::SorbetRuntimeSupport
#const_missing, #define_sorbet_constant!, #sorbet_constant_defined?, #to_sorbet_type, to_sorbet_type
Constructor Details
This class inherits a constructor from DockerEngineAPI::Internal::Type::BaseModel
Instance Attribute Details
#unpacked ⇒ Integer
Unpacked is the size (in bytes) of the locally unpacked (uncompressed) image content that’s directly usable by the containers running this image. It’s independent of the distributable content - e.g. the image might still have an unpacked data that’s still used by some container even when the distributable/compressed content is already gone.
1342 |
# File 'lib/docker_engine_api/models/image.rb', line 1342 required :unpacked, Integer, api_name: :Unpacked |