Class: DockerEngineAPI::Models::Image::Metadata
- Inherits:
-
Internal::Type::BaseModel
- Object
- Internal::Type::BaseModel
- DockerEngineAPI::Models::Image::Metadata
- Defined in:
- lib/docker_engine_api/models/image.rb
Overview
Instance Attribute Summary collapse
-
#last_tag_time ⇒ String?
Date and time at which the image was last tagged in [RFC 3339](www.ietf.org/rfc/rfc3339.txt) format with nano-seconds.
Method Summary
Methods inherited from Internal::Type::BaseModel
#==, ==, #[], coerce, #deconstruct_keys, #deep_to_h, dump, fields, hash, #hash, inherited, #initialize, inspect, #inspect, known_fields, optional, recursively_to_h, required, #to_h, #to_json, #to_s, to_sorbet_type, #to_yaml
Methods included from Internal::Type::Converter
#coerce, coerce, #dump, dump, inspect, #inspect, meta_info, new_coerce_state, type_info
Methods included from Internal::Util::SorbetRuntimeSupport
#const_missing, #define_sorbet_constant!, #sorbet_constant_defined?, #to_sorbet_type, to_sorbet_type
Constructor Details
This class inherits a constructor from DockerEngineAPI::Internal::Type::BaseModel
Instance Attribute Details
#last_tag_time ⇒ String?
Date and time at which the image was last tagged in [RFC 3339](www.ietf.org/rfc/rfc3339.txt) format with nano-seconds.
This information is only available if the image was tagged locally, and omitted otherwise.
1363 |
# File 'lib/docker_engine_api/models/image.rb', line 1363 optional :last_tag_time, String, api_name: :LastTagTime, nil?: true |