Class: DockerEngineAPI::Models::ImageBuildPruneParams

Inherits:
Internal::Type::BaseModel show all
Extended by:
Internal::Type::RequestParameters::Converter
Includes:
Internal::Type::RequestParameters
Defined in:
lib/docker_engine_api/models/image_build_prune_params.rb

Overview

Instance Attribute Summary collapse

Attributes included from Internal::Type::RequestParameters

#request_options

Instance Method Summary collapse

Methods included from Internal::Type::RequestParameters::Converter

dump_request

Methods included from Internal::Type::RequestParameters

included

Methods inherited from Internal::Type::BaseModel

==, #==, #[], coerce, #deconstruct_keys, #deep_to_h, dump, fields, hash, #hash, inherited, inspect, #inspect, known_fields, optional, recursively_to_h, required, #to_h, #to_json, #to_s, to_sorbet_type, #to_yaml

Methods included from Internal::Type::Converter

#coerce, coerce, #dump, dump, inspect, #inspect, meta_info, new_coerce_state, type_info

Methods included from Internal::Util::SorbetRuntimeSupport

#const_missing, #define_sorbet_constant!, #sorbet_constant_defined?, #to_sorbet_type, to_sorbet_type

Constructor Details

#initialize(all: nil, filters: nil, max_used_space: nil, min_free_space: nil, reserved_space: nil, request_options: {}) ⇒ Object

Some parameter documentations has been truncated, see DockerEngineAPI::Models::ImageBuildPruneParams for more details.

Parameters:

  • all (Boolean) (defaults to: nil)

    Remove all types of build cache

  • filters (String) (defaults to: nil)

    A JSON encoded value of the filters (a map[string][]string) to

  • max_used_space (Integer) (defaults to: nil)

    Maximum amount of disk space allowed to keep for cache

  • min_free_space (Integer) (defaults to: nil)

    Target amount of free disk space after pruning

  • reserved_space (Integer) (defaults to: nil)

    Amount of disk space in bytes to keep for cache

  • request_options (DockerEngineAPI::RequestOptions, Hash{Symbol=>Object}) (defaults to: {})


# File 'lib/docker_engine_api/models/image_build_prune_params.rb', line 54

Instance Attribute Details

#allBoolean?

Remove all types of build cache

Returns:

  • (Boolean, nil)


14
# File 'lib/docker_engine_api/models/image_build_prune_params.rb', line 14

optional :all, DockerEngineAPI::Internal::Type::Boolean

#filtersString?

A JSON encoded value of the filters (a map[string][]string) to process on the list of build cache objects.

Available filters:

  • ‘until=<timestamp>` remove cache older than `<timestamp>`. The `<timestamp>` can be Unix timestamps, date formatted timestamps, or Go duration strings (e.g. 10m, 1h30m) computed relative to the daemon’s local time.

  • ‘id=<id>`

  • ‘parent=<id>`

  • ‘type=<string>`

  • ‘description=<string>`

  • inuse

  • shared

  • private

Returns:

  • (String, nil)


34
# File 'lib/docker_engine_api/models/image_build_prune_params.rb', line 34

optional :filters, String

#max_used_spaceInteger?

Maximum amount of disk space allowed to keep for cache

Returns:

  • (Integer, nil)


40
# File 'lib/docker_engine_api/models/image_build_prune_params.rb', line 40

optional :max_used_space, Integer

#min_free_spaceInteger?

Target amount of free disk space after pruning

Returns:

  • (Integer, nil)


46
# File 'lib/docker_engine_api/models/image_build_prune_params.rb', line 46

optional :min_free_space, Integer

#reserved_spaceInteger?

Amount of disk space in bytes to keep for cache

Returns:

  • (Integer, nil)


52
# File 'lib/docker_engine_api/models/image_build_prune_params.rb', line 52

optional :reserved_space, Integer