Class: DockerEngineAPI::Models::ImageDeleteParams

Inherits:
Internal::Type::BaseModel show all
Extended by:
Internal::Type::RequestParameters::Converter
Includes:
Internal::Type::RequestParameters
Defined in:
lib/docker_engine_api/models/image_delete_params.rb

Overview

Instance Attribute Summary collapse

Attributes included from Internal::Type::RequestParameters

#request_options

Instance Method Summary collapse

Methods included from Internal::Type::RequestParameters::Converter

dump_request

Methods included from Internal::Type::RequestParameters

included

Methods inherited from Internal::Type::BaseModel

==, #==, #[], coerce, #deconstruct_keys, #deep_to_h, dump, fields, hash, #hash, inherited, inspect, #inspect, known_fields, optional, recursively_to_h, required, #to_h, #to_json, #to_s, to_sorbet_type, #to_yaml

Methods included from Internal::Type::Converter

#coerce, coerce, #dump, dump, inspect, #inspect, meta_info, new_coerce_state, type_info

Methods included from Internal::Util::SorbetRuntimeSupport

#const_missing, #define_sorbet_constant!, #sorbet_constant_defined?, #to_sorbet_type, to_sorbet_type

Constructor Details

#initialize(force: nil, noprune: nil, platforms: nil, request_options: {}) ⇒ Object

Some parameter documentations has been truncated, see DockerEngineAPI::Models::ImageDeleteParams for more details.

Parameters:

  • force (Boolean) (defaults to: nil)

    Remove the image even if it is being used by stopped containers or has other tag

  • noprune (Boolean) (defaults to: nil)

    Do not delete untagged parent images

  • platforms (Array<String>) (defaults to: nil)

    Select platform-specific content to delete.

  • request_options (DockerEngineAPI::RequestOptions, Hash{Symbol=>Object}) (defaults to: {})


# File 'lib/docker_engine_api/models/image_delete_params.rb', line 30

Instance Attribute Details

#forceBoolean?

Remove the image even if it is being used by stopped containers or has other tags

Returns:

  • (Boolean, nil)


15
# File 'lib/docker_engine_api/models/image_delete_params.rb', line 15

optional :force, DockerEngineAPI::Internal::Type::Boolean

#nopruneBoolean?

Do not delete untagged parent images

Returns:

  • (Boolean, nil)


21
# File 'lib/docker_engine_api/models/image_delete_params.rb', line 21

optional :noprune, DockerEngineAPI::Internal::Type::Boolean

#platformsArray<String>?

Select platform-specific content to delete. Multiple values are accepted. Each platform is a OCI platform encoded as a JSON string.

Returns:

  • (Array<String>, nil)


28
# File 'lib/docker_engine_api/models/image_delete_params.rb', line 28

optional :platforms, DockerEngineAPI::Internal::Type::ArrayOf[String]