Class: DockerEngineAPI::Models::ImagePullParams

Inherits:
Internal::Type::BaseModel show all
Extended by:
Internal::Type::RequestParameters::Converter
Includes:
Internal::Type::RequestParameters
Defined in:
lib/docker_engine_api/models/image_pull_params.rb

Overview

Instance Attribute Summary collapse

Attributes included from Internal::Type::RequestParameters

#request_options

Instance Method Summary collapse

Methods included from Internal::Type::RequestParameters::Converter

dump_request

Methods included from Internal::Type::RequestParameters

included

Methods inherited from Internal::Type::BaseModel

==, #==, #[], coerce, #deconstruct_keys, #deep_to_h, dump, fields, hash, #hash, inherited, inspect, #inspect, known_fields, optional, recursively_to_h, required, #to_h, #to_json, #to_s, to_sorbet_type, #to_yaml

Methods included from Internal::Type::Converter

#coerce, coerce, #dump, dump, inspect, #inspect, meta_info, new_coerce_state, type_info

Methods included from Internal::Util::SorbetRuntimeSupport

#const_missing, #define_sorbet_constant!, #sorbet_constant_defined?, #to_sorbet_type, to_sorbet_type

Constructor Details

#initialize(changes: nil, from_image: nil, from_src: nil, message: nil, platform: nil, repo: nil, tag: nil, body: nil, x_registry_auth: nil, request_options: {}) ⇒ Object

Some parameter documentations has been truncated, see DockerEngineAPI::Models::ImagePullParams for more details.

Parameters:

  • changes (Array<String>) (defaults to: nil)

    Apply Dockerfile instructions to the image that is created,

  • from_image (String) (defaults to: nil)

    Name of the image to pull. If the name includes a tag or digest, specific behavi

  • from_src (String) (defaults to: nil)

    Source to import. The value may be a URL from which the image can be retrieved o

  • message (String) (defaults to: nil)

    Set commit message for imported image.

  • platform (String) (defaults to: nil)

    Platform in the format os[/arch].

  • repo (String) (defaults to: nil)

    Repository name given to an image when it is imported. The repo may include a ta

  • tag (String) (defaults to: nil)

    Tag or digest. If empty when pulling an image, this causes all tags for the give

  • body (String) (defaults to: nil)
  • x_registry_auth (String) (defaults to: nil)
  • request_options (DockerEngineAPI::RequestOptions, Hash{Symbol=>Object}) (defaults to: {})


# File 'lib/docker_engine_api/models/image_pull_params.rb', line 90


Instance Attribute Details

#bodyString?

Returns:

  • (String, nil)


83
# File 'lib/docker_engine_api/models/image_pull_params.rb', line 83

optional :body, String

#changesArray<String>?

Apply Dockerfile instructions to the image that is created, for example: ‘changes=ENV DEBUG=true`. Note that `ENV DEBUG=true` should be URI component encoded.

Supported Dockerfile instructions: CMD|ENTRYPOINT|ENV|EXPOSE|ONBUILD|USER|VOLUME|WORKDIR

Returns:

  • (Array<String>, nil)


19
# File 'lib/docker_engine_api/models/image_pull_params.rb', line 19

optional :changes, DockerEngineAPI::Internal::Type::ArrayOf[String]

#from_imageString?

Name of the image to pull. If the name includes a tag or digest, specific behavior applies:

  • If only fromImage includes a tag, that tag is used.

  • If both fromImage and tag are provided, tag takes precedence.

  • If fromImage includes a digest, the image is pulled by digest, and tag is ignored.

  • If neither a tag nor digest is specified, all tags are pulled.

Returns:

  • (String, nil)


32
# File 'lib/docker_engine_api/models/image_pull_params.rb', line 32

optional :from_image, String

#from_srcString?

Source to import. The value may be a URL from which the image can be retrieved or - to read the image from the request body. This parameter may only be used when importing an image.

Returns:

  • (String, nil)


40
# File 'lib/docker_engine_api/models/image_pull_params.rb', line 40

optional :from_src, String

#messageString?

Set commit message for imported image.

Returns:

  • (String, nil)


46
# File 'lib/docker_engine_api/models/image_pull_params.rb', line 46

optional :message, String

#platformString?

Platform in the format os[/arch].

When used in combination with the fromImage option, the daemon checks if the given image is present in the local image cache with the given OS and Architecture, and otherwise attempts to pull the image. If the option is not set, the host’s native OS and Architecture are used. If the given image does not exist in the local image cache, the daemon attempts to pull the image with the host’s native OS and Architecture. If the given image does exists in the local image cache, but its OS or architecture does not match, a warning is produced.

When used with the fromSrc option to import an image from an archive, this option sets the platform information for the imported image. If the option is not set, the host’s native OS and Architecture are used for the imported image.

Returns:

  • (String, nil)


64
# File 'lib/docker_engine_api/models/image_pull_params.rb', line 64

optional :platform, String

#repoString?

Repository name given to an image when it is imported. The repo may include a tag. This parameter may only be used when importing an image.

Returns:

  • (String, nil)


71
# File 'lib/docker_engine_api/models/image_pull_params.rb', line 71

optional :repo, String

#tagString?

Tag or digest. If empty when pulling an image, this causes all tags for the given image to be pulled.

Returns:

  • (String, nil)


78
# File 'lib/docker_engine_api/models/image_pull_params.rb', line 78

optional :tag, String

#x_registry_authString?

Returns:

  • (String, nil)


88
# File 'lib/docker_engine_api/models/image_pull_params.rb', line 88

optional :x_registry_auth, String