Class: DockerEngineAPI::Models::ImagePushParams

Inherits:
Internal::Type::BaseModel show all
Extended by:
Internal::Type::RequestParameters::Converter
Includes:
Internal::Type::RequestParameters
Defined in:
lib/docker_engine_api/models/image_push_params.rb

Overview

Instance Attribute Summary collapse

Attributes included from Internal::Type::RequestParameters

#request_options

Instance Method Summary collapse

Methods included from Internal::Type::RequestParameters::Converter

dump_request

Methods included from Internal::Type::RequestParameters

included

Methods inherited from Internal::Type::BaseModel

==, #==, #[], coerce, #deconstruct_keys, #deep_to_h, dump, fields, hash, #hash, inherited, inspect, #inspect, known_fields, optional, recursively_to_h, required, #to_h, #to_json, #to_s, to_sorbet_type, #to_yaml

Methods included from Internal::Type::Converter

#coerce, coerce, #dump, dump, inspect, #inspect, meta_info, new_coerce_state, type_info

Methods included from Internal::Util::SorbetRuntimeSupport

#const_missing, #define_sorbet_constant!, #sorbet_constant_defined?, #to_sorbet_type, to_sorbet_type

Constructor Details

#initialize(x_registry_auth:, platform: nil, tag: nil, request_options: {}) ⇒ Object

Some parameter documentations has been truncated, see DockerEngineAPI::Models::ImagePushParams for more details.

Parameters:

  • x_registry_auth (String)
  • platform (String) (defaults to: nil)

    JSON-encoded OCI platform to select the platform-variant to push.

  • tag (String) (defaults to: nil)

    Tag of the image to push. For example, latest. If no tag is provided,

  • request_options (DockerEngineAPI::RequestOptions, Hash{Symbol=>Object}) (defaults to: {})


# File 'lib/docker_engine_api/models/image_push_params.rb', line 36


Instance Attribute Details

#platformString?

JSON-encoded OCI platform to select the platform-variant to push. If not provided, all available variants will attempt to be pushed.

If the daemon provides a multi-platform image store, this selects the platform-variant to push to the registry. If the image is a single-platform image, or if the multi-platform image does not provide a variant matching the given platform, an error is returned.

Example: ‘“linux”, “architecture”: “arm”, “variant”: “v5”`

Returns:

  • (String, nil)


27
# File 'lib/docker_engine_api/models/image_push_params.rb', line 27

optional :platform, String

#tagString?

Tag of the image to push. For example, latest. If no tag is provided, all tags of the given image that are present in the local image store are pushed.

Returns:

  • (String, nil)


34
# File 'lib/docker_engine_api/models/image_push_params.rb', line 34

optional :tag, String

#x_registry_authString

Returns:

  • (String)


13
# File 'lib/docker_engine_api/models/image_push_params.rb', line 13

required :x_registry_auth, String