Class: DockerEngineAPI::Models::Info::Containerd::Namespaces

Inherits:
Internal::Type::BaseModel show all
Defined in:
lib/docker_engine_api/models/info.rb

Overview

See Also:

Instance Attribute Summary collapse

Method Summary

Methods inherited from Internal::Type::BaseModel

#==, ==, #[], coerce, #deconstruct_keys, #deep_to_h, dump, fields, hash, #hash, inherited, #initialize, inspect, #inspect, known_fields, optional, recursively_to_h, required, #to_h, #to_json, #to_s, to_sorbet_type, #to_yaml

Methods included from Internal::Type::Converter

#coerce, coerce, #dump, dump, inspect, #inspect, meta_info, new_coerce_state, type_info

Methods included from Internal::Util::SorbetRuntimeSupport

#const_missing, #define_sorbet_constant!, #sorbet_constant_defined?, #to_sorbet_type, to_sorbet_type

Constructor Details

This class inherits a constructor from DockerEngineAPI::Internal::Type::BaseModel

Instance Attribute Details

#containersString?

The default containerd namespace used for containers managed by the daemon.

The default namespace for containers is “moby”, but will be suffixed with the ‘<uid>.<gid>` of the remapped root if user-namespaces are enabled and the containerd image-store is used.

Returns:

  • (String, nil)


734
# File 'lib/docker_engine_api/models/info.rb', line 734

optional :containers, String, api_name: :Containers

#pluginsString?

The default containerd namespace used for plugins managed by the daemon.

The default namespace for plugins is “plugins.moby”, but will be suffixed with the ‘<uid>.<gid>` of the remapped root if user-namespaces are enabled and the containerd image-store is used.

Returns:

  • (String, nil)


744
# File 'lib/docker_engine_api/models/info.rb', line 744

optional :plugins, String, api_name: :Plugins