Class: DockerEngineAPI::Models::Info::RegistryConfig::IndexConfig

Inherits:
Internal::Type::BaseModel show all
Defined in:
lib/docker_engine_api/models/info.rb

Instance Attribute Summary collapse

Instance Method Summary collapse

Methods inherited from Internal::Type::BaseModel

==, #==, #[], coerce, #deconstruct_keys, #deep_to_h, dump, fields, hash, #hash, inherited, inspect, #inspect, known_fields, optional, recursively_to_h, required, #to_h, #to_json, #to_s, to_sorbet_type, #to_yaml

Methods included from Internal::Type::Converter

#coerce, coerce, #dump, dump, inspect, #inspect, meta_info, new_coerce_state, type_info

Methods included from Internal::Util::SorbetRuntimeSupport

#const_missing, #define_sorbet_constant!, #sorbet_constant_defined?, #to_sorbet_type, to_sorbet_type

Constructor Details

#initialize(index_configs: nil, insecure_registry_cid_rs: nil, mirrors: nil) ⇒ Object

Some parameter documentations has been truncated, see DockerEngineAPI::Models::Info::RegistryConfig for more details.

RegistryServiceConfig stores daemon registry services configuration.

Parameters:

  • index_configs (Hash{Symbol=>DockerEngineAPI::Models::Info::RegistryConfig::IndexConfig, nil}) (defaults to: nil)
  • insecure_registry_cid_rs (Array<String>) (defaults to: nil)

    List of IP ranges of insecure registries, using the CIDR syntax

  • mirrors (Array<String>) (defaults to: nil)

    List of registry URLs that act as a mirror for the official



1078
1079
1080
1081
1082
1083
1084
1085
1086
1087
1088
1089
1090
1091
1092
1093
1094
1095
1096
1097
1098
1099
1100
1101
1102
1103
1104
1105
1106
1107
1108
1109
1110
1111
1112
1113
1114
1115
1116
1117
1118
1119
1120
1121
1122
1123
1124
1125
# File 'lib/docker_engine_api/models/info.rb', line 1078

class IndexConfig < DockerEngineAPI::Internal::Type::BaseModel
  # @!attribute mirrors
  #   List of mirrors, expressed as URIs.
  #
  #   @return [Array<String>, nil]
  optional :mirrors, DockerEngineAPI::Internal::Type::ArrayOf[String], api_name: :Mirrors

  # @!attribute name
  #   Name of the registry, such as "docker.io".
  #
  #   @return [String, nil]
  optional :name, String, api_name: :Name

  # @!attribute official
  #   Indicates whether this is an official registry (i.e., Docker Hub / docker.io)
  #
  #   @return [Boolean, nil]
  optional :official, DockerEngineAPI::Internal::Type::Boolean, api_name: :Official

  # @!attribute secure
  #   Indicates if the registry is part of the list of insecure registries.
  #
  #   If `false`, the registry is insecure. Insecure registries accept un-encrypted
  #   (HTTP) and/or untrusted (HTTPS with certificates from unknown CAs)
  #   communication.
  #
  #   > **Warning**: Insecure registries can be useful when running a local registry.
  #   > However, because its use creates security vulnerabilities it should ONLY be
  #   > enabled for testing purposes. For increased security, users should add their
  #   > CA to their system's list of trusted CAs instead of enabling this option.
  #
  #   @return [Boolean, nil]
  optional :secure, DockerEngineAPI::Internal::Type::Boolean, api_name: :Secure

  # @!method initialize(mirrors: nil, name: nil, official: nil, secure: nil)
  #   Some parameter documentations has been truncated, see
  #   {DockerEngineAPI::Models::Info::RegistryConfig::IndexConfig} for more details.
  #
  #   IndexInfo contains information about a registry.
  #
  #   @param mirrors [Array<String>] List of mirrors, expressed as URIs.
  #
  #   @param name [String] Name of the registry, such as "docker.io".
  #
  #   @param official [Boolean] Indicates whether this is an official registry (i.e., Docker Hub / docker.io)
  #
  #   @param secure [Boolean] Indicates if the registry is part of the list of insecure
end

Instance Attribute Details

#mirrorsArray<String>?

List of mirrors, expressed as URIs.

Returns:

  • (Array<String>, nil)


1083
# File 'lib/docker_engine_api/models/info.rb', line 1083

optional :mirrors, DockerEngineAPI::Internal::Type::ArrayOf[String], api_name: :Mirrors

#nameString?

Name of the registry, such as “docker.io”.

Returns:

  • (String, nil)


1089
# File 'lib/docker_engine_api/models/info.rb', line 1089

optional :name, String, api_name: :Name

#officialBoolean?

Indicates whether this is an official registry (i.e., Docker Hub / docker.io)

Returns:

  • (Boolean, nil)


1095
# File 'lib/docker_engine_api/models/info.rb', line 1095

optional :official, DockerEngineAPI::Internal::Type::Boolean, api_name: :Official

#secureBoolean?

Indicates if the registry is part of the list of insecure registries.

If false, the registry is insecure. Insecure registries accept un-encrypted (HTTP) and/or untrusted (HTTPS with certificates from unknown CAs) communication.

> Warning: Insecure registries can be useful when running a local registry. > However, because its use creates security vulnerabilities it should ONLY be > enabled for testing purposes. For increased security, users should add their > CA to their system’s list of trusted CAs instead of enabling this option.

Returns:

  • (Boolean, nil)


1110
# File 'lib/docker_engine_api/models/info.rb', line 1110

optional :secure, DockerEngineAPI::Internal::Type::Boolean, api_name: :Secure