Class: DockerEngineAPI::Models::Info::Swarm
- Inherits:
-
Internal::Type::BaseModel
- Object
- Internal::Type::BaseModel
- DockerEngineAPI::Models::Info::Swarm
- Defined in:
- lib/docker_engine_api/models/info.rb
Overview
Defined Under Namespace
Modules: LocalNodeState Classes: Cluster, RemoteManager
Instance Attribute Summary collapse
-
#cluster ⇒ DockerEngineAPI::Models::Info::Swarm::Cluster?
ClusterInfo represents information about the swarm as is returned by the “/info” endpoint.
- #control_available ⇒ Boolean?
- #error ⇒ String?
-
#local_node_state ⇒ Symbol, ...
Current local status of this node.
-
#managers ⇒ Integer?
Total number of managers in the swarm.
-
#node_addr ⇒ String?
IP address at which this node can be reached by other nodes in the swarm.
-
#node_id ⇒ String?
Unique identifier of for this node in the swarm.
-
#nodes ⇒ Integer?
Total number of nodes in the swarm.
-
#remote_managers ⇒ Array<DockerEngineAPI::Models::Info::Swarm::RemoteManager>?
List of ID’s and addresses of other managers in the swarm.
Class Method Summary collapse
Instance Method Summary collapse
-
#initialize(index: nil) ⇒ Object
constructor
The version number of the object such as node, service, etc.
Methods inherited from Internal::Type::BaseModel
==, #==, #[], coerce, #deconstruct_keys, #deep_to_h, dump, fields, hash, #hash, inherited, inspect, #inspect, known_fields, optional, recursively_to_h, required, #to_h, #to_json, #to_s, to_sorbet_type, #to_yaml
Methods included from Internal::Type::Converter
#coerce, coerce, #dump, dump, inspect, #inspect, meta_info, new_coerce_state, type_info
Methods included from Internal::Util::SorbetRuntimeSupport
#const_missing, #define_sorbet_constant!, #sorbet_constant_defined?, #to_sorbet_type, to_sorbet_type
Constructor Details
#initialize(index: nil) ⇒ Object
The version number of the object such as node, service, etc. This is needed to avoid conflicting writes. The client must send the version number along with the modified specification when updating these objects.
This approach ensures safe concurrency and determinism in that the change on the object may not be applied if the version number has changed from the last read. In other words, if two update requests specify the same base version, only one of the requests can succeed. As a result, two separate update requests that happen at the same time will not unintentionally overwrite each other.
|
|
# File 'lib/docker_engine_api/models/info.rb', line 1258
|
Instance Attribute Details
#cluster ⇒ DockerEngineAPI::Models::Info::Swarm::Cluster?
ClusterInfo represents information about the swarm as is returned by the “/info” endpoint. Join-tokens are not included.
1205 |
# File 'lib/docker_engine_api/models/info.rb', line 1205 optional :cluster, -> { DockerEngineAPI::Info::Swarm::Cluster }, api_name: :Cluster, nil?: true |
#control_available ⇒ Boolean?
1210 |
# File 'lib/docker_engine_api/models/info.rb', line 1210 optional :control_available, DockerEngineAPI::Internal::Type::Boolean, api_name: :ControlAvailable |
#error ⇒ String?
1215 |
# File 'lib/docker_engine_api/models/info.rb', line 1215 optional :error, String, api_name: :Error |
#local_node_state ⇒ Symbol, ...
Current local status of this node.
1221 1222 1223 |
# File 'lib/docker_engine_api/models/info.rb', line 1221 optional :local_node_state, enum: -> { DockerEngineAPI::Info::Swarm::LocalNodeState }, api_name: :LocalNodeState |
#managers ⇒ Integer?
Total number of managers in the swarm.
1229 |
# File 'lib/docker_engine_api/models/info.rb', line 1229 optional :managers, Integer, api_name: :Managers, nil?: true |
#node_addr ⇒ String?
IP address at which this node can be reached by other nodes in the swarm.
1235 |
# File 'lib/docker_engine_api/models/info.rb', line 1235 optional :node_addr, String, api_name: :NodeAddr |
#node_id ⇒ String?
Unique identifier of for this node in the swarm.
1241 |
# File 'lib/docker_engine_api/models/info.rb', line 1241 optional :node_id, String, api_name: :NodeID |
#nodes ⇒ Integer?
Total number of nodes in the swarm.
1247 |
# File 'lib/docker_engine_api/models/info.rb', line 1247 optional :nodes, Integer, api_name: :Nodes, nil?: true |
#remote_managers ⇒ Array<DockerEngineAPI::Models::Info::Swarm::RemoteManager>?
List of ID’s and addresses of other managers in the swarm.
1253 1254 1255 1256 |
# File 'lib/docker_engine_api/models/info.rb', line 1253 optional :remote_managers, -> { DockerEngineAPI::Internal::Type::ArrayOf[DockerEngineAPI::Info::Swarm::RemoteManager] }, api_name: :RemoteManagers, nil?: true |
Class Method Details
.values ⇒ Array<Symbol>
|
|
# File 'lib/docker_engine_api/models/info.rb', line 1458
|