Class: DockerEngineAPI::Models::Info::Swarm::Cluster

Inherits:
Internal::Type::BaseModel show all
Defined in:
lib/docker_engine_api/models/info.rb

Overview

See Also:

Defined Under Namespace

Classes: TlsInfo, Version

Instance Attribute Summary collapse

Instance Method Summary collapse

Methods inherited from Internal::Type::BaseModel

==, #==, #[], coerce, #deconstruct_keys, #deep_to_h, dump, fields, hash, #hash, inherited, inspect, #inspect, known_fields, optional, recursively_to_h, required, #to_h, #to_json, #to_s, to_sorbet_type, #to_yaml

Methods included from Internal::Type::Converter

#coerce, coerce, #dump, dump, inspect, #inspect, meta_info, new_coerce_state, type_info

Methods included from Internal::Util::SorbetRuntimeSupport

#const_missing, #define_sorbet_constant!, #sorbet_constant_defined?, #to_sorbet_type, to_sorbet_type

Constructor Details

#initialize(cert_issuer_public_key: nil, cert_issuer_subject: nil, trust_root: nil) ⇒ Object

Some parameter documentations has been truncated, see TlsInfo for more details.

Information about the issuer of leaf TLS certificates and the trusted root CA certificate.

Parameters:

  • cert_issuer_public_key (String) (defaults to: nil)

    The base64-url-safe-encoded raw public key bytes of the issuer.

  • cert_issuer_subject (String) (defaults to: nil)

    The base64-url-safe-encoded raw subject bytes of the issuer.

  • trust_root (String) (defaults to: nil)

    The root CA certificate(s) that are used to validate leaf TLS



# File 'lib/docker_engine_api/models/info.rb', line 1362


Instance Attribute Details

#created_atString?

Date and time at which the swarm was initialised in [RFC 3339](www.ietf.org/rfc/rfc3339.txt) format with nano-seconds.

Returns:

  • (String, nil)


1289
# File 'lib/docker_engine_api/models/info.rb', line 1289

optional :created_at, String, api_name: :CreatedAt

#data_path_portInteger?

DataPathPort specifies the data path port number for data traffic. Acceptable port range is 1024 to 49151. If no port is set or is set to 0, the default port (4789) is used.

Returns:

  • (Integer, nil)


1297
# File 'lib/docker_engine_api/models/info.rb', line 1297

optional :data_path_port, Integer, api_name: :DataPathPort

#default_addr_poolArray<String>?

Default Address Pool specifies default subnet pools for global scope networks.

Returns:

  • (Array<String>, nil)


1303
1304
1305
# File 'lib/docker_engine_api/models/info.rb', line 1303

optional :default_addr_pool,
DockerEngineAPI::Internal::Type::ArrayOf[String],
api_name: :DefaultAddrPool

#idString?

The ID of the swarm.

Returns:

  • (String, nil)


1311
# File 'lib/docker_engine_api/models/info.rb', line 1311

optional :id, String, api_name: :ID

#root_rotation_in_progressBoolean?

Whether there is currently a root CA rotation in progress for the swarm

Returns:

  • (Boolean, nil)


1317
1318
1319
# File 'lib/docker_engine_api/models/info.rb', line 1317

optional :root_rotation_in_progress,
DockerEngineAPI::Internal::Type::Boolean,
api_name: :RootRotationInProgress

#specDockerEngineAPI::Models::Spec?

User modifiable swarm configuration.



1325
# File 'lib/docker_engine_api/models/info.rb', line 1325

optional :spec, -> { DockerEngineAPI::Spec }, api_name: :Spec

#subnet_sizeInteger?

SubnetSize specifies the subnet size of the networks created from the default subnet pool.

Returns:

  • (Integer, nil)


1332
# File 'lib/docker_engine_api/models/info.rb', line 1332

optional :subnet_size, Integer, api_name: :SubnetSize

#tls_infoDockerEngineAPI::Models::Info::Swarm::Cluster::TlsInfo?

Information about the issuer of leaf TLS certificates and the trusted root CA certificate.



1339
# File 'lib/docker_engine_api/models/info.rb', line 1339

optional :tls_info, -> { DockerEngineAPI::Info::Swarm::Cluster::TlsInfo }, api_name: :TLSInfo

#updated_atString?

Date and time at which the swarm was last updated in [RFC 3339](www.ietf.org/rfc/rfc3339.txt) format with nano-seconds.

Returns:

  • (String, nil)


1346
# File 'lib/docker_engine_api/models/info.rb', line 1346

optional :updated_at, String, api_name: :UpdatedAt

#versionDockerEngineAPI::Models::Info::Swarm::Cluster::Version?

The version number of the object such as node, service, etc. This is needed to avoid conflicting writes. The client must send the version number along with the modified specification when updating these objects.

This approach ensures safe concurrency and determinism in that the change on the object may not be applied if the version number has changed from the last read. In other words, if two update requests specify the same base version, only one of the requests can succeed. As a result, two separate update requests that happen at the same time will not unintentionally overwrite each other.



1360
# File 'lib/docker_engine_api/models/info.rb', line 1360

optional :version, -> { DockerEngineAPI::Info::Swarm::Cluster::Version }, api_name: :Version