Class: DockerEngineAPI::Models::Inspect

Inherits:
Internal::Type::BaseModel show all
Defined in:
lib/docker_engine_api/models/inspect.rb

Overview

Defined Under Namespace

Classes: Descriptor, Platform

Instance Attribute Summary collapse

Instance Method Summary collapse

Methods inherited from Internal::Type::BaseModel

==, #==, #[], coerce, #deconstruct_keys, #deep_to_h, dump, fields, hash, #hash, inherited, inspect, #inspect, known_fields, optional, recursively_to_h, required, #to_h, #to_json, #to_s, to_sorbet_type, #to_yaml

Methods included from Internal::Type::Converter

#coerce, coerce, #dump, dump, inspect, #inspect, meta_info, new_coerce_state, type_info

Methods included from Internal::Util::SorbetRuntimeSupport

#const_missing, #define_sorbet_constant!, #sorbet_constant_defined?, #to_sorbet_type, to_sorbet_type

Constructor Details

#initialize(architecture: nil, os: nil, os_features: nil, os_version: nil, variant: nil) ⇒ Object

Some parameter documentations has been truncated, see DockerEngineAPI::Models::Inspect::Descriptor::Platform for more details.

Describes the platform which the image in the manifest runs on, as defined in the [OCI Image Index Specification](github.com/opencontainers/image-spec/blob/v1.0.1/image-index.md).



# File 'lib/docker_engine_api/models/inspect.rb', line 24

Instance Attribute Details

#descriptorDockerEngineAPI::Models::Inspect::Descriptor

A descriptor struct containing digest, media type, and size, as defined in the [OCI Content Descriptors Specification](github.com/opencontainers/image-spec/blob/v1.0.1/descriptor.md).



12
# File 'lib/docker_engine_api/models/inspect.rb', line 12

required :descriptor, -> { DockerEngineAPI::Inspect::Descriptor }, api_name: :Descriptor

#platformsArray<DockerEngineAPI::Models::Inspect::Platform, nil>

An array containing all platforms supported by the image.



18
19
20
21
22
# File 'lib/docker_engine_api/models/inspect.rb', line 18

required :platforms,
-> {
  DockerEngineAPI::Internal::Type::ArrayOf[DockerEngineAPI::Inspect::Platform, nil?: true]
},
api_name: :Platforms