Class: DockerEngineAPI::Models::NetworkCreateParams

Inherits:
Internal::Type::BaseModel show all
Extended by:
Internal::Type::RequestParameters::Converter
Includes:
Internal::Type::RequestParameters
Defined in:
lib/docker_engine_api/models/network_create_params.rb

Overview

Defined Under Namespace

Classes: ConfigFrom, Ipam

Instance Attribute Summary collapse

Attributes included from Internal::Type::RequestParameters

#request_options

Instance Method Summary collapse

Methods included from Internal::Type::RequestParameters::Converter

dump_request

Methods included from Internal::Type::RequestParameters

included

Methods inherited from Internal::Type::BaseModel

==, #==, #[], coerce, #deconstruct_keys, #deep_to_h, dump, fields, hash, #hash, inherited, inspect, #inspect, known_fields, optional, recursively_to_h, required, #to_h, #to_json, #to_s, to_sorbet_type, #to_yaml

Methods included from Internal::Type::Converter

#coerce, coerce, #dump, dump, inspect, #inspect, meta_info, new_coerce_state, type_info

Methods included from Internal::Util::SorbetRuntimeSupport

#const_missing, #define_sorbet_constant!, #sorbet_constant_defined?, #to_sorbet_type, to_sorbet_type

Constructor Details

#initialize(network: nil) ⇒ Object

Some parameter documentations has been truncated, see ConfigFrom for more details.

The config-only network source to provide the configuration for this network.

Parameters:

  • network (String) (defaults to: nil)

    The name of the config-only network that provides the network’s



# File 'lib/docker_engine_api/models/network_create_params.rb', line 132


Instance Attribute Details

#attachableBoolean?

Globally scoped network is manually attachable by regular containers from workers in swarm mode.

Returns:

  • (Boolean, nil)


21
# File 'lib/docker_engine_api/models/network_create_params.rb', line 21

optional :attachable, DockerEngineAPI::Internal::Type::Boolean, api_name: :Attachable

#config_fromDockerEngineAPI::Models::NetworkCreateParams::ConfigFrom?

The config-only network source to provide the configuration for this network.



27
# File 'lib/docker_engine_api/models/network_create_params.rb', line 27

optional :config_from, -> { DockerEngineAPI::NetworkCreateParams::ConfigFrom }, api_name: :ConfigFrom

#config_onlyBoolean?

Creates a config-only network. Config-only networks are placeholder networks for network configurations to be used by other networks. Config-only networks cannot be used directly to run containers or services.

Returns:

  • (Boolean, nil)


35
# File 'lib/docker_engine_api/models/network_create_params.rb', line 35

optional :config_only, DockerEngineAPI::Internal::Type::Boolean, api_name: :ConfigOnly

#driverString?

Name of the network driver plugin to use.

Returns:

  • (String, nil)


41
# File 'lib/docker_engine_api/models/network_create_params.rb', line 41

optional :driver, String, api_name: :Driver

#enable_i_pv4Boolean?

Enable IPv4 on the network.

Returns:

  • (Boolean, nil)


47
# File 'lib/docker_engine_api/models/network_create_params.rb', line 47

optional :enable_i_pv4, DockerEngineAPI::Internal::Type::Boolean, api_name: :EnableIPv4

#enable_i_pv6Boolean?

Enable IPv6 on the network.

Returns:

  • (Boolean, nil)


53
# File 'lib/docker_engine_api/models/network_create_params.rb', line 53

optional :enable_i_pv6, DockerEngineAPI::Internal::Type::Boolean, api_name: :EnableIPv6

#ingressBoolean?

Ingress network is the network which provides the routing-mesh in swarm mode.

Returns:

  • (Boolean, nil)


59
# File 'lib/docker_engine_api/models/network_create_params.rb', line 59

optional :ingress, DockerEngineAPI::Internal::Type::Boolean, api_name: :Ingress

#internalBoolean?

Restrict external access to the network.

Returns:

  • (Boolean, nil)


65
# File 'lib/docker_engine_api/models/network_create_params.rb', line 65

optional :internal, DockerEngineAPI::Internal::Type::Boolean, api_name: :Internal

#ipamDockerEngineAPI::Models::NetworkCreateParams::Ipam?



70
# File 'lib/docker_engine_api/models/network_create_params.rb', line 70

optional :ipam, -> { DockerEngineAPI::NetworkCreateParams::Ipam }, api_name: :IPAM

#labelsHash{Symbol=>String}?

User-defined key/value metadata.

Returns:

  • (Hash{Symbol=>String}, nil)


76
# File 'lib/docker_engine_api/models/network_create_params.rb', line 76

optional :labels, DockerEngineAPI::Internal::Type::HashOf[String], api_name: :Labels

#nameString

The network’s name.

Returns:

  • (String)


14
# File 'lib/docker_engine_api/models/network_create_params.rb', line 14

required :name, String, api_name: :Name

#optionsHash{Symbol=>String}?

Network specific options to be used by the drivers.

Returns:

  • (Hash{Symbol=>String}, nil)


82
# File 'lib/docker_engine_api/models/network_create_params.rb', line 82

optional :options, DockerEngineAPI::Internal::Type::HashOf[String], api_name: :Options

#scopeString?

The level at which the network exists (e.g. swarm for cluster-wide or local for machine level).

Returns:

  • (String, nil)


89
# File 'lib/docker_engine_api/models/network_create_params.rb', line 89

optional :scope, String, api_name: :Scope