Class: DockerEngineAPI::Models::NetworkCreateParams::ConfigFrom

Inherits:
Internal::Type::BaseModel show all
Defined in:
lib/docker_engine_api/models/network_create_params.rb

Instance Attribute Summary collapse

Instance Method Summary collapse

Methods inherited from Internal::Type::BaseModel

==, #==, #[], coerce, #deconstruct_keys, #deep_to_h, dump, fields, hash, #hash, inherited, inspect, #inspect, known_fields, optional, recursively_to_h, required, #to_h, #to_json, #to_s, to_sorbet_type, #to_yaml

Methods included from Internal::Type::Converter

#coerce, coerce, #dump, dump, inspect, #inspect, meta_info, new_coerce_state, type_info

Methods included from Internal::Util::SorbetRuntimeSupport

#const_missing, #define_sorbet_constant!, #sorbet_constant_defined?, #to_sorbet_type, to_sorbet_type

Constructor Details

#initialize(name:, attachable: nil, config_from: nil, config_only: nil, driver: nil, enable_i_pv4: nil, enable_i_pv6: nil, ingress: nil, internal: nil, ipam: nil, labels: nil, options: nil, scope: nil, request_options: {}) ⇒ Object

Some parameter documentations has been truncated, see DockerEngineAPI::Models::NetworkCreateParams for more details.

Parameters:

  • name (String)

    The network’s name.

  • attachable (Boolean) (defaults to: nil)

    Globally scoped network is manually attachable by regular

  • config_from (DockerEngineAPI::Models::NetworkCreateParams::ConfigFrom) (defaults to: nil)

    The config-only network source to provide the configuration for

  • config_only (Boolean) (defaults to: nil)

    Creates a config-only network. Config-only networks are placeholder

  • driver (String) (defaults to: nil)

    Name of the network driver plugin to use.

  • enable_i_pv4 (Boolean) (defaults to: nil)

    Enable IPv4 on the network.

  • enable_i_pv6 (Boolean) (defaults to: nil)

    Enable IPv6 on the network.

  • ingress (Boolean) (defaults to: nil)

    Ingress network is the network which provides the routing-mesh

  • internal (Boolean) (defaults to: nil)

    Restrict external access to the network.

  • ipam (DockerEngineAPI::Models::NetworkCreateParams::Ipam) (defaults to: nil)
  • labels (Hash{Symbol=>String}) (defaults to: nil)

    User-defined key/value metadata.

  • options (Hash{Symbol=>String}) (defaults to: nil)

    Network specific options to be used by the drivers.

  • scope (String) (defaults to: nil)

    The level at which the network exists (e.g. swarm for cluster-wide

  • request_options (DockerEngineAPI::RequestOptions, Hash{Symbol=>Object}) (defaults to: {})


123
124
125
126
127
128
129
130
131
132
133
134
135
136
137
138
139
# File 'lib/docker_engine_api/models/network_create_params.rb', line 123

class ConfigFrom < DockerEngineAPI::Internal::Type::BaseModel
  # @!attribute network
  #   The name of the config-only network that provides the network's configuration.
  #   The specified network must be an existing config-only network. Only network
  #   names are allowed, not network IDs.
  #
  #   @return [String, nil]
  optional :network, String, api_name: :Network

  # @!method initialize(network: nil)
  #   Some parameter documentations has been truncated, see
  #   {DockerEngineAPI::Models::NetworkCreateParams::ConfigFrom} for more details.
  #
  #   The config-only network source to provide the configuration for this network.
  #
  #   @param network [String] The name of the config-only network that provides the network's
end

Instance Attribute Details

#networkString?

The name of the config-only network that provides the network’s configuration. The specified network must be an existing config-only network. Only network names are allowed, not network IDs.

Returns:

  • (String, nil)


130
# File 'lib/docker_engine_api/models/network_create_params.rb', line 130

optional :network, String, api_name: :Network