Class: DockerEngineAPI::Models::Node::ManagerStatus

Inherits:
Internal::Type::BaseModel show all
Defined in:
lib/docker_engine_api/models/node.rb

Overview

See Also:

Defined Under Namespace

Modules: Reachability

Instance Attribute Summary collapse

Instance Method Summary collapse

Methods inherited from Internal::Type::BaseModel

==, #==, #[], coerce, #deconstruct_keys, #deep_to_h, dump, fields, hash, #hash, inherited, inspect, #inspect, known_fields, optional, recursively_to_h, required, #to_h, #to_json, #to_s, to_sorbet_type, #to_yaml

Methods included from Internal::Type::Converter

#coerce, coerce, #dump, dump, inspect, #inspect, meta_info, new_coerce_state, type_info

Methods included from Internal::Util::SorbetRuntimeSupport

#const_missing, #define_sorbet_constant!, #sorbet_constant_defined?, #to_sorbet_type, to_sorbet_type

Constructor Details

#initialize(addr: nil, leader: nil, reachability: nil) ⇒ Object

Some parameter documentations has been truncated, see DockerEngineAPI::Models::Node::ManagerStatus for more details.

ManagerStatus represents the status of a manager.

It provides the current status of a node’s manager component, if the node is a manager.

Parameters:

  • addr (String) (defaults to: nil)

    The IP address and port at which the manager is reachable.

  • leader (Boolean) (defaults to: nil)
  • reachability (Symbol, DockerEngineAPI::Models::Node::ManagerStatus::Reachability) (defaults to: nil)

    Reachability represents the reachability of a node.



# File 'lib/docker_engine_api/models/node.rb', line 361


Instance Attribute Details

#addrString?

The IP address and port at which the manager is reachable.

Returns:

  • (String, nil)


346
# File 'lib/docker_engine_api/models/node.rb', line 346

optional :addr, String, api_name: :Addr

#leaderBoolean?

Returns:

  • (Boolean, nil)


351
# File 'lib/docker_engine_api/models/node.rb', line 351

optional :leader, DockerEngineAPI::Internal::Type::Boolean, api_name: :Leader

#reachabilitySymbol, ...

Reachability represents the reachability of a node.



357
358
359
# File 'lib/docker_engine_api/models/node.rb', line 357

optional :reachability,
enum: -> { DockerEngineAPI::Node::ManagerStatus::Reachability },
api_name: :Reachability