Class: DockerEngineAPI::Models::NodeListParams

Inherits:
Internal::Type::BaseModel show all
Extended by:
Internal::Type::RequestParameters::Converter
Includes:
Internal::Type::RequestParameters
Defined in:
lib/docker_engine_api/models/node_list_params.rb

Overview

Instance Attribute Summary collapse

Attributes included from Internal::Type::RequestParameters

#request_options

Instance Method Summary collapse

Methods included from Internal::Type::RequestParameters::Converter

dump_request

Methods included from Internal::Type::RequestParameters

included

Methods inherited from Internal::Type::BaseModel

==, #==, #[], coerce, #deconstruct_keys, #deep_to_h, dump, fields, hash, #hash, inherited, inspect, #inspect, known_fields, optional, recursively_to_h, required, #to_h, #to_json, #to_s, to_sorbet_type, #to_yaml

Methods included from Internal::Type::Converter

#coerce, coerce, #dump, dump, inspect, #inspect, meta_info, new_coerce_state, type_info

Methods included from Internal::Util::SorbetRuntimeSupport

#const_missing, #define_sorbet_constant!, #sorbet_constant_defined?, #to_sorbet_type, to_sorbet_type

Constructor Details

#initialize(filters: nil, request_options: {}) ⇒ Object

Some parameter documentations has been truncated, see DockerEngineAPI::Models::NodeListParams for more details.

Parameters:

  • filters (String) (defaults to: nil)

    Filters to process on the nodes list, encoded as JSON (a map[string][]string).

  • request_options (DockerEngineAPI::RequestOptions, Hash{Symbol=>Object}) (defaults to: {})


# File 'lib/docker_engine_api/models/node_list_params.rb', line 25


Instance Attribute Details

#filtersString?

Filters to process on the nodes list, encoded as JSON (a map[string][]string).

Available filters:

  • ‘id=<node id>`

  • ‘label=<engine label>`

  • membership=(accepted|pending)‘

  • ‘name=<node name>`

  • ‘node.label=<node label>`

  • role=(manager|worker)‘

Returns:

  • (String, nil)


23
# File 'lib/docker_engine_api/models/node_list_params.rb', line 23

optional :filters, String