Class: DockerEngineAPI::Models::Plugin::Config::Interface
- Inherits:
-
Internal::Type::BaseModel
- Object
- Internal::Type::BaseModel
- DockerEngineAPI::Models::Plugin::Config::Interface
- Defined in:
- lib/docker_engine_api/models/plugin.rb
Overview
Defined Under Namespace
Modules: ProtocolScheme
Instance Attribute Summary collapse
-
#protocol_scheme ⇒ Symbol, ...
Protocol to use for clients connecting to the plugin.
- #socket ⇒ String
- #types ⇒ Array<String>
Instance Method Summary collapse
-
#initialize(socket:, types:, protocol_scheme: nil) ⇒ Object
constructor
The interface between Docker and the plugin.
Methods inherited from Internal::Type::BaseModel
==, #==, #[], coerce, #deconstruct_keys, #deep_to_h, dump, fields, hash, #hash, inherited, inspect, #inspect, known_fields, optional, recursively_to_h, required, #to_h, #to_json, #to_s, to_sorbet_type, #to_yaml
Methods included from Internal::Type::Converter
#coerce, coerce, #dump, dump, inspect, #inspect, meta_info, new_coerce_state, type_info
Methods included from Internal::Util::SorbetRuntimeSupport
#const_missing, #define_sorbet_constant!, #sorbet_constant_defined?, #to_sorbet_type, to_sorbet_type
Constructor Details
#initialize(socket:, types:, protocol_scheme: nil) ⇒ Object
The interface between Docker and the plugin
|
|
# File 'lib/docker_engine_api/models/plugin.rb', line 252
|
Instance Attribute Details
#protocol_scheme ⇒ Symbol, ...
Protocol to use for clients connecting to the plugin.
248 249 250 |
# File 'lib/docker_engine_api/models/plugin.rb', line 248 optional :protocol_scheme, enum: -> { DockerEngineAPI::Plugin::Config::Interface::ProtocolScheme }, api_name: :ProtocolScheme |
#socket ⇒ String
237 |
# File 'lib/docker_engine_api/models/plugin.rb', line 237 required :socket, String, api_name: :Socket |
#types ⇒ Array<String>
242 |
# File 'lib/docker_engine_api/models/plugin.rb', line 242 required :types, DockerEngineAPI::Internal::Type::ArrayOf[String], api_name: :Types |