Class: DockerEngineAPI::Models::PluginPullParams

Inherits:
Internal::Type::BaseModel show all
Extended by:
Internal::Type::RequestParameters::Converter
Includes:
Internal::Type::RequestParameters
Defined in:
lib/docker_engine_api/models/plugin_pull_params.rb

Overview

Instance Attribute Summary collapse

Attributes included from Internal::Type::RequestParameters

#request_options

Instance Method Summary collapse

Methods included from Internal::Type::RequestParameters::Converter

dump_request

Methods included from Internal::Type::RequestParameters

included

Methods inherited from Internal::Type::BaseModel

==, #==, #[], coerce, #deconstruct_keys, #deep_to_h, dump, fields, hash, #hash, inherited, inspect, #inspect, known_fields, optional, recursively_to_h, required, #to_h, #to_json, #to_s, to_sorbet_type, #to_yaml

Methods included from Internal::Type::Converter

#coerce, coerce, #dump, dump, inspect, #inspect, meta_info, new_coerce_state, type_info

Methods included from Internal::Util::SorbetRuntimeSupport

#const_missing, #define_sorbet_constant!, #sorbet_constant_defined?, #to_sorbet_type, to_sorbet_type

Constructor Details

#initialize(remote:, name: nil, body: nil, x_registry_auth: nil, request_options: {}) ⇒ Object

Some parameter documentations has been truncated, see DockerEngineAPI::Models::PluginPullParams for more details.

Parameters:

  • remote (String)

    Remote reference for plugin to install.

  • name (String) (defaults to: nil)

    Local name for the pulled plugin.

  • body (Array<DockerEngineAPI::Models::Privilege>) (defaults to: nil)
  • x_registry_auth (String) (defaults to: nil)
  • request_options (DockerEngineAPI::RequestOptions, Hash{Symbol=>Object}) (defaults to: {})


# File 'lib/docker_engine_api/models/plugin_pull_params.rb', line 36


Instance Attribute Details

#bodyArray<DockerEngineAPI::Models::Privilege>?

Returns:



29
# File 'lib/docker_engine_api/models/plugin_pull_params.rb', line 29

optional :body, -> { DockerEngineAPI::Internal::Type::ArrayOf[DockerEngineAPI::Privilege] }

#nameString?

Local name for the pulled plugin.

The :latest tag is optional, and is used as the default if omitted.

Returns:

  • (String, nil)


24
# File 'lib/docker_engine_api/models/plugin_pull_params.rb', line 24

optional :name, String

#remoteString

Remote reference for plugin to install.

The :latest tag is optional, and is used as the default if omitted.

Returns:

  • (String)


16
# File 'lib/docker_engine_api/models/plugin_pull_params.rb', line 16

required :remote, String

#x_registry_authString?

Returns:

  • (String, nil)


34
# File 'lib/docker_engine_api/models/plugin_pull_params.rb', line 34

optional :x_registry_auth, String