Class: DockerEngineAPI::Models::Service::ServiceStatus
- Inherits:
-
Internal::Type::BaseModel
- Object
- Internal::Type::BaseModel
- DockerEngineAPI::Models::Service::ServiceStatus
- Defined in:
- lib/docker_engine_api/models/service.rb
Overview
Instance Attribute Summary collapse
-
#completed_tasks ⇒ Integer?
The number of tasks for a job that are in the Completed state.
-
#desired_tasks ⇒ Integer?
The number of tasks for the service desired to be running.
-
#running_tasks ⇒ Integer?
The number of tasks for the service currently in the Running state.
Method Summary
Methods inherited from Internal::Type::BaseModel
#==, ==, #[], coerce, #deconstruct_keys, #deep_to_h, dump, fields, hash, #hash, inherited, #initialize, inspect, #inspect, known_fields, optional, recursively_to_h, required, #to_h, #to_json, #to_s, to_sorbet_type, #to_yaml
Methods included from Internal::Type::Converter
#coerce, coerce, #dump, dump, inspect, #inspect, meta_info, new_coerce_state, type_info
Methods included from Internal::Util::SorbetRuntimeSupport
#const_missing, #define_sorbet_constant!, #sorbet_constant_defined?, #to_sorbet_type, to_sorbet_type
Constructor Details
This class inherits a constructor from DockerEngineAPI::Internal::Type::BaseModel
Instance Attribute Details
#completed_tasks ⇒ Integer?
The number of tasks for a job that are in the Completed state. This field must be cross-referenced with the service type, as the value of 0 may mean the service is not in a job mode, or it may mean the job-mode service has no tasks yet Completed.
428 |
# File 'lib/docker_engine_api/models/service.rb', line 428 optional :completed_tasks, Integer, api_name: :CompletedTasks |
#desired_tasks ⇒ Integer?
The number of tasks for the service desired to be running. For replicated services, this is the replica count from the service spec. For global services, this is computed by taking count of all tasks for the service with a Desired State other than Shutdown.
437 |
# File 'lib/docker_engine_api/models/service.rb', line 437 optional :desired_tasks, Integer, api_name: :DesiredTasks |
#running_tasks ⇒ Integer?
The number of tasks for the service currently in the Running state.
443 |
# File 'lib/docker_engine_api/models/service.rb', line 443 optional :running_tasks, Integer, api_name: :RunningTasks |