Class: DockerEngineAPI::Models::ServiceLogsParams
- Inherits:
-
Internal::Type::BaseModel
- Object
- Internal::Type::BaseModel
- DockerEngineAPI::Models::ServiceLogsParams
- Extended by:
- Internal::Type::RequestParameters::Converter
- Includes:
- Internal::Type::RequestParameters
- Defined in:
- lib/docker_engine_api/models/service_logs_params.rb
Overview
Instance Attribute Summary collapse
-
#details ⇒ Boolean?
Show service context and extra details provided to logs.
-
#follow ⇒ Boolean?
Keep connection after returning logs.
-
#since ⇒ Integer?
Only return logs since this time, as a UNIX timestamp.
-
#stderr ⇒ Boolean?
Return logs from
stderr. -
#stdout ⇒ Boolean?
Return logs from
stdout. -
#tail ⇒ String?
Only return this number of log lines from the end of the logs.
-
#timestamps ⇒ Boolean?
Add timestamps to every log line.
Attributes included from Internal::Type::RequestParameters
Instance Method Summary collapse
-
#initialize(details: nil, follow: nil, since: nil, stderr: nil, stdout: nil, tail: nil, timestamps: nil, request_options: {}) ⇒ Object
constructor
Some parameter documentations has been truncated, see ServiceLogsParams for more details.
Methods included from Internal::Type::RequestParameters::Converter
Methods included from Internal::Type::RequestParameters
Methods inherited from Internal::Type::BaseModel
==, #==, #[], coerce, #deconstruct_keys, #deep_to_h, dump, fields, hash, #hash, inherited, inspect, #inspect, known_fields, optional, recursively_to_h, required, #to_h, #to_json, #to_s, to_sorbet_type, #to_yaml
Methods included from Internal::Type::Converter
#coerce, coerce, #dump, dump, inspect, #inspect, meta_info, new_coerce_state, type_info
Methods included from Internal::Util::SorbetRuntimeSupport
#const_missing, #define_sorbet_constant!, #sorbet_constant_defined?, #to_sorbet_type, to_sorbet_type
Constructor Details
#initialize(details: nil, follow: nil, since: nil, stderr: nil, stdout: nil, tail: nil, timestamps: nil, request_options: {}) ⇒ Object
Some parameter documentations has been truncated, see DockerEngineAPI::Models::ServiceLogsParams for more details.
|
|
# File 'lib/docker_engine_api/models/service_logs_params.rb', line 53
|
Instance Attribute Details
#details ⇒ Boolean?
Show service context and extra details provided to logs.
14 |
# File 'lib/docker_engine_api/models/service_logs_params.rb', line 14 optional :details, DockerEngineAPI::Internal::Type::Boolean |
#follow ⇒ Boolean?
Keep connection after returning logs.
20 |
# File 'lib/docker_engine_api/models/service_logs_params.rb', line 20 optional :follow, DockerEngineAPI::Internal::Type::Boolean |
#since ⇒ Integer?
Only return logs since this time, as a UNIX timestamp
26 |
# File 'lib/docker_engine_api/models/service_logs_params.rb', line 26 optional :since, Integer |
#stderr ⇒ Boolean?
Return logs from stderr
32 |
# File 'lib/docker_engine_api/models/service_logs_params.rb', line 32 optional :stderr, DockerEngineAPI::Internal::Type::Boolean |
#stdout ⇒ Boolean?
Return logs from stdout
38 |
# File 'lib/docker_engine_api/models/service_logs_params.rb', line 38 optional :stdout, DockerEngineAPI::Internal::Type::Boolean |
#tail ⇒ String?
Only return this number of log lines from the end of the logs. Specify as an integer or all to output all log lines.
45 |
# File 'lib/docker_engine_api/models/service_logs_params.rb', line 45 optional :tail, String |
#timestamps ⇒ Boolean?
Add timestamps to every log line
51 |
# File 'lib/docker_engine_api/models/service_logs_params.rb', line 51 optional :timestamps, DockerEngineAPI::Internal::Type::Boolean |