Module: DockerEngineAPI::Models::Spec::UpdateConfig::Order

Extended by:
Internal::Type::Enum
Defined in:
lib/docker_engine_api/models/spec.rb

Overview

The order of operations when rolling out an updated task. Either the old task is shut down before the new task is started, or the new task is started before the old task is shut down.

See Also:

Constant Summary collapse

STOP_FIRST =
:"stop-first"
START_FIRST =
:"start-first"

Class Method Summary collapse

Methods included from Internal::Type::Enum

==, ===, coerce, dump, hash, inspect, to_sorbet_type, values

Methods included from Internal::Util::SorbetRuntimeSupport

#const_missing, #define_sorbet_constant!, #sorbet_constant_defined?, #to_sorbet_type, to_sorbet_type

Methods included from Internal::Type::Converter

#coerce, coerce, #dump, dump, inspect, #inspect, meta_info, new_coerce_state, type_info

Class Method Details

.valuesArray<Symbol>

Returns:

  • (Array<Symbol>)


# File 'lib/docker_engine_api/models/spec.rb', line 504