Class: DockerEngineAPI::Models::StatsResponse

Inherits:
Internal::Type::BaseModel show all
Defined in:
lib/docker_engine_api/models/stats_response.rb

Overview

Defined Under Namespace

Classes: BlkioStats, CPUStats, MemoryStats, PidsStats, PrecpuStats, StorageStats

Instance Attribute Summary collapse

Instance Method Summary collapse

Methods inherited from Internal::Type::BaseModel

==, #==, #[], coerce, #deconstruct_keys, #deep_to_h, dump, fields, hash, #hash, inherited, inspect, #inspect, known_fields, optional, recursively_to_h, required, #to_h, #to_json, #to_s, to_sorbet_type, #to_yaml

Methods included from Internal::Type::Converter

#coerce, coerce, #dump, dump, inspect, #inspect, meta_info, new_coerce_state, type_info

Methods included from Internal::Util::SorbetRuntimeSupport

#const_missing, #define_sorbet_constant!, #sorbet_constant_defined?, #to_sorbet_type, to_sorbet_type

Constructor Details

#initialize(periods: nil, throttled_periods: nil, throttled_time: nil) ⇒ Object

Some parameter documentations has been truncated, see DockerEngineAPI::Models::StatsResponse::PrecpuStats::ThrottlingData for more details.

CPU throttling stats of the container.

This type is Linux-specific and omitted for Windows containers.

Parameters:

  • periods (Integer) (defaults to: nil)

    Number of periods with throttling active.

  • throttled_periods (Integer) (defaults to: nil)

    Number of periods when the container hit its throttling limit.

  • throttled_time (Integer) (defaults to: nil)

    Aggregated time (in nanoseconds) the container was throttled for.



# File 'lib/docker_engine_api/models/stats_response.rb', line 108


Instance Attribute Details

#blkio_statsDockerEngineAPI::Models::StatsResponse::BlkioStats?

BlkioStats stores all IO service stats for data read and write.

This type is Linux-specific and holds many fields that are specific to cgroups v1. On a cgroup v2 host, all fields other than io_service_bytes_recursive are omitted or null.

This type is only populated on Linux and omitted for Windows containers.



23
# File 'lib/docker_engine_api/models/stats_response.rb', line 23

optional :blkio_stats, -> { DockerEngineAPI::StatsResponse::BlkioStats }, nil?: true

#cpu_statsDockerEngineAPI::Models::StatsResponse::CPUStats?

CPU related info of the container



29
# File 'lib/docker_engine_api/models/stats_response.rb', line 29

optional :cpu_stats, -> { DockerEngineAPI::StatsResponse::CPUStats }, nil?: true

#idString?

ID of the container for which the stats were collected.

Returns:

  • (String, nil)


11
# File 'lib/docker_engine_api/models/stats_response.rb', line 11

optional :id, String, nil?: true

#memory_statsDockerEngineAPI::Models::StatsResponse::MemoryStats?

Aggregates all memory stats since container inception on Linux. Windows returns stats for commit and private working set only.



36
# File 'lib/docker_engine_api/models/stats_response.rb', line 36

optional :memory_stats, -> { DockerEngineAPI::StatsResponse::MemoryStats }

#nameString?

Name of the container for which the stats were collected.

Returns:

  • (String, nil)


42
# File 'lib/docker_engine_api/models/stats_response.rb', line 42

optional :name, String, nil?: true

#networksObject?

Network statistics for the container per interface.

This field is omitted if the container has no networking enabled.

Returns:

  • (Object, nil)


50
# File 'lib/docker_engine_api/models/stats_response.rb', line 50

optional :networks, DockerEngineAPI::Internal::Type::Unknown, nil?: true

#num_procsInteger?

The number of processors on the system.

This field is Windows-specific and always zero for Linux containers.

Returns:

  • (Integer, nil)


58
# File 'lib/docker_engine_api/models/stats_response.rb', line 58

optional :num_procs, Integer

#os_typeString?

OSType is the OS of the container (“linux” or “windows”) to allow platform-specific handling of stats.

Returns:

  • (String, nil)


65
# File 'lib/docker_engine_api/models/stats_response.rb', line 65

optional :os_type, String, nil?: true

#pids_statsDockerEngineAPI::Models::StatsResponse::PidsStats?

PidsStats contains Linux-specific stats of a container’s process-IDs (PIDs).

This type is Linux-specific and omitted for Windows containers.



73
# File 'lib/docker_engine_api/models/stats_response.rb', line 73

optional :pids_stats, -> { DockerEngineAPI::StatsResponse::PidsStats }, nil?: true

#precpu_statsDockerEngineAPI::Models::StatsResponse::PrecpuStats?

CPU related info of the container



79
# File 'lib/docker_engine_api/models/stats_response.rb', line 79

optional :precpu_stats, -> { DockerEngineAPI::StatsResponse::PrecpuStats }, nil?: true

#prereadTime?

Date and time at which this first sample was collected. This field is not propagated if the “one-shot” option is set. If the “one-shot” option is set, this field may be omitted, empty, or set to a default date (0001-01-01T00:00:00Z).

The value is formatted as [RFC 3339](www.ietf.org/rfc/rfc3339.txt) with nano-seconds.

Returns:

  • (Time, nil)


91
# File 'lib/docker_engine_api/models/stats_response.rb', line 91

optional :preread, Time

#readTime?

Date and time at which this sample was collected. The value is formatted as [RFC 3339](www.ietf.org/rfc/rfc3339.txt) with nano-seconds.

Returns:

  • (Time, nil)


98
# File 'lib/docker_engine_api/models/stats_response.rb', line 98

optional :read, Time

#storage_statsDockerEngineAPI::Models::StatsResponse::StorageStats?

StorageStats is the disk I/O stats for read/write on Windows.

This type is Windows-specific and omitted for Linux containers.



106
# File 'lib/docker_engine_api/models/stats_response.rb', line 106

optional :storage_stats, -> { DockerEngineAPI::StatsResponse::StorageStats }, nil?: true