Class: DockerEngineAPI::Models::StatsResponse::BlkioStats

Inherits:
Internal::Type::BaseModel show all
Defined in:
lib/docker_engine_api/models/stats_response.rb

Overview

See Also:

Defined Under Namespace

Classes: IoMergedRecursive, IoQueueRecursive, IoServiceBytesRecursive, IoServiceTimeRecursive, IoServicedRecursive, IoTimeRecursive, IoWaitTimeRecursive, SectorsRecursive

Instance Attribute Summary collapse

Instance Method Summary collapse

Methods inherited from Internal::Type::BaseModel

==, #==, #[], coerce, #deconstruct_keys, #deep_to_h, dump, fields, hash, #hash, inherited, inspect, #inspect, known_fields, optional, recursively_to_h, required, #to_h, #to_json, #to_s, to_sorbet_type, #to_yaml

Methods included from Internal::Type::Converter

#coerce, coerce, #dump, dump, inspect, #inspect, meta_info, new_coerce_state, type_info

Methods included from Internal::Util::SorbetRuntimeSupport

#const_missing, #define_sorbet_constant!, #sorbet_constant_defined?, #to_sorbet_type, to_sorbet_type

Constructor Details

#initialize(major: nil, minor: nil, op: nil, value: nil) ⇒ Object

Blkio stats entry.

This type is Linux-specific and omitted for Windows containers.

Parameters:

  • major (Integer) (defaults to: nil)
  • minor (Integer) (defaults to: nil)
  • op (String) (defaults to: nil)
  • value (Integer) (defaults to: nil)


# File 'lib/docker_engine_api/models/stats_response.rb', line 281

Instance Attribute Details

#io_merged_recursiveArray<DockerEngineAPI::Models::StatsResponse::BlkioStats::IoMergedRecursive, nil>?

This field is only available when using Linux containers with cgroups v1. It is omitted or null when using cgroups v2.



147
148
149
150
151
152
# File 'lib/docker_engine_api/models/stats_response.rb', line 147

optional :io_merged_recursive,
-> {
  DockerEngineAPI::Internal::Type::ArrayOf[DockerEngineAPI::StatsResponse::BlkioStats::IoMergedRecursive,
                                           nil?: true]
},
nil?: true

#io_queue_recursiveArray<DockerEngineAPI::Models::StatsResponse::BlkioStats::IoQueueRecursive, nil>?

This field is only available when using Linux containers with cgroups v1. It is omitted or null when using cgroups v2.



159
160
161
162
163
164
# File 'lib/docker_engine_api/models/stats_response.rb', line 159

optional :io_queue_recursive,
-> {
  DockerEngineAPI::Internal::Type::ArrayOf[DockerEngineAPI::StatsResponse::BlkioStats::IoQueueRecursive,
                                           nil?: true]
},
nil?: true

#io_service_bytes_recursiveArray<DockerEngineAPI::Models::StatsResponse::BlkioStats::IoServiceBytesRecursive, nil>?



169
170
# File 'lib/docker_engine_api/models/stats_response.rb', line 169

optional :io_service_bytes_recursive,
-> { DockerEngineAPI::Internal::Type::ArrayOf[DockerEngineAPI::StatsResponse::BlkioStats::IoServiceBytesRecursive, nil?: true] }

#io_service_time_recursiveArray<DockerEngineAPI::Models::StatsResponse::BlkioStats::IoServiceTimeRecursive, nil>?

This field is only available when using Linux containers with cgroups v1. It is omitted or null when using cgroups v2.



177
178
179
180
181
182
# File 'lib/docker_engine_api/models/stats_response.rb', line 177

optional :io_service_time_recursive,
-> {
  DockerEngineAPI::Internal::Type::ArrayOf[DockerEngineAPI::StatsResponse::BlkioStats::IoServiceTimeRecursive,
                                           nil?: true]
},
nil?: true

#io_serviced_recursiveArray<DockerEngineAPI::Models::StatsResponse::BlkioStats::IoServicedRecursive, nil>?

This field is only available when using Linux containers with cgroups v1. It is omitted or null when using cgroups v2.



189
190
191
192
193
194
# File 'lib/docker_engine_api/models/stats_response.rb', line 189

optional :io_serviced_recursive,
-> {
  DockerEngineAPI::Internal::Type::ArrayOf[DockerEngineAPI::StatsResponse::BlkioStats::IoServicedRecursive,
                                           nil?: true]
},
nil?: true

#io_time_recursiveArray<DockerEngineAPI::Models::StatsResponse::BlkioStats::IoTimeRecursive, nil>?

This field is only available when using Linux containers with cgroups v1. It is omitted or null when using cgroups v2.



201
202
203
204
205
206
# File 'lib/docker_engine_api/models/stats_response.rb', line 201

optional :io_time_recursive,
-> {
  DockerEngineAPI::Internal::Type::ArrayOf[DockerEngineAPI::StatsResponse::BlkioStats::IoTimeRecursive,
                                           nil?: true]
},
nil?: true

#io_wait_time_recursiveArray<DockerEngineAPI::Models::StatsResponse::BlkioStats::IoWaitTimeRecursive, nil>?

This field is only available when using Linux containers with cgroups v1. It is omitted or null when using cgroups v2.



213
214
215
216
217
218
# File 'lib/docker_engine_api/models/stats_response.rb', line 213

optional :io_wait_time_recursive,
-> {
  DockerEngineAPI::Internal::Type::ArrayOf[DockerEngineAPI::StatsResponse::BlkioStats::IoWaitTimeRecursive,
                                           nil?: true]
},
nil?: true

#sectors_recursiveArray<DockerEngineAPI::Models::StatsResponse::BlkioStats::SectorsRecursive, nil>?

This field is only available when using Linux containers with cgroups v1. It is omitted or null when using cgroups v2.



225
226
227
228
229
230
# File 'lib/docker_engine_api/models/stats_response.rb', line 225

optional :sectors_recursive,
-> {
  DockerEngineAPI::Internal::Type::ArrayOf[DockerEngineAPI::StatsResponse::BlkioStats::SectorsRecursive,
                                           nil?: true]
},
nil?: true