Class: DockerEngineAPI::Models::Summary

Inherits:
Internal::Type::BaseModel show all
Defined in:
lib/docker_engine_api/models/summary.rb

Defined Under Namespace

Modules: State Classes: Health, HostConfig, ImageManifestDescriptor, Mount, NetworkSettings, Port

Instance Attribute Summary collapse

Class Method Summary collapse

Instance Method Summary collapse

Methods inherited from Internal::Type::BaseModel

==, #==, #[], coerce, #deconstruct_keys, #deep_to_h, dump, fields, hash, #hash, inherited, inspect, #inspect, known_fields, optional, recursively_to_h, required, #to_h, #to_json, #to_s, to_sorbet_type, #to_yaml

Methods included from Internal::Type::Converter

#coerce, coerce, #dump, dump, inspect, #inspect, meta_info, new_coerce_state, type_info

Methods included from Internal::Util::SorbetRuntimeSupport

#const_missing, #define_sorbet_constant!, #sorbet_constant_defined?, #to_sorbet_type, to_sorbet_type

Constructor Details

#initialize(i_pv4_address: nil, i_pv6_address: nil, link_local_ips: nil) ⇒ Object

EndpointIPAMConfig represents an endpoint’s IPAM configuration.

Parameters:

  • i_pv4_address (String) (defaults to: nil)
  • i_pv6_address (String) (defaults to: nil)
  • link_local_ips (Array<String>) (defaults to: nil)


# File 'lib/docker_engine_api/models/summary.rb', line 145


Instance Attribute Details

#commandString?

Command to run when starting the container

Returns:

  • (String, nil)


10
# File 'lib/docker_engine_api/models/summary.rb', line 10

optional :command, String, api_name: :Command

#createdInteger?

Date and time at which the container was created as a Unix timestamp (number of seconds since EPOCH).

Returns:

  • (Integer, nil)


17
# File 'lib/docker_engine_api/models/summary.rb', line 17

optional :created, Integer, api_name: :Created

#healthDockerEngineAPI::Models::Summary::Health?

Summary of health status

Added in v1.52, before that version all container summary not include Health. After this attribute introduced, it includes containers with no health checks configured, or containers that are not running with none



27
# File 'lib/docker_engine_api/models/summary.rb', line 27

optional :health, -> { DockerEngineAPI::Summary::Health }, api_name: :Health

#host_configDockerEngineAPI::Models::Summary::HostConfig?

Summary of host-specific runtime information of the container. This is a reduced set of information in the container’s “HostConfig” as available in the container “inspect” response.



35
# File 'lib/docker_engine_api/models/summary.rb', line 35

optional :host_config, -> { DockerEngineAPI::Summary::HostConfig }, api_name: :HostConfig

#idString?

The ID of this container as a 128-bit (64-character) hexadecimal string (32 bytes).

Returns:

  • (String, nil)


42
# File 'lib/docker_engine_api/models/summary.rb', line 42

optional :id, String, api_name: :Id

#imageString?

The name or ID of the image used to create the container.

This field shows the image reference as was specified when creating the container, which can be in its canonical form (e.g., docker.io/library/ubuntu:latest or ‘docker.io/library/ubuntu@sha256:72297848456d5d37d1262630108ab308d3e9ec7ed1c3286a32fe09856619a782`), short form (e.g., ubuntu:latest)), or the ID(-prefix) of the image (e.g., 72297848456d).

The content of this field can be updated at runtime if the image used to create the container is untagged, in which case the field is updated to contain the the image ID (digest) it was resolved to in its canonical, non-truncated form (e.g., sha256:72297848456d5d37d1262630108ab308d3e9ec7ed1c3286a32fe09856619a782).

Returns:

  • (String, nil)


60
# File 'lib/docker_engine_api/models/summary.rb', line 60

optional :image, String, api_name: :Image

#image_idString?

The ID (digest) of the image that this container was created from.

Returns:

  • (String, nil)


66
# File 'lib/docker_engine_api/models/summary.rb', line 66

optional :image_id, String, api_name: :ImageID

#image_manifest_descriptorDockerEngineAPI::Models::Summary::ImageManifestDescriptor?

A descriptor struct containing digest, media type, and size, as defined in the [OCI Content Descriptors Specification](github.com/opencontainers/image-spec/blob/v1.0.1/descriptor.md).



73
74
75
# File 'lib/docker_engine_api/models/summary.rb', line 73

optional :image_manifest_descriptor,
-> { DockerEngineAPI::Summary::ImageManifestDescriptor },
api_name: :ImageManifestDescriptor

#labelsHash{Symbol=>String}?

User-defined key/value metadata.

Returns:

  • (Hash{Symbol=>String}, nil)


81
# File 'lib/docker_engine_api/models/summary.rb', line 81

optional :labels, DockerEngineAPI::Internal::Type::HashOf[String], api_name: :Labels

#mountsArray<DockerEngineAPI::Models::Summary::Mount>?

List of mounts used by the container.



87
88
89
# File 'lib/docker_engine_api/models/summary.rb', line 87

optional :mounts,
-> { DockerEngineAPI::Internal::Type::ArrayOf[DockerEngineAPI::Summary::Mount] },
api_name: :Mounts

#namesArray<String>?

The names associated with this container. Most containers have a single name, but when using legacy “links”, the container can have multiple names.

For historic reasons, names are prefixed with a forward-slash (/).

Returns:

  • (Array<String>, nil)


98
# File 'lib/docker_engine_api/models/summary.rb', line 98

optional :names, DockerEngineAPI::Internal::Type::ArrayOf[String], api_name: :Names

#network_settingsDockerEngineAPI::Models::Summary::NetworkSettings?

Summary of the container’s network settings



104
# File 'lib/docker_engine_api/models/summary.rb', line 104

optional :network_settings, -> { DockerEngineAPI::Summary::NetworkSettings }, api_name: :NetworkSettings

#portsArray<DockerEngineAPI::Models::Summary::Port>?

Port-mappings for the container.



110
111
112
# File 'lib/docker_engine_api/models/summary.rb', line 110

optional :ports,
-> { DockerEngineAPI::Internal::Type::ArrayOf[DockerEngineAPI::Summary::Port] },
api_name: :Ports

#size_root_fsInteger?

The total size of all files in the read-only layers from the image that the container uses. These layers can be shared between containers.

This field is omitted by default, and only set when size is requested in the API request.

Returns:

  • (Integer, nil)


122
# File 'lib/docker_engine_api/models/summary.rb', line 122

optional :size_root_fs, Integer, api_name: :SizeRootFs, nil?: true

#size_rwInteger?

The size of files that have been created or changed by this container.

This field is omitted by default, and only set when size is requested in the API request.

Returns:

  • (Integer, nil)


131
# File 'lib/docker_engine_api/models/summary.rb', line 131

optional :size_rw, Integer, api_name: :SizeRw, nil?: true

#stateSymbol, ...

The state of this container.

Returns:



137
# File 'lib/docker_engine_api/models/summary.rb', line 137

optional :state, enum: -> { DockerEngineAPI::Summary::State }, api_name: :State

#statusString?

Additional human-readable status of this container (e.g. ‘Exit 0`)

Returns:

  • (String, nil)


143
# File 'lib/docker_engine_api/models/summary.rb', line 143

optional :status, String, api_name: :Status

Class Method Details

.valuesArray<Symbol>

Returns:

  • (Array<Symbol>)


# File 'lib/docker_engine_api/models/summary.rb', line 219