Class: DockerEngineAPI::Models::Summary::Health

Inherits:
Internal::Type::BaseModel show all
Defined in:
lib/docker_engine_api/models/summary.rb

Overview

See Also:

Defined Under Namespace

Modules: Status

Instance Attribute Summary collapse

Instance Method Summary collapse

Methods inherited from Internal::Type::BaseModel

==, #==, #[], coerce, #deconstruct_keys, #deep_to_h, dump, fields, hash, #hash, inherited, inspect, #inspect, known_fields, optional, recursively_to_h, required, #to_h, #to_json, #to_s, to_sorbet_type, #to_yaml

Methods included from Internal::Type::Converter

#coerce, coerce, #dump, dump, inspect, #inspect, meta_info, new_coerce_state, type_info

Methods included from Internal::Util::SorbetRuntimeSupport

#const_missing, #define_sorbet_constant!, #sorbet_constant_defined?, #to_sorbet_type, to_sorbet_type

Constructor Details

#initialize(failing_streak: nil, status: nil) ⇒ Object

Summary of health status

Added in v1.52, before that version all container summary not include Health. After this attribute introduced, it includes containers with no health checks configured, or containers that are not running with none

Parameters:



# File 'lib/docker_engine_api/models/summary.rb', line 197


Instance Attribute Details

#failing_streakInteger?

FailingStreak is the number of consecutive failures

Returns:

  • (Integer, nil)


189
# File 'lib/docker_engine_api/models/summary.rb', line 189

optional :failing_streak, Integer, api_name: :FailingStreak

#statusSymbol, ...

the health status of the container



195
# File 'lib/docker_engine_api/models/summary.rb', line 195

optional :status, enum: -> { DockerEngineAPI::Summary::Health::Status }, api_name: :Status