Class: DockerEngineAPI::Models::Summary::HostConfig

Inherits:
Internal::Type::BaseModel show all
Defined in:
lib/docker_engine_api/models/summary.rb

Overview

See Also:

Instance Attribute Summary collapse

Method Summary

Methods inherited from Internal::Type::BaseModel

#==, ==, #[], coerce, #deconstruct_keys, #deep_to_h, dump, fields, hash, #hash, inherited, #initialize, inspect, #inspect, known_fields, optional, recursively_to_h, required, #to_h, #to_json, #to_s, to_sorbet_type, #to_yaml

Methods included from Internal::Type::Converter

#coerce, coerce, #dump, dump, inspect, #inspect, meta_info, new_coerce_state, type_info

Methods included from Internal::Util::SorbetRuntimeSupport

#const_missing, #define_sorbet_constant!, #sorbet_constant_defined?, #to_sorbet_type, to_sorbet_type

Constructor Details

This class inherits a constructor from DockerEngineAPI::Internal::Type::BaseModel

Instance Attribute Details

#annotationsHash{Symbol=>String}?

Arbitrary key-value metadata attached to the container.

Returns:

  • (Hash{Symbol=>String}, nil)


230
231
232
233
# File 'lib/docker_engine_api/models/summary.rb', line 230

optional :annotations,
DockerEngineAPI::Internal::Type::HashOf[String],
api_name: :Annotations,
nil?: true

#network_modeString?

Networking mode (host, none, ‘container:<id>`) or name of the primary network the container is using.

This field is primarily for backward compatibility. The container can be connected to multiple networks for which information can be found in the NetworkSettings.Networks field, which enumerates settings per network.

Returns:

  • (String, nil)


244
# File 'lib/docker_engine_api/models/summary.rb', line 244

optional :network_mode, String, api_name: :NetworkMode