Class: DockerEngineAPI::Models::SwarmInitParams

Inherits:
Internal::Type::BaseModel show all
Extended by:
Internal::Type::RequestParameters::Converter
Includes:
Internal::Type::RequestParameters
Defined in:
lib/docker_engine_api/models/swarm_init_params.rb

Overview

Instance Attribute Summary collapse

Attributes included from Internal::Type::RequestParameters

#request_options

Instance Method Summary collapse

Methods included from Internal::Type::RequestParameters::Converter

dump_request

Methods included from Internal::Type::RequestParameters

included

Methods inherited from Internal::Type::BaseModel

==, #==, #[], coerce, #deconstruct_keys, #deep_to_h, dump, fields, hash, #hash, inherited, inspect, #inspect, known_fields, optional, recursively_to_h, required, #to_h, #to_json, #to_s, to_sorbet_type, #to_yaml

Methods included from Internal::Type::Converter

#coerce, coerce, #dump, dump, inspect, #inspect, meta_info, new_coerce_state, type_info

Methods included from Internal::Util::SorbetRuntimeSupport

#const_missing, #define_sorbet_constant!, #sorbet_constant_defined?, #to_sorbet_type, to_sorbet_type

Constructor Details

#initialize(advertise_addr: nil, data_path_addr: nil, data_path_port: nil, default_addr_pool: nil, force_new_cluster: nil, listen_addr: nil, spec: nil, subnet_size: nil, request_options: {}) ⇒ Object

Some parameter documentations has been truncated, see DockerEngineAPI::Models::SwarmInitParams for more details.

Parameters:

  • advertise_addr (String) (defaults to: nil)

    Externally reachable address advertised to other nodes. This

  • data_path_addr (String) (defaults to: nil)

    Address or interface to use for data path traffic (format:

  • data_path_port (Integer) (defaults to: nil)

    DataPathPort specifies the data path port number for data traffic.

  • default_addr_pool (Array<String>) (defaults to: nil)

    Default Address Pool specifies default subnet pools for global

  • force_new_cluster (Boolean) (defaults to: nil)

    Force creation of a new swarm.

  • listen_addr (String) (defaults to: nil)

    Listen address used for inter-manager communication, as well

  • spec (DockerEngineAPI::Models::Spec) (defaults to: nil)

    User modifiable swarm configuration.

  • subnet_size (Integer) (defaults to: nil)

    SubnetSize specifies the subnet size of the networks created

  • request_options (DockerEngineAPI::RequestOptions, Hash{Symbol=>Object}) (defaults to: {})


# File 'lib/docker_engine_api/models/swarm_init_params.rb', line 78


Instance Attribute Details

Externally reachable address advertised to other nodes. This can either be an address/port combination in the form 192.168.1.1:4567, or an interface followed by a port number, like eth0:4567. If the port number is omitted, the port number from the listen address is used. If AdvertiseAddr is not specified, it will be automatically detected when possible.

Returns:

  • (String, nil)


18
# File 'lib/docker_engine_api/models/swarm_init_params.rb', line 18

optional :advertise_addr, String, api_name: :AdvertiseAddr

#data_path_addrString?

Address or interface to use for data path traffic (format: ‘<ip|interface>`), for example, 192.168.1.1, or an interface, like eth0. If DataPathAddr is unspecified, the same address as AdvertiseAddr is used.

The DataPathAddr specifies the address that global scope network drivers will publish towards other nodes in order to reach the containers running on this node. Using this parameter it is possible to separate the container data traffic from the management traffic of the cluster.

Returns:

  • (String, nil)


31
# File 'lib/docker_engine_api/models/swarm_init_params.rb', line 31

optional :data_path_addr, String, api_name: :DataPathAddr

#data_path_portInteger?

DataPathPort specifies the data path port number for data traffic. Acceptable port range is 1024 to 49151. if no port is set or is set to 0, default port 4789 will be used.

Returns:

  • (Integer, nil)


39
# File 'lib/docker_engine_api/models/swarm_init_params.rb', line 39

optional :data_path_port, Integer, api_name: :DataPathPort

#default_addr_poolArray<String>?

Default Address Pool specifies default subnet pools for global scope networks.

Returns:

  • (Array<String>, nil)


45
46
47
# File 'lib/docker_engine_api/models/swarm_init_params.rb', line 45

optional :default_addr_pool,
DockerEngineAPI::Internal::Type::ArrayOf[String],
api_name: :DefaultAddrPool

#force_new_clusterBoolean?

Force creation of a new swarm.

Returns:

  • (Boolean, nil)


53
# File 'lib/docker_engine_api/models/swarm_init_params.rb', line 53

optional :force_new_cluster, DockerEngineAPI::Internal::Type::Boolean, api_name: :ForceNewCluster

#listen_addrString?

Listen address used for inter-manager communication, as well as determining the networking interface used for the VXLAN Tunnel Endpoint (VTEP). This can either be an address/port combination in the form 192.168.1.1:4567, or an interface followed by a port number, like eth0:4567. If the port number is omitted, the default swarm listening port is used.

Returns:

  • (String, nil)


63
# File 'lib/docker_engine_api/models/swarm_init_params.rb', line 63

optional :listen_addr, String, api_name: :ListenAddr

#specDockerEngineAPI::Models::Spec?

User modifiable swarm configuration.



69
# File 'lib/docker_engine_api/models/swarm_init_params.rb', line 69

optional :spec, -> { DockerEngineAPI::Spec }, api_name: :Spec

#subnet_sizeInteger?

SubnetSize specifies the subnet size of the networks created from the default subnet pool.

Returns:

  • (Integer, nil)


76
# File 'lib/docker_engine_api/models/swarm_init_params.rb', line 76

optional :subnet_size, Integer, api_name: :SubnetSize