Class: DockerEngineAPI::Models::SwarmJoinParams

Inherits:
Internal::Type::BaseModel show all
Extended by:
Internal::Type::RequestParameters::Converter
Includes:
Internal::Type::RequestParameters
Defined in:
lib/docker_engine_api/models/swarm_join_params.rb

Overview

Instance Attribute Summary collapse

Attributes included from Internal::Type::RequestParameters

#request_options

Instance Method Summary collapse

Methods included from Internal::Type::RequestParameters::Converter

dump_request

Methods included from Internal::Type::RequestParameters

included

Methods inherited from Internal::Type::BaseModel

==, #==, #[], coerce, #deconstruct_keys, #deep_to_h, dump, fields, hash, #hash, inherited, inspect, #inspect, known_fields, optional, recursively_to_h, required, #to_h, #to_json, #to_s, to_sorbet_type, #to_yaml

Methods included from Internal::Type::Converter

#coerce, coerce, #dump, dump, inspect, #inspect, meta_info, new_coerce_state, type_info

Methods included from Internal::Util::SorbetRuntimeSupport

#const_missing, #define_sorbet_constant!, #sorbet_constant_defined?, #to_sorbet_type, to_sorbet_type

Constructor Details

#initialize(advertise_addr: nil, data_path_addr: nil, join_token: nil, listen_addr: nil, remote_addrs: nil, request_options: {}) ⇒ Object

Some parameter documentations has been truncated, see DockerEngineAPI::Models::SwarmJoinParams for more details.

Parameters:

  • advertise_addr (String) (defaults to: nil)

    Externally reachable address advertised to other nodes. This

  • data_path_addr (String) (defaults to: nil)

    Address or interface to use for data path traffic (format:

  • join_token (String) (defaults to: nil)

    Secret token for joining this swarm.

  • listen_addr (String) (defaults to: nil)

    Listen address used for inter-manager communication if the node

  • remote_addrs (Array<String>) (defaults to: nil)

    Addresses of manager nodes already participating in the swarm.

  • request_options (DockerEngineAPI::RequestOptions, Hash{Symbol=>Object}) (defaults to: {})


# File 'lib/docker_engine_api/models/swarm_join_params.rb', line 53


Instance Attribute Details

Externally reachable address advertised to other nodes. This can either be an address/port combination in the form 192.168.1.1:4567, or an interface followed by a port number, like eth0:4567. If the port number is omitted, the port number from the listen address is used. If AdvertiseAddr is not specified, it will be automatically detected when possible.

Returns:

  • (String, nil)


18
# File 'lib/docker_engine_api/models/swarm_join_params.rb', line 18

optional :advertise_addr, String, api_name: :AdvertiseAddr

#data_path_addrString?

Address or interface to use for data path traffic (format: ‘<ip|interface>`), for example, 192.168.1.1, or an interface, like eth0. If DataPathAddr is unspecified, the same address as AdvertiseAddr is used.

The DataPathAddr specifies the address that global scope network drivers will publish towards other nodes in order to reach the containers running on this node. Using this parameter it is possible to separate the container data traffic from the management traffic of the cluster.

Returns:

  • (String, nil)


31
# File 'lib/docker_engine_api/models/swarm_join_params.rb', line 31

optional :data_path_addr, String, api_name: :DataPathAddr

#join_tokenString?

Secret token for joining this swarm.

Returns:

  • (String, nil)


37
# File 'lib/docker_engine_api/models/swarm_join_params.rb', line 37

optional :join_token, String, api_name: :JoinToken

#listen_addrString?

Listen address used for inter-manager communication if the node gets promoted to manager, as well as determining the networking interface used for the VXLAN Tunnel Endpoint (VTEP).

Returns:

  • (String, nil)


45
# File 'lib/docker_engine_api/models/swarm_join_params.rb', line 45

optional :listen_addr, String, api_name: :ListenAddr

#remote_addrsArray<String>?

Addresses of manager nodes already participating in the swarm.

Returns:

  • (Array<String>, nil)


51
# File 'lib/docker_engine_api/models/swarm_join_params.rb', line 51

optional :remote_addrs, DockerEngineAPI::Internal::Type::ArrayOf[String], api_name: :RemoteAddrs