Class: DockerEngineAPI::Models::Task::Status
- Inherits:
-
Internal::Type::BaseModel
- Object
- Internal::Type::BaseModel
- DockerEngineAPI::Models::Task::Status
- Defined in:
- lib/docker_engine_api/models/task.rb
Overview
Defined Under Namespace
Modules: State Classes: ContainerStatus, PortStatus
Instance Attribute Summary collapse
-
#container_status ⇒ DockerEngineAPI::Models::Task::Status::ContainerStatus?
represents the status of a container.
- #err ⇒ String?
- #message ⇒ String?
-
#port_status ⇒ DockerEngineAPI::Models::Task::Status::PortStatus?
represents the port status of a task’s host ports whose service has published host ports.
- #state ⇒ Symbol, ...
- #timestamp ⇒ String?
Class Method Summary collapse
Instance Method Summary collapse
-
#initialize(container_id: nil, exit_code: nil, pid: nil) ⇒ Object
constructor
represents the status of a container.
Methods inherited from Internal::Type::BaseModel
==, #==, #[], coerce, #deconstruct_keys, #deep_to_h, dump, fields, hash, #hash, inherited, inspect, #inspect, known_fields, optional, recursively_to_h, required, #to_h, #to_json, #to_s, to_sorbet_type, #to_yaml
Methods included from Internal::Type::Converter
#coerce, coerce, #dump, dump, inspect, #inspect, meta_info, new_coerce_state, type_info
Methods included from Internal::Util::SorbetRuntimeSupport
#const_missing, #define_sorbet_constant!, #sorbet_constant_defined?, #to_sorbet_type, to_sorbet_type
Constructor Details
#initialize(container_id: nil, exit_code: nil, pid: nil) ⇒ Object
represents the status of a container.
|
|
# File 'lib/docker_engine_api/models/task.rb', line 276
|
Instance Attribute Details
#container_status ⇒ DockerEngineAPI::Models::Task::Status::ContainerStatus?
represents the status of a container.
245 246 247 |
# File 'lib/docker_engine_api/models/task.rb', line 245 optional :container_status, -> { DockerEngineAPI::Task::Status::ContainerStatus }, api_name: :ContainerStatus |
#err ⇒ String?
252 |
# File 'lib/docker_engine_api/models/task.rb', line 252 optional :err, String, api_name: :Err |
#message ⇒ String?
257 |
# File 'lib/docker_engine_api/models/task.rb', line 257 optional :message, String, api_name: :Message |
#port_status ⇒ DockerEngineAPI::Models::Task::Status::PortStatus?
represents the port status of a task’s host ports whose service has published host ports
264 |
# File 'lib/docker_engine_api/models/task.rb', line 264 optional :port_status, -> { DockerEngineAPI::Task::Status::PortStatus }, api_name: :PortStatus |
#state ⇒ Symbol, ...
269 |
# File 'lib/docker_engine_api/models/task.rb', line 269 optional :state, enum: -> { DockerEngineAPI::Task::Status::State }, api_name: :State |
#timestamp ⇒ String?
274 |
# File 'lib/docker_engine_api/models/task.rb', line 274 optional :timestamp, String, api_name: :Timestamp |
Class Method Details
.values ⇒ Array<Symbol>
|
|
# File 'lib/docker_engine_api/models/task.rb', line 418
|