Class: DockerEngineAPI::Models::Version::Component

Inherits:
Internal::Type::BaseModel show all
Defined in:
lib/docker_engine_api/models/version.rb

Instance Attribute Summary collapse

Instance Method Summary collapse

Methods inherited from Internal::Type::BaseModel

==, #==, #[], coerce, #deconstruct_keys, #deep_to_h, dump, fields, hash, #hash, inherited, inspect, #inspect, known_fields, optional, recursively_to_h, required, #to_h, #to_json, #to_s, to_sorbet_type, #to_yaml

Methods included from Internal::Type::Converter

#coerce, coerce, #dump, dump, inspect, #inspect, meta_info, new_coerce_state, type_info

Methods included from Internal::Util::SorbetRuntimeSupport

#const_missing, #define_sorbet_constant!, #sorbet_constant_defined?, #to_sorbet_type, to_sorbet_type

Constructor Details

#initialize(api_version: nil, arch: nil, build_time: nil, components: nil, experimental: nil, git_commit: nil, go_version: nil, kernel_version: nil, min_api_version: nil, os: nil, platform: nil, version: nil) ⇒ Object

Some parameter documentations has been truncated, see DockerEngineAPI::Models::Version for more details.

Response of Engine API: GET “/version”

Parameters:

  • api_version (String) (defaults to: nil)

    The default (and highest) API version that is supported by the daemon

  • arch (String) (defaults to: nil)

    Architecture of the daemon, as returned by the Go runtime (GOARCH).

  • build_time (String) (defaults to: nil)

    The date and time that the daemon was compiled.

  • components (Array<DockerEngineAPI::Models::Version::Component>) (defaults to: nil)

    Information about system components

  • experimental (Boolean) (defaults to: nil)

    Indicates if the daemon is started with experimental features enabled.

  • git_commit (String) (defaults to: nil)

    The Git commit of the source code that was used to build the daemon

  • go_version (String) (defaults to: nil)

    The version Go used to compile the daemon, and the version of the Go

  • kernel_version (String) (defaults to: nil)

    The kernel version (‘uname -r`) that the daemon is running on.

  • min_api_version (String) (defaults to: nil)

    The minimum API version that is supported by the daemon

  • os (String) (defaults to: nil)

    The operating system that the daemon is running on (“linux” or “windows”)

  • platform (DockerEngineAPI::Models::Version::Platform) (defaults to: nil)
  • version (String) (defaults to: nil)

    The version of the daemon



118
119
120
121
122
123
124
125
126
127
128
129
130
131
132
133
134
135
136
137
138
139
140
141
142
143
144
145
146
147
148
149
150
# File 'lib/docker_engine_api/models/version.rb', line 118

class Component < DockerEngineAPI::Internal::Type::BaseModel
  # @!attribute name
  #   Name of the component
  #
  #   @return [String]
  required :name, String, api_name: :Name

  # @!attribute version
  #   Version of the component
  #
  #   @return [String]
  required :version, String, api_name: :Version

  # @!attribute details
  #   Key/value pairs of strings with additional information about the component.
  #   These values are intended for informational purposes only, and their content is
  #   not defined, and not part of the API specification.
  #
  #   These messages can be printed by the client as information to the user.
  #
  #   @return [Object, nil]
  optional :details, DockerEngineAPI::Internal::Type::Unknown, api_name: :Details, nil?: true

  # @!method initialize(name:, version:, details: nil)
  #   Some parameter documentations has been truncated, see
  #   {DockerEngineAPI::Models::Version::Component} for more details.
  #
  #   @param name [String] Name of the component
  #
  #   @param version [String] Version of the component
  #
  #   @param details [Object, nil] Key/value pairs of strings with additional information about the
end

Instance Attribute Details

#detailsObject?

Key/value pairs of strings with additional information about the component. These values are intended for informational purposes only, and their content is not defined, and not part of the API specification.

These messages can be printed by the client as information to the user.

Returns:

  • (Object, nil)


139
# File 'lib/docker_engine_api/models/version.rb', line 139

optional :details, DockerEngineAPI::Internal::Type::Unknown, api_name: :Details, nil?: true

#nameString

Name of the component

Returns:

  • (String)


123
# File 'lib/docker_engine_api/models/version.rb', line 123

required :name, String, api_name: :Name

#versionString

Version of the component

Returns:

  • (String)


129
# File 'lib/docker_engine_api/models/version.rb', line 129

required :version, String, api_name: :Version