Class: DockerEngineAPI::Models::Volume::ClusterVolume::Info

Inherits:
Internal::Type::BaseModel show all
Defined in:
lib/docker_engine_api/models/volume.rb

Overview

See Also:

Instance Attribute Summary collapse

Method Summary

Methods inherited from Internal::Type::BaseModel

#==, ==, #[], coerce, #deconstruct_keys, #deep_to_h, dump, fields, hash, #hash, inherited, #initialize, inspect, #inspect, known_fields, optional, recursively_to_h, required, #to_h, #to_json, #to_s, to_sorbet_type, #to_yaml

Methods included from Internal::Type::Converter

#coerce, coerce, #dump, dump, inspect, #inspect, meta_info, new_coerce_state, type_info

Methods included from Internal::Util::SorbetRuntimeSupport

#const_missing, #define_sorbet_constant!, #sorbet_constant_defined?, #to_sorbet_type, to_sorbet_type

Constructor Details

This class inherits a constructor from DockerEngineAPI::Internal::Type::BaseModel

Instance Attribute Details

#accessible_topologyArray<Hash{Symbol=>String}>?

The topology this volume is actually accessible from.

Returns:

  • (Array<Hash{Symbol=>String}>, nil)


198
199
200
# File 'lib/docker_engine_api/models/volume.rb', line 198

optional :accessible_topology,
DockerEngineAPI::Internal::Type::ArrayOf[DockerEngineAPI::Internal::Type::HashOf[String]],
api_name: :AccessibleTopology

#capacity_bytesInteger?

The capacity of the volume in bytes. A value of 0 indicates that the capacity is unknown.

Returns:

  • (Integer, nil)


207
# File 'lib/docker_engine_api/models/volume.rb', line 207

optional :capacity_bytes, Integer, api_name: :CapacityBytes

#volume_contextHash{Symbol=>String}?

A map of strings to strings returned from the storage plugin when the volume is created.

Returns:

  • (Hash{Symbol=>String}, nil)


214
# File 'lib/docker_engine_api/models/volume.rb', line 214

optional :volume_context, DockerEngineAPI::Internal::Type::HashOf[String], api_name: :VolumeContext

#volume_idString?

The ID of the volume as returned by the CSI storage plugin. This is distinct from the volume’s ID as provided by Docker. This ID is never used by the user when communicating with Docker to refer to this volume. If the ID is blank, then the Volume has not been successfully created in the plugin yet.

Returns:

  • (String, nil)


223
# File 'lib/docker_engine_api/models/volume.rb', line 223

optional :volume_id, String, api_name: :VolumeID