Class: DockerEngineAPI::Models::Volume::ClusterVolume::Spec::AccessMode::AccessibilityRequirements

Inherits:
Internal::Type::BaseModel
  • Object
show all
Defined in:
lib/docker_engine_api/models/volume.rb

Overview

Instance Attribute Summary collapse

Method Summary

Methods inherited from Internal::Type::BaseModel

#==, ==, #[], coerce, #deconstruct_keys, #deep_to_h, dump, fields, hash, #hash, inherited, #initialize, inspect, #inspect, known_fields, optional, recursively_to_h, required, #to_h, #to_json, #to_s, to_sorbet_type, #to_yaml

Methods included from Internal::Type::Converter

#coerce, coerce, #dump, dump, inspect, #inspect, meta_info, new_coerce_state, type_info

Methods included from Internal::Util::SorbetRuntimeSupport

#const_missing, #define_sorbet_constant!, #sorbet_constant_defined?, #to_sorbet_type, to_sorbet_type

Constructor Details

This class inherits a constructor from DockerEngineAPI::Internal::Type::BaseModel

Instance Attribute Details

#preferredArray<Hash{Symbol=>String}>?

A list of topologies that the volume should attempt to be provisioned in.

Returns:

  • (Array<Hash{Symbol=>String}>, nil)


454
455
456
# File 'lib/docker_engine_api/models/volume.rb', line 454

optional :preferred,
DockerEngineAPI::Internal::Type::ArrayOf[DockerEngineAPI::Internal::Type::HashOf[String]],
api_name: :Preferred

#requisiteArray<Hash{Symbol=>String}>?

A list of required topologies, at least one of which the volume must be accessible from.

Returns:

  • (Array<Hash{Symbol=>String}>, nil)


463
464
465
# File 'lib/docker_engine_api/models/volume.rb', line 463

optional :requisite,
DockerEngineAPI::Internal::Type::ArrayOf[DockerEngineAPI::Internal::Type::HashOf[String]],
api_name: :Requisite