Module: DockerEngineAPI::Models::Volume::ClusterVolume::Spec::AccessMode::Availability

Extended by:
Internal::Type::Enum
Defined in:
lib/docker_engine_api/models/volume.rb

Overview

The availability of the volume for use in tasks.

  • active The volume is fully available for scheduling on the cluster

  • pause No new workloads should use the volume, but existing workloads are not stopped.

  • drain All workloads using this volume should be stopped and rescheduled, and no new ones should be started.

See Also:

Constant Summary collapse

ACTIVE =
:active
PAUSE =
:pause
DRAIN =
:drain

Method Summary

Methods included from Internal::Type::Enum

==, ===, coerce, dump, hash, inspect, to_sorbet_type, values

Methods included from Internal::Util::SorbetRuntimeSupport

#const_missing, #define_sorbet_constant!, #sorbet_constant_defined?, #to_sorbet_type, to_sorbet_type

Methods included from Internal::Type::Converter

#coerce, coerce, #dump, dump, inspect, #inspect, meta_info, new_coerce_state, type_info