Class: DockerEngineAPI::Models::Volume::UsageData

Inherits:
Internal::Type::BaseModel show all
Defined in:
lib/docker_engine_api/models/volume.rb

Overview

See Also:

Instance Attribute Summary collapse

Instance Method Summary collapse

Methods inherited from Internal::Type::BaseModel

==, #==, #[], coerce, #deconstruct_keys, #deep_to_h, dump, fields, hash, #hash, inherited, inspect, #inspect, known_fields, optional, recursively_to_h, required, #to_h, #to_json, #to_s, to_sorbet_type, #to_yaml

Methods included from Internal::Type::Converter

#coerce, coerce, #dump, dump, inspect, #inspect, meta_info, new_coerce_state, type_info

Methods included from Internal::Util::SorbetRuntimeSupport

#const_missing, #define_sorbet_constant!, #sorbet_constant_defined?, #to_sorbet_type, to_sorbet_type

Constructor Details

#initialize(ref_count:, size:) ⇒ Object

Some parameter documentations has been truncated, see DockerEngineAPI::Models::Volume::UsageData for more details.

Usage details about the volume. This information is used by the GET /system/df endpoint, and omitted in other endpoints.

Parameters:

  • ref_count (Integer) —

    The number of containers referencing this volume. This field

  • size (Integer) —

    Amount of disk space used by the volume (in bytes). This information



# File 'lib/docker_engine_api/models/volume.rb', line 638

Instance Attribute Details

#ref_count ⇒ Integer

The number of containers referencing this volume. This field is set to -1 if the reference-count is not available.

Returns:

  • (Integer)


628
# File 'lib/docker_engine_api/models/volume.rb', line 628

required :ref_count, Integer, api_name: :RefCount

#size ⇒ Integer

Amount of disk space used by the volume (in bytes). This information is only available for volumes created with the "local" volume driver. For volumes created with other volume drivers, this field is set to -1 ("not available")

Returns:

  • (Integer)


636
# File 'lib/docker_engine_api/models/volume.rb', line 636

required :size, Integer, api_name: :Size