Class: DockerEngineAPI::Models::VolumeUpdateParams::Spec::AccessMode::Secret
- Inherits:
-
Internal::Type::BaseModel
- Object
- Internal::Type::BaseModel
- DockerEngineAPI::Models::VolumeUpdateParams::Spec::AccessMode::Secret
- Defined in:
- lib/docker_engine_api/models/volume_update_params.rb
Instance Attribute Summary collapse
-
#key ⇒ String?
Key is the name of the key of the key-value pair passed to the plugin.
-
#secret ⇒ String?
Secret is the swarm Secret object from which to read data.
Method Summary
Methods inherited from Internal::Type::BaseModel
#==, ==, #[], coerce, #deconstruct_keys, #deep_to_h, dump, fields, hash, #hash, inherited, #initialize, inspect, #inspect, known_fields, optional, recursively_to_h, required, #to_h, #to_json, #to_s, to_sorbet_type, #to_yaml
Methods included from Internal::Type::Converter
#coerce, coerce, #dump, dump, inspect, #inspect, meta_info, new_coerce_state, type_info
Methods included from Internal::Util::SorbetRuntimeSupport
#const_missing, #define_sorbet_constant!, #sorbet_constant_defined?, #to_sorbet_type, to_sorbet_type
Constructor Details
This class inherits a constructor from DockerEngineAPI::Internal::Type::BaseModel
Instance Attribute Details
#key ⇒ String?
Key is the name of the key of the key-value pair passed to the plugin.
277 |
# File 'lib/docker_engine_api/models/volume_update_params.rb', line 277 optional :key, String, api_name: :Key |
#secret ⇒ String?
Secret is the swarm Secret object from which to read data. This can be a Secret name or ID. The Secret data is retrieved by swarm and used as the value of the key-value pair passed to the plugin.
285 |
# File 'lib/docker_engine_api/models/volume_update_params.rb', line 285 optional :secret, String, api_name: :Secret |