Class: DockerEngineAPI::Models::Container::NetworkSettings
- Inherits:
-
Internal::Type::BaseModel
- Object
- Internal::Type::BaseModel
- DockerEngineAPI::Models::Container::NetworkSettings
- Defined in:
- lib/docker_engine_api/models/container.rb
Overview
Defined Under Namespace
Instance Attribute Summary collapse
-
#networks ⇒ Hash{Symbol=>DockerEngineAPI::Models::Container::NetworkSettings::Network}?
Information about all networks that the container is connected to.
-
#ports ⇒ Hash{Symbol=>Array<DockerEngineAPI::Models::Container::NetworkSettings::Port>}?
PortMap describes the mapping of container ports to host ports, using the container’s port-number and protocol as key in the format ‘<port>/<protocol>`, for example,
80/udp. -
#sandbox_id ⇒ String?
SandboxID uniquely represents a container’s network stack.
-
#sandbox_key ⇒ String?
SandboxKey is the full path of the netns handle.
Instance Method Summary collapse
-
#initialize(i_pv4_address: nil, i_pv6_address: nil, link_local_ips: nil) ⇒ Object
constructor
EndpointIPAMConfig represents an endpoint’s IPAM configuration.
Methods inherited from Internal::Type::BaseModel
==, #==, #[], coerce, #deconstruct_keys, #deep_to_h, dump, fields, hash, #hash, inherited, inspect, #inspect, known_fields, optional, recursively_to_h, required, #to_h, #to_json, #to_s, to_sorbet_type, #to_yaml
Methods included from Internal::Type::Converter
#coerce, coerce, #dump, dump, inspect, #inspect, meta_info, new_coerce_state, type_info
Methods included from Internal::Util::SorbetRuntimeSupport
#const_missing, #define_sorbet_constant!, #sorbet_constant_defined?, #to_sorbet_type, to_sorbet_type
Constructor Details
#initialize(i_pv4_address: nil, i_pv6_address: nil, link_local_ips: nil) ⇒ Object
EndpointIPAMConfig represents an endpoint’s IPAM configuration.
|
|
# File 'lib/docker_engine_api/models/container.rb', line 2187
|
Instance Attribute Details
#networks ⇒ Hash{Symbol=>DockerEngineAPI::Models::Container::NetworkSettings::Network}?
Information about all networks that the container is connected to.
1979 1980 1981 1982 1983 |
# File 'lib/docker_engine_api/models/container.rb', line 1979 optional :networks, -> { DockerEngineAPI::Internal::Type::HashOf[DockerEngineAPI::Container::NetworkSettings::Network] }, api_name: :Networks |
#ports ⇒ Hash{Symbol=>Array<DockerEngineAPI::Models::Container::NetworkSettings::Port>}?
PortMap describes the mapping of container ports to host ports, using the container’s port-number and protocol as key in the format ‘<port>/<protocol>`, for example, 80/udp.
If a container’s port is mapped for multiple protocols, separate entries are added to the mapping table.
1994 1995 1996 1997 1998 |
# File 'lib/docker_engine_api/models/container.rb', line 1994 optional :ports, -> { DockerEngineAPI::Internal::Type::HashOf[DockerEngineAPI::Internal::Type::ArrayOf[DockerEngineAPI::Container::NetworkSettings::Port]] }, api_name: :Ports |
#sandbox_id ⇒ String?
SandboxID uniquely represents a container’s network stack.
2004 |
# File 'lib/docker_engine_api/models/container.rb', line 2004 optional :sandbox_id, String, api_name: :SandboxID |
#sandbox_key ⇒ String?
SandboxKey is the full path of the netns handle
2010 |
# File 'lib/docker_engine_api/models/container.rb', line 2010 optional :sandbox_key, String, api_name: :SandboxKey |