Class: DockerEngineAPI::Models::ContainerAttachParams
- Inherits:
-
Internal::Type::BaseModel
- Object
- Internal::Type::BaseModel
- DockerEngineAPI::Models::ContainerAttachParams
- Extended by:
- Internal::Type::RequestParameters::Converter
- Includes:
- Internal::Type::RequestParameters
- Defined in:
- lib/docker_engine_api/models/container_attach_params.rb
Overview
Instance Attribute Summary collapse
-
#detach_keys ⇒ String?
Override the key sequence for detaching a container.Format is a single character
[a-Z]or ‘ctrl-<value>` where `<value>` is one of:a-z, `@`, `^`,[, `,` or_.. -
#logs ⇒ Boolean?
Replay previous logs from the container.
-
#stderr ⇒ Boolean?
Attach to
stderr. -
#stdin ⇒ Boolean?
Attach to
stdin. -
#stdout ⇒ Boolean?
Attach to
stdout. -
#stream ⇒ Boolean?
Stream attached streams from the time the request was made onwards.
Attributes included from Internal::Type::RequestParameters
Instance Method Summary collapse
-
#initialize(detach_keys: nil, logs: nil, stderr: nil, stdin: nil, stdout: nil, stream: nil, request_options: {}) ⇒ Object
constructor
Some parameter documentations has been truncated, see ContainerAttachParams for more details.
Methods included from Internal::Type::RequestParameters::Converter
Methods included from Internal::Type::RequestParameters
Methods inherited from Internal::Type::BaseModel
==, #==, #[], coerce, #deconstruct_keys, #deep_to_h, dump, fields, hash, #hash, inherited, inspect, #inspect, known_fields, optional, recursively_to_h, required, #to_h, #to_json, #to_s, to_sorbet_type, #to_yaml
Methods included from Internal::Type::Converter
#coerce, coerce, #dump, dump, inspect, #inspect, meta_info, new_coerce_state, type_info
Methods included from Internal::Util::SorbetRuntimeSupport
#const_missing, #define_sorbet_constant!, #sorbet_constant_defined?, #to_sorbet_type, to_sorbet_type
Constructor Details
#initialize(detach_keys: nil, logs: nil, stderr: nil, stdin: nil, stdout: nil, stream: nil, request_options: {}) ⇒ Object
Some parameter documentations has been truncated, see DockerEngineAPI::Models::ContainerAttachParams for more details.
|
|
# File 'lib/docker_engine_api/models/container_attach_params.rb', line 54
|
Instance Attribute Details
#detach_keys ⇒ String?
Override the key sequence for detaching a container.Format is a single character [a-Z] or ‘ctrl-<value>` where `<value>` is one of: a-z, `@`, `^`, [, `,` or _.
16 |
# File 'lib/docker_engine_api/models/container_attach_params.rb', line 16 optional :detach_keys, String |
#logs ⇒ Boolean?
Replay previous logs from the container.
This is useful for attaching to a container that has started and you want to output everything since the container started.
If stream is also enabled, once all the previous output has been returned, it will seamlessly transition into streaming current output.
28 |
# File 'lib/docker_engine_api/models/container_attach_params.rb', line 28 optional :logs, DockerEngineAPI::Internal::Type::Boolean |
#stderr ⇒ Boolean?
Attach to stderr
34 |
# File 'lib/docker_engine_api/models/container_attach_params.rb', line 34 optional :stderr, DockerEngineAPI::Internal::Type::Boolean |
#stdin ⇒ Boolean?
Attach to stdin
40 |
# File 'lib/docker_engine_api/models/container_attach_params.rb', line 40 optional :stdin, DockerEngineAPI::Internal::Type::Boolean |
#stdout ⇒ Boolean?
Attach to stdout
46 |
# File 'lib/docker_engine_api/models/container_attach_params.rb', line 46 optional :stdout, DockerEngineAPI::Internal::Type::Boolean |
#stream ⇒ Boolean?
Stream attached streams from the time the request was made onwards.
52 |
# File 'lib/docker_engine_api/models/container_attach_params.rb', line 52 optional :stream, DockerEngineAPI::Internal::Type::Boolean |