Class: DockerEngineAPI::Models::ContainerCreateParams
- Inherits:
-
Internal::Type::BaseModel
- Object
- Internal::Type::BaseModel
- DockerEngineAPI::Models::ContainerCreateParams
- Extended by:
- Internal::Type::RequestParameters::Converter
- Includes:
- Internal::Type::RequestParameters
- Defined in:
- lib/docker_engine_api/models/container_create_params.rb
Overview
Defined Under Namespace
Classes: Config
Instance Attribute Summary collapse
-
#config ⇒ DockerEngineAPI::Models::ContainerCreateParams::Config
Configuration for a container that is portable between hosts.
-
#name ⇒ String?
Assign the specified name to the container.
-
#platform ⇒ String?
Platform in the format
os[/arch[/variant]]used for image lookup.
Attributes included from Internal::Type::RequestParameters
Method Summary
Methods included from Internal::Type::RequestParameters::Converter
Methods included from Internal::Type::RequestParameters
Methods inherited from Internal::Type::BaseModel
#==, ==, #[], coerce, #deconstruct_keys, #deep_to_h, dump, fields, hash, #hash, inherited, #initialize, inspect, #inspect, known_fields, optional, recursively_to_h, required, #to_h, #to_json, #to_s, to_sorbet_type, #to_yaml
Methods included from Internal::Type::Converter
#coerce, coerce, #dump, dump, inspect, #inspect, meta_info, new_coerce_state, type_info
Methods included from Internal::Util::SorbetRuntimeSupport
#const_missing, #define_sorbet_constant!, #sorbet_constant_defined?, #to_sorbet_type, to_sorbet_type
Constructor Details
This class inherits a constructor from DockerEngineAPI::Internal::Type::BaseModel
Instance Attribute Details
#config ⇒ DockerEngineAPI::Models::ContainerCreateParams::Config
Configuration for a container that is portable between hosts.
14 |
# File 'lib/docker_engine_api/models/container_create_params.rb', line 14 required :config, -> { DockerEngineAPI::ContainerCreateParams::Config } |
#name ⇒ String?
Assign the specified name to the container. Must match ‘/?[a-zA-Z0-9]+`.
21 |
# File 'lib/docker_engine_api/models/container_create_params.rb', line 21 optional :name, String |
#platform ⇒ String?
Platform in the format os[/arch[/variant]] used for image lookup.
When specified, the daemon checks if the requested image is present in the local image cache with the given OS and Architecture, and otherwise returns a 404 status.
If the option is not set, the host’s native OS and Architecture are used to look up the image in the image cache. However, if no platform is passed and the given image does exist in the local image cache, but its OS or architecture does not match, the container is created with the available image, and a warning is added to the Warnings field in the response, for example;
WARNING: The requested image's platform (linux/arm64/v8) does not
match the detected host platform (linux/amd64) and no
specific platform was requested
41 |
# File 'lib/docker_engine_api/models/container_create_params.rb', line 41 optional :platform, String |