Class: DockerEngineAPI::Models::ContainerExecParams
- Inherits:
-
Internal::Type::BaseModel
- Object
- Internal::Type::BaseModel
- DockerEngineAPI::Models::ContainerExecParams
- Extended by:
- Internal::Type::RequestParameters::Converter
- Includes:
- Internal::Type::RequestParameters
- Defined in:
- lib/docker_engine_api/models/container_exec_params.rb
Overview
Instance Attribute Summary collapse
-
#attach_stderr ⇒ Boolean?
Attach to
stderrof the exec command. -
#attach_stdin ⇒ Boolean?
Attach to
stdinof the exec command. -
#attach_stdout ⇒ Boolean?
Attach to
stdoutof the exec command. -
#cmd ⇒ Array<String>?
Command to run, as a string or array of strings.
-
#console_size ⇒ Array<Integer>?
Initial console size, as an ‘[height, width]` array.
-
#detach_keys ⇒ String?
Override the key sequence for detaching a container.
-
#env ⇒ Array<String>?
A list of environment variables in the form ‘[“VAR=value”, …]`.
-
#privileged ⇒ Boolean?
Runs the exec process with extended privileges.
-
#tty ⇒ Boolean?
Allocate a pseudo-TTY.
-
#user ⇒ String?
The user, and optionally, group to run the exec process inside the container.
-
#working_dir ⇒ String?
The working directory for the exec process inside the container.
Attributes included from Internal::Type::RequestParameters
Instance Method Summary collapse
-
#initialize(attach_stderr: nil, attach_stdin: nil, attach_stdout: nil, cmd: nil, console_size: nil, detach_keys: nil, env: nil, privileged: nil, tty: nil, user: nil, working_dir: nil, request_options: {}) ⇒ Object
constructor
Some parameter documentations has been truncated, see ContainerExecParams for more details.
Methods included from Internal::Type::RequestParameters::Converter
Methods included from Internal::Type::RequestParameters
Methods inherited from Internal::Type::BaseModel
==, #==, #[], coerce, #deconstruct_keys, #deep_to_h, dump, fields, hash, #hash, inherited, inspect, #inspect, known_fields, optional, recursively_to_h, required, #to_h, #to_json, #to_s, to_sorbet_type, #to_yaml
Methods included from Internal::Type::Converter
#coerce, coerce, #dump, dump, inspect, #inspect, meta_info, new_coerce_state, type_info
Methods included from Internal::Util::SorbetRuntimeSupport
#const_missing, #define_sorbet_constant!, #sorbet_constant_defined?, #to_sorbet_type, to_sorbet_type
Constructor Details
#initialize(attach_stderr: nil, attach_stdin: nil, attach_stdout: nil, cmd: nil, console_size: nil, detach_keys: nil, env: nil, privileged: nil, tty: nil, user: nil, working_dir: nil, request_options: {}) ⇒ Object
Some parameter documentations has been truncated, see DockerEngineAPI::Models::ContainerExecParams for more details.
|
|
# File 'lib/docker_engine_api/models/container_exec_params.rb', line 82
|
Instance Attribute Details
#attach_stderr ⇒ Boolean?
Attach to stderr of the exec command.
14 |
# File 'lib/docker_engine_api/models/container_exec_params.rb', line 14 optional :attach_stderr, DockerEngineAPI::Internal::Type::Boolean, api_name: :AttachStderr |
#attach_stdin ⇒ Boolean?
Attach to stdin of the exec command.
20 |
# File 'lib/docker_engine_api/models/container_exec_params.rb', line 20 optional :attach_stdin, DockerEngineAPI::Internal::Type::Boolean, api_name: :AttachStdin |
#attach_stdout ⇒ Boolean?
Attach to stdout of the exec command.
26 |
# File 'lib/docker_engine_api/models/container_exec_params.rb', line 26 optional :attach_stdout, DockerEngineAPI::Internal::Type::Boolean, api_name: :AttachStdout |
#cmd ⇒ Array<String>?
Command to run, as a string or array of strings.
32 |
# File 'lib/docker_engine_api/models/container_exec_params.rb', line 32 optional :cmd, DockerEngineAPI::Internal::Type::ArrayOf[String], api_name: :Cmd |
#console_size ⇒ Array<Integer>?
Initial console size, as an ‘[height, width]` array.
38 39 40 41 |
# File 'lib/docker_engine_api/models/container_exec_params.rb', line 38 optional :console_size, DockerEngineAPI::Internal::Type::ArrayOf[Integer], api_name: :ConsoleSize, nil?: true |
#detach_keys ⇒ String?
Override the key sequence for detaching a container. Format is a single character [a-Z] or ‘ctrl-<value>` where `<value>` is one of: a-z, `@`, `^`, [, `,` or _.
49 |
# File 'lib/docker_engine_api/models/container_exec_params.rb', line 49 optional :detach_keys, String, api_name: :DetachKeys |
#env ⇒ Array<String>?
A list of environment variables in the form ‘[“VAR=value”, …]`.
55 |
# File 'lib/docker_engine_api/models/container_exec_params.rb', line 55 optional :env, DockerEngineAPI::Internal::Type::ArrayOf[String], api_name: :Env |
#privileged ⇒ Boolean?
Runs the exec process with extended privileges.
61 |
# File 'lib/docker_engine_api/models/container_exec_params.rb', line 61 optional :privileged, DockerEngineAPI::Internal::Type::Boolean, api_name: :Privileged |
#tty ⇒ Boolean?
Allocate a pseudo-TTY.
67 |
# File 'lib/docker_engine_api/models/container_exec_params.rb', line 67 optional :tty, DockerEngineAPI::Internal::Type::Boolean, api_name: :Tty |
#user ⇒ String?
The user, and optionally, group to run the exec process inside the container. Format is one of: user, user:group, uid, or uid:gid.
74 |
# File 'lib/docker_engine_api/models/container_exec_params.rb', line 74 optional :user, String, api_name: :User |
#working_dir ⇒ String?
The working directory for the exec process inside the container.
80 |
# File 'lib/docker_engine_api/models/container_exec_params.rb', line 80 optional :working_dir, String, api_name: :WorkingDir |