Class: DockerEngineAPI::Models::Image::Manifest::Size
- Inherits:
-
Internal::Type::BaseModel
- Object
- Internal::Type::BaseModel
- DockerEngineAPI::Models::Image::Manifest::Size
- Defined in:
- lib/docker_engine_api/models/image.rb
Overview
Instance Attribute Summary collapse
-
#content ⇒ Integer
Content is the size (in bytes) of all the locally present content in the content store (e.g. image config, layers) referenced by this manifest and its children.
-
#total ⇒ Integer
Total is the total size (in bytes) of all the locally present data (both distributable and non-distributable) that’s related to this manifest and its children.
Method Summary
Methods inherited from Internal::Type::BaseModel
#==, ==, #[], coerce, #deconstruct_keys, #deep_to_h, dump, fields, hash, #hash, inherited, #initialize, inspect, #inspect, known_fields, optional, recursively_to_h, required, #to_h, #to_json, #to_s, to_sorbet_type, #to_yaml
Methods included from Internal::Type::Converter
#coerce, coerce, #dump, dump, inspect, #inspect, meta_info, new_coerce_state, type_info
Methods included from Internal::Util::SorbetRuntimeSupport
#const_missing, #define_sorbet_constant!, #sorbet_constant_defined?, #to_sorbet_type, to_sorbet_type
Constructor Details
This class inherits a constructor from DockerEngineAPI::Internal::Type::BaseModel
Instance Attribute Details
#content ⇒ Integer
Content is the size (in bytes) of all the locally present content in the content store (e.g. image config, layers) referenced by this manifest and its children. This only includes blobs in the content store.
1200 |
# File 'lib/docker_engine_api/models/image.rb', line 1200 required :content, Integer, api_name: :Content |
#total ⇒ Integer
Total is the total size (in bytes) of all the locally present data (both distributable and non-distributable) that’s related to this manifest and its children. This equal to the sum of [Content] size AND all the sizes in the
- Size
-
struct present in the Kind-specific data struct. For example, for an
image kind (Kind == “image”) this would include the size of the image content and unpacked image snapshots ([Size.Content] + [ImageData.Size.Unpacked]).
1211 |
# File 'lib/docker_engine_api/models/image.rb', line 1211 required :total, Integer, api_name: :Total |