Class: DockerEngineAPI::Models::ImageBuildPruneParams
- Inherits:
-
Internal::Type::BaseModel
- Object
- Internal::Type::BaseModel
- DockerEngineAPI::Models::ImageBuildPruneParams
- Extended by:
- Internal::Type::RequestParameters::Converter
- Includes:
- Internal::Type::RequestParameters
- Defined in:
- lib/docker_engine_api/models/image_build_prune_params.rb
Overview
Instance Attribute Summary collapse
-
#all ⇒ Boolean?
Remove all types of build cache.
-
#filters ⇒ String?
A JSON encoded value of the filters (a
map[string][]string) to process on the list of build cache objects. -
#max_used_space ⇒ Integer?
Maximum amount of disk space allowed to keep for cache.
-
#min_free_space ⇒ Integer?
Target amount of free disk space after pruning.
-
#reserved_space ⇒ Integer?
Amount of disk space in bytes to keep for cache.
Attributes included from Internal::Type::RequestParameters
Instance Method Summary collapse
-
#initialize(all: nil, filters: nil, max_used_space: nil, min_free_space: nil, reserved_space: nil, request_options: {}) ⇒ Object
constructor
Some parameter documentations has been truncated, see ImageBuildPruneParams for more details.
Methods included from Internal::Type::RequestParameters::Converter
Methods included from Internal::Type::RequestParameters
Methods inherited from Internal::Type::BaseModel
==, #==, #[], coerce, #deconstruct_keys, #deep_to_h, dump, fields, hash, #hash, inherited, inspect, #inspect, known_fields, optional, recursively_to_h, required, #to_h, #to_json, #to_s, to_sorbet_type, #to_yaml
Methods included from Internal::Type::Converter
#coerce, coerce, #dump, dump, inspect, #inspect, meta_info, new_coerce_state, type_info
Methods included from Internal::Util::SorbetRuntimeSupport
#const_missing, #define_sorbet_constant!, #sorbet_constant_defined?, #to_sorbet_type, to_sorbet_type
Constructor Details
#initialize(all: nil, filters: nil, max_used_space: nil, min_free_space: nil, reserved_space: nil, request_options: {}) ⇒ Object
Some parameter documentations has been truncated, see DockerEngineAPI::Models::ImageBuildPruneParams for more details.
|
|
# File 'lib/docker_engine_api/models/image_build_prune_params.rb', line 54
|
Instance Attribute Details
#all ⇒ Boolean?
Remove all types of build cache
14 |
# File 'lib/docker_engine_api/models/image_build_prune_params.rb', line 14 optional :all, DockerEngineAPI::Internal::Type::Boolean |
#filters ⇒ String?
A JSON encoded value of the filters (a map[string][]string) to process on the list of build cache objects.
Available filters:
-
‘until=<timestamp>` remove cache older than `<timestamp>`. The `<timestamp>` can be Unix timestamps, date formatted timestamps, or Go duration strings (e.g.
10m,1h30m) computed relative to the daemon’s local time. -
‘id=<id>`
-
‘parent=<id>`
-
‘type=<string>`
-
‘description=<string>`
-
inuse -
shared -
private
34 |
# File 'lib/docker_engine_api/models/image_build_prune_params.rb', line 34 optional :filters, String |
#max_used_space ⇒ Integer?
Maximum amount of disk space allowed to keep for cache
40 |
# File 'lib/docker_engine_api/models/image_build_prune_params.rb', line 40 optional :max_used_space, Integer |
#min_free_space ⇒ Integer?
Target amount of free disk space after pruning
46 |
# File 'lib/docker_engine_api/models/image_build_prune_params.rb', line 46 optional :min_free_space, Integer |
#reserved_space ⇒ Integer?
Amount of disk space in bytes to keep for cache
52 |
# File 'lib/docker_engine_api/models/image_build_prune_params.rb', line 52 optional :reserved_space, Integer |