Class: DockerEngineAPI::Models::ImageHistoryParams
- Inherits:
-
Internal::Type::BaseModel
- Object
- Internal::Type::BaseModel
- DockerEngineAPI::Models::ImageHistoryParams
- Extended by:
- Internal::Type::RequestParameters::Converter
- Includes:
- Internal::Type::RequestParameters
- Defined in:
- lib/docker_engine_api/models/image_history_params.rb
Overview
Instance Attribute Summary collapse
-
#platform ⇒ String?
JSON-encoded OCI platform to select the platform-variant.
Attributes included from Internal::Type::RequestParameters
Instance Method Summary collapse
-
#initialize(platform: nil, request_options: {}) ⇒ Object
constructor
Some parameter documentations has been truncated, see ImageHistoryParams for more details.
Methods included from Internal::Type::RequestParameters::Converter
Methods included from Internal::Type::RequestParameters
Methods inherited from Internal::Type::BaseModel
==, #==, #[], coerce, #deconstruct_keys, #deep_to_h, dump, fields, hash, #hash, inherited, inspect, #inspect, known_fields, optional, recursively_to_h, required, #to_h, #to_json, #to_s, to_sorbet_type, #to_yaml
Methods included from Internal::Type::Converter
#coerce, coerce, #dump, dump, inspect, #inspect, meta_info, new_coerce_state, type_info
Methods included from Internal::Util::SorbetRuntimeSupport
#const_missing, #define_sorbet_constant!, #sorbet_constant_defined?, #to_sorbet_type, to_sorbet_type
Constructor Details
#initialize(platform: nil, request_options: {}) ⇒ Object
Some parameter documentations has been truncated, see DockerEngineAPI::Models::ImageHistoryParams for more details.
|
|
# File 'lib/docker_engine_api/models/image_history_params.rb', line 25
|
Instance Attribute Details
#platform ⇒ String?
JSON-encoded OCI platform to select the platform-variant. If omitted, it defaults to any locally available platform, prioritizing the daemon’s host platform.
If the daemon provides a multi-platform image store, this selects the platform-variant to show the history for. If the image is a single-platform image, or if the multi-platform image does not provide a variant matching the given platform, an error is returned.
Example: ‘“linux”, “architecture”: “arm”, “variant”: “v5”`
23 |
# File 'lib/docker_engine_api/models/image_history_params.rb', line 23 optional :platform, String |