Class: DockerEngineAPI::Models::ImagePullParams
- Inherits:
-
Internal::Type::BaseModel
- Object
- Internal::Type::BaseModel
- DockerEngineAPI::Models::ImagePullParams
- Extended by:
- Internal::Type::RequestParameters::Converter
- Includes:
- Internal::Type::RequestParameters
- Defined in:
- lib/docker_engine_api/models/image_pull_params.rb
Overview
Instance Attribute Summary collapse
- #body ⇒ String?
-
#changes ⇒ Array<String>?
Apply
Dockerfileinstructions to the image that is created, for example: ‘changes=ENV DEBUG=true`. -
#from_image ⇒ String?
Name of the image to pull.
-
#from_src ⇒ String?
Source to import.
-
#message ⇒ String?
Set commit message for imported image.
-
#platform ⇒ String?
Platform in the format os[/arch].
-
#repo ⇒ String?
Repository name given to an image when it is imported.
-
#tag ⇒ String?
Tag or digest.
- #x_registry_auth ⇒ String?
Attributes included from Internal::Type::RequestParameters
Instance Method Summary collapse
-
#initialize(changes: nil, from_image: nil, from_src: nil, message: nil, platform: nil, repo: nil, tag: nil, body: nil, x_registry_auth: nil, request_options: {}) ⇒ Object
constructor
Some parameter documentations has been truncated, see ImagePullParams for more details.
Methods included from Internal::Type::RequestParameters::Converter
Methods included from Internal::Type::RequestParameters
Methods inherited from Internal::Type::BaseModel
==, #==, #[], coerce, #deconstruct_keys, #deep_to_h, dump, fields, hash, #hash, inherited, inspect, #inspect, known_fields, optional, recursively_to_h, required, #to_h, #to_json, #to_s, to_sorbet_type, #to_yaml
Methods included from Internal::Type::Converter
#coerce, coerce, #dump, dump, inspect, #inspect, meta_info, new_coerce_state, type_info
Methods included from Internal::Util::SorbetRuntimeSupport
#const_missing, #define_sorbet_constant!, #sorbet_constant_defined?, #to_sorbet_type, to_sorbet_type
Constructor Details
#initialize(changes: nil, from_image: nil, from_src: nil, message: nil, platform: nil, repo: nil, tag: nil, body: nil, x_registry_auth: nil, request_options: {}) ⇒ Object
Some parameter documentations has been truncated, see DockerEngineAPI::Models::ImagePullParams for more details.
|
|
# File 'lib/docker_engine_api/models/image_pull_params.rb', line 90
|
Instance Attribute Details
#body ⇒ String?
83 |
# File 'lib/docker_engine_api/models/image_pull_params.rb', line 83 optional :body, String |
#changes ⇒ Array<String>?
Apply Dockerfile instructions to the image that is created, for example: ‘changes=ENV DEBUG=true`. Note that `ENV DEBUG=true` should be URI component encoded.
Supported Dockerfile instructions: CMD|ENTRYPOINT|ENV|EXPOSE|ONBUILD|USER|VOLUME|WORKDIR
19 |
# File 'lib/docker_engine_api/models/image_pull_params.rb', line 19 optional :changes, DockerEngineAPI::Internal::Type::ArrayOf[String] |
#from_image ⇒ String?
Name of the image to pull. If the name includes a tag or digest, specific behavior applies:
-
If only
fromImageincludes a tag, that tag is used. -
If both
fromImageandtagare provided,tagtakes precedence. -
If
fromImageincludes a digest, the image is pulled by digest, andtagis ignored. -
If neither a tag nor digest is specified, all tags are pulled.
32 |
# File 'lib/docker_engine_api/models/image_pull_params.rb', line 32 optional :from_image, String |
#from_src ⇒ String?
Source to import. The value may be a URL from which the image can be retrieved or - to read the image from the request body. This parameter may only be used when importing an image.
40 |
# File 'lib/docker_engine_api/models/image_pull_params.rb', line 40 optional :from_src, String |
#message ⇒ String?
Set commit message for imported image.
46 |
# File 'lib/docker_engine_api/models/image_pull_params.rb', line 46 optional :message, String |
#platform ⇒ String?
Platform in the format os[/arch].
When used in combination with the fromImage option, the daemon checks if the given image is present in the local image cache with the given OS and Architecture, and otherwise attempts to pull the image. If the option is not set, the host’s native OS and Architecture are used. If the given image does not exist in the local image cache, the daemon attempts to pull the image with the host’s native OS and Architecture. If the given image does exists in the local image cache, but its OS or architecture does not match, a warning is produced.
When used with the fromSrc option to import an image from an archive, this option sets the platform information for the imported image. If the option is not set, the host’s native OS and Architecture are used for the imported image.
64 |
# File 'lib/docker_engine_api/models/image_pull_params.rb', line 64 optional :platform, String |
#repo ⇒ String?
Repository name given to an image when it is imported. The repo may include a tag. This parameter may only be used when importing an image.
71 |
# File 'lib/docker_engine_api/models/image_pull_params.rb', line 71 optional :repo, String |
#tag ⇒ String?
Tag or digest. If empty when pulling an image, this causes all tags for the given image to be pulled.
78 |
# File 'lib/docker_engine_api/models/image_pull_params.rb', line 78 optional :tag, String |
#x_registry_auth ⇒ String?
88 |
# File 'lib/docker_engine_api/models/image_pull_params.rb', line 88 optional :x_registry_auth, String |