Class: DockerEngineAPI::Models::ImagePushParams
- Inherits:
-
Internal::Type::BaseModel
- Object
- Internal::Type::BaseModel
- DockerEngineAPI::Models::ImagePushParams
- Extended by:
- Internal::Type::RequestParameters::Converter
- Includes:
- Internal::Type::RequestParameters
- Defined in:
- lib/docker_engine_api/models/image_push_params.rb
Overview
Instance Attribute Summary collapse
-
#platform ⇒ String?
JSON-encoded OCI platform to select the platform-variant to push.
-
#tag ⇒ String?
Tag of the image to push.
- #x_registry_auth ⇒ String
Attributes included from Internal::Type::RequestParameters
Instance Method Summary collapse
-
#initialize(x_registry_auth:, platform: nil, tag: nil, request_options: {}) ⇒ Object
constructor
Some parameter documentations has been truncated, see ImagePushParams for more details.
Methods included from Internal::Type::RequestParameters::Converter
Methods included from Internal::Type::RequestParameters
Methods inherited from Internal::Type::BaseModel
==, #==, #[], coerce, #deconstruct_keys, #deep_to_h, dump, fields, hash, #hash, inherited, inspect, #inspect, known_fields, optional, recursively_to_h, required, #to_h, #to_json, #to_s, to_sorbet_type, #to_yaml
Methods included from Internal::Type::Converter
#coerce, coerce, #dump, dump, inspect, #inspect, meta_info, new_coerce_state, type_info
Methods included from Internal::Util::SorbetRuntimeSupport
#const_missing, #define_sorbet_constant!, #sorbet_constant_defined?, #to_sorbet_type, to_sorbet_type
Constructor Details
#initialize(x_registry_auth:, platform: nil, tag: nil, request_options: {}) ⇒ Object
Some parameter documentations has been truncated, see DockerEngineAPI::Models::ImagePushParams for more details.
|
|
# File 'lib/docker_engine_api/models/image_push_params.rb', line 36
|
Instance Attribute Details
#platform ⇒ String?
JSON-encoded OCI platform to select the platform-variant to push. If not provided, all available variants will attempt to be pushed.
If the daemon provides a multi-platform image store, this selects the platform-variant to push to the registry. If the image is a single-platform image, or if the multi-platform image does not provide a variant matching the given platform, an error is returned.
Example: ‘“linux”, “architecture”: “arm”, “variant”: “v5”`
27 |
# File 'lib/docker_engine_api/models/image_push_params.rb', line 27 optional :platform, String |
#tag ⇒ String?
Tag of the image to push. For example, latest. If no tag is provided, all tags of the given image that are present in the local image store are pushed.
34 |
# File 'lib/docker_engine_api/models/image_push_params.rb', line 34 optional :tag, String |
#x_registry_auth ⇒ String
13 |
# File 'lib/docker_engine_api/models/image_push_params.rb', line 13 required :x_registry_auth, String |