Class: DockerEngineAPI::Models::NetworkCreateParams
- Inherits:
-
Internal::Type::BaseModel
- Object
- Internal::Type::BaseModel
- DockerEngineAPI::Models::NetworkCreateParams
- Extended by:
- Internal::Type::RequestParameters::Converter
- Includes:
- Internal::Type::RequestParameters
- Defined in:
- lib/docker_engine_api/models/network_create_params.rb
Overview
Defined Under Namespace
Classes: ConfigFrom, Ipam
Instance Attribute Summary collapse
-
#attachable ⇒ Boolean?
Globally scoped network is manually attachable by regular containers from workers in swarm mode.
-
#config_from ⇒ DockerEngineAPI::Models::NetworkCreateParams::ConfigFrom?
The config-only network source to provide the configuration for this network.
-
#config_only ⇒ Boolean?
Creates a config-only network.
-
#driver ⇒ String?
Name of the network driver plugin to use.
-
#enable_i_pv4 ⇒ Boolean?
Enable IPv4 on the network.
-
#enable_i_pv6 ⇒ Boolean?
Enable IPv6 on the network.
-
#ingress ⇒ Boolean?
Ingress network is the network which provides the routing-mesh in swarm mode.
-
#internal ⇒ Boolean?
Restrict external access to the network.
- #ipam ⇒ DockerEngineAPI::Models::NetworkCreateParams::Ipam?
-
#labels ⇒ Hash{Symbol=>String}?
User-defined key/value metadata.
-
#name ⇒ String
The network’s name.
-
#options ⇒ Hash{Symbol=>String}?
Network specific options to be used by the drivers.
-
#scope ⇒ String?
The level at which the network exists (e.g.
swarmfor cluster-wide orlocalfor machine level).
Attributes included from Internal::Type::RequestParameters
Instance Method Summary collapse
-
#initialize(network: nil) ⇒ Object
constructor
Some parameter documentations has been truncated, see ConfigFrom for more details.
Methods included from Internal::Type::RequestParameters::Converter
Methods included from Internal::Type::RequestParameters
Methods inherited from Internal::Type::BaseModel
==, #==, #[], coerce, #deconstruct_keys, #deep_to_h, dump, fields, hash, #hash, inherited, inspect, #inspect, known_fields, optional, recursively_to_h, required, #to_h, #to_json, #to_s, to_sorbet_type, #to_yaml
Methods included from Internal::Type::Converter
#coerce, coerce, #dump, dump, inspect, #inspect, meta_info, new_coerce_state, type_info
Methods included from Internal::Util::SorbetRuntimeSupport
#const_missing, #define_sorbet_constant!, #sorbet_constant_defined?, #to_sorbet_type, to_sorbet_type
Constructor Details
#initialize(network: nil) ⇒ Object
Some parameter documentations has been truncated, see ConfigFrom for more details.
The config-only network source to provide the configuration for this network.
|
|
# File 'lib/docker_engine_api/models/network_create_params.rb', line 132
|
Instance Attribute Details
#attachable ⇒ Boolean?
Globally scoped network is manually attachable by regular containers from workers in swarm mode.
21 |
# File 'lib/docker_engine_api/models/network_create_params.rb', line 21 optional :attachable, DockerEngineAPI::Internal::Type::Boolean, api_name: :Attachable |
#config_from ⇒ DockerEngineAPI::Models::NetworkCreateParams::ConfigFrom?
The config-only network source to provide the configuration for this network.
27 |
# File 'lib/docker_engine_api/models/network_create_params.rb', line 27 optional :config_from, -> { DockerEngineAPI::NetworkCreateParams::ConfigFrom }, api_name: :ConfigFrom |
#config_only ⇒ Boolean?
Creates a config-only network. Config-only networks are placeholder networks for network configurations to be used by other networks. Config-only networks cannot be used directly to run containers or services.
35 |
# File 'lib/docker_engine_api/models/network_create_params.rb', line 35 optional :config_only, DockerEngineAPI::Internal::Type::Boolean, api_name: :ConfigOnly |
#driver ⇒ String?
Name of the network driver plugin to use.
41 |
# File 'lib/docker_engine_api/models/network_create_params.rb', line 41 optional :driver, String, api_name: :Driver |
#enable_i_pv4 ⇒ Boolean?
Enable IPv4 on the network.
47 |
# File 'lib/docker_engine_api/models/network_create_params.rb', line 47 optional :enable_i_pv4, DockerEngineAPI::Internal::Type::Boolean, api_name: :EnableIPv4 |
#enable_i_pv6 ⇒ Boolean?
Enable IPv6 on the network.
53 |
# File 'lib/docker_engine_api/models/network_create_params.rb', line 53 optional :enable_i_pv6, DockerEngineAPI::Internal::Type::Boolean, api_name: :EnableIPv6 |
#ingress ⇒ Boolean?
Ingress network is the network which provides the routing-mesh in swarm mode.
59 |
# File 'lib/docker_engine_api/models/network_create_params.rb', line 59 optional :ingress, DockerEngineAPI::Internal::Type::Boolean, api_name: :Ingress |
#internal ⇒ Boolean?
Restrict external access to the network.
65 |
# File 'lib/docker_engine_api/models/network_create_params.rb', line 65 optional :internal, DockerEngineAPI::Internal::Type::Boolean, api_name: :Internal |
#ipam ⇒ DockerEngineAPI::Models::NetworkCreateParams::Ipam?
70 |
# File 'lib/docker_engine_api/models/network_create_params.rb', line 70 optional :ipam, -> { DockerEngineAPI::NetworkCreateParams::Ipam }, api_name: :IPAM |
#labels ⇒ Hash{Symbol=>String}?
User-defined key/value metadata.
76 |
# File 'lib/docker_engine_api/models/network_create_params.rb', line 76 optional :labels, DockerEngineAPI::Internal::Type::HashOf[String], api_name: :Labels |
#name ⇒ String
The network’s name.
14 |
# File 'lib/docker_engine_api/models/network_create_params.rb', line 14 required :name, String, api_name: :Name |
#options ⇒ Hash{Symbol=>String}?
Network specific options to be used by the drivers.
82 |
# File 'lib/docker_engine_api/models/network_create_params.rb', line 82 optional :options, DockerEngineAPI::Internal::Type::HashOf[String], api_name: :Options |
#scope ⇒ String?
The level at which the network exists (e.g. swarm for cluster-wide or local for machine level).
89 |
# File 'lib/docker_engine_api/models/network_create_params.rb', line 89 optional :scope, String, api_name: :Scope |