Class: DockerEngineAPI::Models::NetworkInspectResponse
- Inherits:
-
Network
- Object
- Internal::Type::BaseModel
- Network
- DockerEngineAPI::Models::NetworkInspectResponse
- Defined in:
- lib/docker_engine_api/models/network_inspect_response.rb
Overview
Defined Under Namespace
Instance Attribute Summary collapse
-
#containers ⇒ Hash{Symbol=>DockerEngineAPI::Models::NetworkInspectResponse::Container}?
Contains endpoints attached to the network.
-
#services ⇒ Hash{Symbol=>Object}?
List of services using the network.
-
#status ⇒ DockerEngineAPI::Models::NetworkInspectResponse::Status?
provides runtime information about the network such as the number of allocated IPs.
Attributes inherited from Network
#attachable, #config_from, #config_only, #created, #driver, #enable_i_pv4, #enable_i_pv6, #id, #ingress, #internal, #ipam, #labels, #name, #options, #peers, #scope
Instance Method Summary collapse
-
#initialize(endpoint_id: nil, i_pv4_address: nil, i_pv6_address: nil, mac_address: nil, name: nil) ⇒ Object
constructor
contains network resources allocated and used for a container in a network.
Methods inherited from Internal::Type::BaseModel
==, #==, #[], coerce, #deconstruct_keys, #deep_to_h, dump, fields, hash, #hash, inherited, inspect, #inspect, known_fields, optional, recursively_to_h, required, #to_h, #to_json, #to_s, to_sorbet_type, #to_yaml
Methods included from Internal::Type::Converter
#coerce, coerce, #dump, dump, inspect, #inspect, meta_info, new_coerce_state, type_info
Methods included from Internal::Util::SorbetRuntimeSupport
#const_missing, #define_sorbet_constant!, #sorbet_constant_defined?, #to_sorbet_type, to_sorbet_type
Constructor Details
#initialize(endpoint_id: nil, i_pv4_address: nil, i_pv6_address: nil, mac_address: nil, name: nil) ⇒ Object
contains network resources allocated and used for a container in a network.
|
|
# File 'lib/docker_engine_api/models/network_inspect_response.rb', line 69
|
Instance Attribute Details
#containers ⇒ Hash{Symbol=>DockerEngineAPI::Models::NetworkInspectResponse::Container}?
Contains endpoints attached to the network.
11 12 13 |
# File 'lib/docker_engine_api/models/network_inspect_response.rb', line 11 optional :containers, -> { DockerEngineAPI::Internal::Type::HashOf[DockerEngineAPI::Models::NetworkInspectResponse::Container] }, api_name: :Containers |
#services ⇒ Hash{Symbol=>Object}?
List of services using the network. This field is only present for swarm scope networks, and omitted for local scope networks.
20 21 22 |
# File 'lib/docker_engine_api/models/network_inspect_response.rb', line 20 optional :services, DockerEngineAPI::Internal::Type::HashOf[DockerEngineAPI::Internal::Type::Unknown], api_name: :Services |
#status ⇒ DockerEngineAPI::Models::NetworkInspectResponse::Status?
provides runtime information about the network such as the number of allocated IPs.
29 |
# File 'lib/docker_engine_api/models/network_inspect_response.rb', line 29 optional :status, -> { DockerEngineAPI::Models::NetworkInspectResponse::Status }, api_name: :Status |