Class: DockerEngineAPI::Models::NetworkInspectResponse::Status::Ipam::Subnet
- Inherits:
-
Internal::Type::BaseModel
- Object
- Internal::Type::BaseModel
- DockerEngineAPI::Models::NetworkInspectResponse::Status::Ipam::Subnet
- Defined in:
- lib/docker_engine_api/models/network_inspect_response.rb
Instance Attribute Summary collapse
-
#dynamic_ips_available ⇒ Integer?
Number of IP addresses within the network’s IPRange for the subnet that are available for allocation, saturating at 2<sup>64</sup> - 1.
-
#ips_in_use ⇒ Integer?
Number of IP addresses in the subnet that are in use or reserved and are therefore unavailable for allocation, saturating at 2<sup>64</sup> - 1.
Instance Method Summary collapse
-
#initialize(dynamic_ips_available: nil, ips_in_use: nil) ⇒ Object
constructor
Some parameter documentations has been truncated, see Subnet for more details.
Methods inherited from Internal::Type::BaseModel
==, #==, #[], coerce, #deconstruct_keys, #deep_to_h, dump, fields, hash, #hash, inherited, inspect, #inspect, known_fields, optional, recursively_to_h, required, #to_h, #to_json, #to_s, to_sorbet_type, #to_yaml
Methods included from Internal::Type::Converter
#coerce, coerce, #dump, dump, inspect, #inspect, meta_info, new_coerce_state, type_info
Methods included from Internal::Util::SorbetRuntimeSupport
#const_missing, #define_sorbet_constant!, #sorbet_constant_defined?, #to_sorbet_type, to_sorbet_type
Constructor Details
#initialize(dynamic_ips_available: nil, ips_in_use: nil) ⇒ Object
Some parameter documentations has been truncated, see DockerEngineAPI::Models::NetworkInspectResponse::Status::Ipam::Subnet for more details.
103 104 105 106 107 108 109 110 111 112 113 114 115 116 117 118 119 120 121 122 123 124 125 126 |
# File 'lib/docker_engine_api/models/network_inspect_response.rb', line 103 class Subnet < DockerEngineAPI::Internal::Type::BaseModel # @!attribute dynamic_ips_available # Number of IP addresses within the network's IPRange for the subnet that are # available for allocation, saturating at 2<sup>64</sup> - 1. # # @return [Integer, nil] optional :dynamic_ips_available, Integer, api_name: :DynamicIPsAvailable # @!attribute ips_in_use # Number of IP addresses in the subnet that are in use or reserved and are # therefore unavailable for allocation, saturating at 2<sup>64</sup> - 1. # # @return [Integer, nil] optional :ips_in_use, Integer, api_name: :IPsInUse # @!method initialize(dynamic_ips_available: nil, ips_in_use: nil) # Some parameter documentations has been truncated, see # {DockerEngineAPI::Models::NetworkInspectResponse::Status::Ipam::Subnet} for more # details. # # @param dynamic_ips_available [Integer] Number of IP addresses within the network's IPRange for the subnet that are avai # # @param ips_in_use [Integer] Number of IP addresses in the subnet that are in use or reserved and are therefo end |
Instance Attribute Details
#dynamic_ips_available ⇒ Integer?
Number of IP addresses within the network’s IPRange for the subnet that are available for allocation, saturating at 2<sup>64</sup> - 1.
109 |
# File 'lib/docker_engine_api/models/network_inspect_response.rb', line 109 optional :dynamic_ips_available, Integer, api_name: :DynamicIPsAvailable |
#ips_in_use ⇒ Integer?
Number of IP addresses in the subnet that are in use or reserved and are therefore unavailable for allocation, saturating at 2<sup>64</sup> - 1.
116 |
# File 'lib/docker_engine_api/models/network_inspect_response.rb', line 116 optional :ips_in_use, Integer, api_name: :IPsInUse |