Class: DockerEngineAPI::Models::NetworkListParams

Inherits:
Internal::Type::BaseModel show all
Extended by:
Internal::Type::RequestParameters::Converter
Includes:
Internal::Type::RequestParameters
Defined in:
lib/docker_engine_api/models/network_list_params.rb

Overview

Instance Attribute Summary collapse

Attributes included from Internal::Type::RequestParameters

#request_options

Instance Method Summary collapse

Methods included from Internal::Type::RequestParameters::Converter

dump_request

Methods included from Internal::Type::RequestParameters

included

Methods inherited from Internal::Type::BaseModel

==, #==, #[], coerce, #deconstruct_keys, #deep_to_h, dump, fields, hash, #hash, inherited, inspect, #inspect, known_fields, optional, recursively_to_h, required, #to_h, #to_json, #to_s, to_sorbet_type, #to_yaml

Methods included from Internal::Type::Converter

#coerce, coerce, #dump, dump, inspect, #inspect, meta_info, new_coerce_state, type_info

Methods included from Internal::Util::SorbetRuntimeSupport

#const_missing, #define_sorbet_constant!, #sorbet_constant_defined?, #to_sorbet_type, to_sorbet_type

Constructor Details

#initialize(filters: nil, request_options: {}) ⇒ Object

Some parameter documentations has been truncated, see DockerEngineAPI::Models::NetworkListParams for more details.

Parameters:

  • filters (String) (defaults to: nil)

    JSON encoded value of the filters (a map[string][]string) to process

  • request_options (DockerEngineAPI::RequestOptions, Hash{Symbol=>Object}) (defaults to: {})


# File 'lib/docker_engine_api/models/network_list_params.rb', line 31


Instance Attribute Details

#filtersString?

JSON encoded value of the filters (a map[string][]string) to process on the networks list.

Available filters:

  • ‘dangling=<boolean>` When set to true (or 1), returns all networks that are not in use by a container. When set to false (or 0), only networks that are in use by one or more containers are returned.

  • ‘driver=<driver-name>` Matches a network’s driver.

  • ‘id=<network-id>` Matches all or part of a network ID.

  • ‘label=<key>` or `label=<key>=<value>` of a network label.

  • ‘name=<network-name>` Matches all or part of a network name.

  • scope=` Filters networks by scope (swarm, global, or local).

  • type=` Filters networks by type. The custom keyword returns all user-defined networks.

Returns:

  • (String, nil)


29
# File 'lib/docker_engine_api/models/network_list_params.rb', line 29

optional :filters, String