Class: DockerEngineAPI::Models::ServiceUpdateParams
- Inherits:
-
Internal::Type::BaseModel
- Object
- Internal::Type::BaseModel
- DockerEngineAPI::Models::ServiceUpdateParams
- Extended by:
- Internal::Type::RequestParameters::Converter
- Includes:
- Internal::Type::RequestParameters
- Defined in:
- lib/docker_engine_api/models/service_update_params.rb
Overview
Defined Under Namespace
Modules: RegistryAuthFrom Classes: Spec
Instance Attribute Summary collapse
-
#registry_auth_from ⇒ Symbol, ...
If the
X-Registry-Authheader is not specified, this parameter indicates where to find registry authorization credentials. -
#rollback ⇒ String?
Set to this parameter to
previousto cause a server-side rollback to the previous service spec. -
#spec ⇒ DockerEngineAPI::Models::ServiceUpdateParams::Spec
User modifiable configuration for a service.
-
#version ⇒ Integer
The version number of the service object being updated.
- #x_registry_auth ⇒ String?
Attributes included from Internal::Type::RequestParameters
Instance Method Summary collapse
-
#initialize ⇒ Object
constructor
User modifiable configuration for a service.
Methods included from Internal::Type::RequestParameters::Converter
Methods included from Internal::Type::RequestParameters
Methods inherited from Internal::Type::BaseModel
==, #==, #[], coerce, #deconstruct_keys, #deep_to_h, dump, fields, hash, #hash, inherited, inspect, #inspect, known_fields, optional, recursively_to_h, required, #to_h, #to_json, #to_s, to_sorbet_type, #to_yaml
Methods included from Internal::Type::Converter
#coerce, coerce, #dump, dump, inspect, #inspect, meta_info, new_coerce_state, type_info
Methods included from Internal::Util::SorbetRuntimeSupport
#const_missing, #define_sorbet_constant!, #sorbet_constant_defined?, #to_sorbet_type, to_sorbet_type
Constructor Details
#initialize ⇒ Object
User modifiable configuration for a service.
|
|
# File 'lib/docker_engine_api/models/service_update_params.rb', line 61
|
Instance Attribute Details
#registry_auth_from ⇒ Symbol, ...
If the X-Registry-Auth header is not specified, this parameter indicates where to find registry authorization credentials.
30 |
# File 'lib/docker_engine_api/models/service_update_params.rb', line 30 optional :registry_auth_from, enum: -> { DockerEngineAPI::ServiceUpdateParams::RegistryAuthFrom } |
#rollback ⇒ String?
Set to this parameter to previous to cause a server-side rollback to the previous service spec. The supplied spec will be ignored in this case.
37 |
# File 'lib/docker_engine_api/models/service_update_params.rb', line 37 optional :rollback, String |
#spec ⇒ DockerEngineAPI::Models::ServiceUpdateParams::Spec
User modifiable configuration for a service.
23 |
# File 'lib/docker_engine_api/models/service_update_params.rb', line 23 required :spec, -> { DockerEngineAPI::ServiceUpdateParams::Spec } |
#version ⇒ Integer
The version number of the service object being updated. This is required to avoid conflicting writes. This version number should be the value as currently set on the service before the update. You can find the current version by calling ‘GET /services/id`
17 |
# File 'lib/docker_engine_api/models/service_update_params.rb', line 17 required :version, Integer |
#x_registry_auth ⇒ String?
42 |
# File 'lib/docker_engine_api/models/service_update_params.rb', line 42 optional :x_registry_auth, String |