Class: DockerEngineAPI::Models::Spec
- Inherits:
-
Internal::Type::BaseModel
- Object
- Internal::Type::BaseModel
- DockerEngineAPI::Models::Spec
- Defined in:
- lib/docker_engine_api/models/spec.rb
Direct Known Subclasses
ConfigCreateParams::Spec, DockerEngineAPI::Models::SecretCreateParams::Spec, DockerEngineAPI::Models::ServiceCreateParams::Spec, DockerEngineAPI::Models::ServiceUpdateParams::Spec
Defined Under Namespace
Classes: EndpointSpec, Mode, Network, RollbackConfig, UpdateConfig
Instance Attribute Summary collapse
-
#endpoint_spec ⇒ DockerEngineAPI::Models::Spec::EndpointSpec?
Properties that can be configured to access and load balance a service.
-
#labels ⇒ Hash{Symbol=>String}?
User-defined key/value metadata.
-
#mode ⇒ DockerEngineAPI::Models::Spec::Mode?
Scheduling mode for the service.
-
#name ⇒ String?
Name of the service.
-
#networks ⇒ Array<DockerEngineAPI::Models::Spec::Network>?
Specifies which networks the service should attach to.
-
#rollback_config ⇒ DockerEngineAPI::Models::Spec::RollbackConfig?
Specification for the rollback strategy of the service.
-
#task_template ⇒ DockerEngineAPI::Models::Spec?
User modifiable task configuration.
-
#update_config ⇒ DockerEngineAPI::Models::Spec::UpdateConfig?
Specification for the update strategy of the service.
Class Method Summary collapse
Instance Method Summary collapse
-
#initialize(aliases: nil, driver_opts: nil, target: nil) ⇒ Object
constructor
Some parameter documentations has been truncated, see Network for more details.
Methods inherited from Internal::Type::BaseModel
==, #==, #[], coerce, #deconstruct_keys, #deep_to_h, dump, fields, hash, #hash, inherited, inspect, #inspect, known_fields, optional, recursively_to_h, required, #to_h, #to_json, #to_s, to_sorbet_type, #to_yaml
Methods included from Internal::Type::Converter
#coerce, coerce, #dump, dump, inspect, #inspect, meta_info, new_coerce_state, type_info
Methods included from Internal::Util::SorbetRuntimeSupport
#const_missing, #define_sorbet_constant!, #sorbet_constant_defined?, #to_sorbet_type, to_sorbet_type
Constructor Details
#initialize(aliases: nil, driver_opts: nil, target: nil) ⇒ Object
Some parameter documentations has been truncated, see Network for more details.
Specifies how a service should be attached to a particular network.
|
|
# File 'lib/docker_engine_api/models/spec.rb', line 59
|
Instance Attribute Details
#endpoint_spec ⇒ DockerEngineAPI::Models::Spec::EndpointSpec?
Properties that can be configured to access and load balance a service.
10 |
# File 'lib/docker_engine_api/models/spec.rb', line 10 optional :endpoint_spec, -> { DockerEngineAPI::Spec::EndpointSpec }, api_name: :EndpointSpec |
#labels ⇒ Hash{Symbol=>String}?
User-defined key/value metadata.
16 |
# File 'lib/docker_engine_api/models/spec.rb', line 16 optional :labels, DockerEngineAPI::Internal::Type::HashOf[String], api_name: :Labels |
#mode ⇒ DockerEngineAPI::Models::Spec::Mode?
Scheduling mode for the service.
22 |
# File 'lib/docker_engine_api/models/spec.rb', line 22 optional :mode, -> { DockerEngineAPI::Spec::Mode }, api_name: :Mode |
#name ⇒ String?
Name of the service.
28 |
# File 'lib/docker_engine_api/models/spec.rb', line 28 optional :name, String, api_name: :Name |
#networks ⇒ Array<DockerEngineAPI::Models::Spec::Network>?
Specifies which networks the service should attach to.
Deprecated: This field is deprecated since v1.44. The Networks field in TaskSpec should be used instead.
37 38 39 |
# File 'lib/docker_engine_api/models/spec.rb', line 37 optional :networks, -> { DockerEngineAPI::Internal::Type::ArrayOf[DockerEngineAPI::Spec::Network] }, api_name: :Networks |
#rollback_config ⇒ DockerEngineAPI::Models::Spec::RollbackConfig?
Specification for the rollback strategy of the service.
45 |
# File 'lib/docker_engine_api/models/spec.rb', line 45 optional :rollback_config, -> { DockerEngineAPI::Spec::RollbackConfig }, api_name: :RollbackConfig |
#task_template ⇒ DockerEngineAPI::Models::Spec?
User modifiable task configuration.
51 |
# File 'lib/docker_engine_api/models/spec.rb', line 51 optional :task_template, -> { DockerEngineAPI::Spec }, api_name: :TaskTemplate |
#update_config ⇒ DockerEngineAPI::Models::Spec::UpdateConfig?
Specification for the update strategy of the service.
57 |
# File 'lib/docker_engine_api/models/spec.rb', line 57 optional :update_config, -> { DockerEngineAPI::Spec::UpdateConfig }, api_name: :UpdateConfig |
Class Method Details
.values ⇒ Array<Symbol>
|
|
# File 'lib/docker_engine_api/models/spec.rb', line 205
|