Class: DockerEngineAPI::Models::Spec::RollbackConfig
- Inherits:
-
Internal::Type::BaseModel
- Object
- Internal::Type::BaseModel
- DockerEngineAPI::Models::Spec::RollbackConfig
- Defined in:
- lib/docker_engine_api/models/spec.rb
Overview
Defined Under Namespace
Modules: FailureAction, Order
Instance Attribute Summary collapse
-
#delay ⇒ Integer?
Amount of time between rollback iterations, in nanoseconds.
-
#failure_action ⇒ Symbol, ...
Action to take if an rolled back task fails to run, or stops running during the rollback.
-
#max_failure_ratio ⇒ Float?
The fraction of tasks that may fail during a rollback before the failure action is invoked, specified as a floating point number between 0 and 1.
-
#monitor ⇒ Integer?
Amount of time to monitor each rolled back task for failures, in nanoseconds.
-
#order ⇒ Symbol, ...
The order of operations when rolling back a task.
-
#parallelism ⇒ Integer?
Maximum number of tasks to be rolled back in one iteration (0 means unlimited parallelism).
Class Method Summary collapse
Instance Method Summary collapse
-
#initialize(delay: nil, failure_action: nil, max_failure_ratio: nil, monitor: nil, order: nil, parallelism: nil) ⇒ Object
constructor
Some parameter documentations has been truncated, see RollbackConfig for more details.
Methods inherited from Internal::Type::BaseModel
==, #==, #[], coerce, #deconstruct_keys, #deep_to_h, dump, fields, hash, #hash, inherited, inspect, #inspect, known_fields, optional, recursively_to_h, required, #to_h, #to_json, #to_s, to_sorbet_type, #to_yaml
Methods included from Internal::Type::Converter
#coerce, coerce, #dump, dump, inspect, #inspect, meta_info, new_coerce_state, type_info
Methods included from Internal::Util::SorbetRuntimeSupport
#const_missing, #define_sorbet_constant!, #sorbet_constant_defined?, #to_sorbet_type, to_sorbet_type
Constructor Details
#initialize(delay: nil, failure_action: nil, max_failure_ratio: nil, monitor: nil, order: nil, parallelism: nil) ⇒ Object
Some parameter documentations has been truncated, see DockerEngineAPI::Models::Spec::RollbackConfig for more details.
Specification for the rollback strategy of the service.
|
|
# File 'lib/docker_engine_api/models/spec.rb', line 367
|
Instance Attribute Details
#delay ⇒ Integer?
Amount of time between rollback iterations, in nanoseconds.
328 |
# File 'lib/docker_engine_api/models/spec.rb', line 328 optional :delay, Integer, api_name: :Delay |
#failure_action ⇒ Symbol, ...
Action to take if an rolled back task fails to run, or stops running during the rollback.
335 336 337 |
# File 'lib/docker_engine_api/models/spec.rb', line 335 optional :failure_action, enum: -> { DockerEngineAPI::Spec::RollbackConfig::FailureAction }, api_name: :FailureAction |
#max_failure_ratio ⇒ Float?
The fraction of tasks that may fail during a rollback before the failure action is invoked, specified as a floating point number between 0 and 1.
344 |
# File 'lib/docker_engine_api/models/spec.rb', line 344 optional :max_failure_ratio, Float, api_name: :MaxFailureRatio |
#monitor ⇒ Integer?
Amount of time to monitor each rolled back task for failures, in nanoseconds.
350 |
# File 'lib/docker_engine_api/models/spec.rb', line 350 optional :monitor, Integer, api_name: :Monitor |
#order ⇒ Symbol, ...
The order of operations when rolling back a task. Either the old task is shut down before the new task is started, or the new task is started before the old task is shut down.
358 |
# File 'lib/docker_engine_api/models/spec.rb', line 358 optional :order, enum: -> { DockerEngineAPI::Spec::RollbackConfig::Order }, api_name: :Order |
#parallelism ⇒ Integer?
Maximum number of tasks to be rolled back in one iteration (0 means unlimited parallelism).
365 |
# File 'lib/docker_engine_api/models/spec.rb', line 365 optional :parallelism, Integer, api_name: :Parallelism |
Class Method Details
.values ⇒ Array<Symbol>
|
|
# File 'lib/docker_engine_api/models/spec.rb', line 395
|