Class: DockerEngineAPI::Models::Spec::UpdateConfig
- Inherits:
-
Internal::Type::BaseModel
- Object
- Internal::Type::BaseModel
- DockerEngineAPI::Models::Spec::UpdateConfig
- Defined in:
- lib/docker_engine_api/models/spec.rb
Overview
Defined Under Namespace
Modules: FailureAction, Order
Instance Attribute Summary collapse
-
#delay ⇒ Integer?
Amount of time between updates, in nanoseconds.
-
#failure_action ⇒ Symbol, ...
Action to take if an updated task fails to run, or stops running during the update.
-
#max_failure_ratio ⇒ Float?
The fraction of tasks that may fail during an update before the failure action is invoked, specified as a floating point number between 0 and 1.
-
#monitor ⇒ Integer?
Amount of time to monitor each updated task for failures, in nanoseconds.
-
#order ⇒ Symbol, ...
The order of operations when rolling out an updated task.
-
#parallelism ⇒ Integer?
Maximum number of tasks to be updated in one iteration (0 means unlimited parallelism).
Class Method Summary collapse
Instance Method Summary collapse
-
#initialize(delay: nil, failure_action: nil, max_failure_ratio: nil, monitor: nil, order: nil, parallelism: nil) ⇒ Object
constructor
Some parameter documentations has been truncated, see UpdateConfig for more details.
Methods inherited from Internal::Type::BaseModel
==, #==, #[], coerce, #deconstruct_keys, #deep_to_h, dump, fields, hash, #hash, inherited, inspect, #inspect, known_fields, optional, recursively_to_h, required, #to_h, #to_json, #to_s, to_sorbet_type, #to_yaml
Methods included from Internal::Type::Converter
#coerce, coerce, #dump, dump, inspect, #inspect, meta_info, new_coerce_state, type_info
Methods included from Internal::Util::SorbetRuntimeSupport
#const_missing, #define_sorbet_constant!, #sorbet_constant_defined?, #to_sorbet_type, to_sorbet_type
Constructor Details
#initialize(delay: nil, failure_action: nil, max_failure_ratio: nil, monitor: nil, order: nil, parallelism: nil) ⇒ Object
Some parameter documentations has been truncated, see DockerEngineAPI::Models::Spec::UpdateConfig for more details.
Specification for the update strategy of the service.
|
|
# File 'lib/docker_engine_api/models/spec.rb', line 460
|
Instance Attribute Details
#delay ⇒ Integer?
Amount of time between updates, in nanoseconds.
421 |
# File 'lib/docker_engine_api/models/spec.rb', line 421 optional :delay, Integer, api_name: :Delay |
#failure_action ⇒ Symbol, ...
Action to take if an updated task fails to run, or stops running during the update.
428 429 430 |
# File 'lib/docker_engine_api/models/spec.rb', line 428 optional :failure_action, enum: -> { DockerEngineAPI::Spec::UpdateConfig::FailureAction }, api_name: :FailureAction |
#max_failure_ratio ⇒ Float?
The fraction of tasks that may fail during an update before the failure action is invoked, specified as a floating point number between 0 and 1.
437 |
# File 'lib/docker_engine_api/models/spec.rb', line 437 optional :max_failure_ratio, Float, api_name: :MaxFailureRatio |
#monitor ⇒ Integer?
Amount of time to monitor each updated task for failures, in nanoseconds.
443 |
# File 'lib/docker_engine_api/models/spec.rb', line 443 optional :monitor, Integer, api_name: :Monitor |
#order ⇒ Symbol, ...
The order of operations when rolling out an updated task. Either the old task is shut down before the new task is started, or the new task is started before the old task is shut down.
451 |
# File 'lib/docker_engine_api/models/spec.rb', line 451 optional :order, enum: -> { DockerEngineAPI::Spec::UpdateConfig::Order }, api_name: :Order |
#parallelism ⇒ Integer?
Maximum number of tasks to be updated in one iteration (0 means unlimited parallelism).
458 |
# File 'lib/docker_engine_api/models/spec.rb', line 458 optional :parallelism, Integer, api_name: :Parallelism |
Class Method Details
.values ⇒ Array<Symbol>
|
|
# File 'lib/docker_engine_api/models/spec.rb', line 489
|