Class: DockerEngineAPI::Models::SwarmJoinParams
- Inherits:
-
Internal::Type::BaseModel
- Object
- Internal::Type::BaseModel
- DockerEngineAPI::Models::SwarmJoinParams
- Extended by:
- Internal::Type::RequestParameters::Converter
- Includes:
- Internal::Type::RequestParameters
- Defined in:
- lib/docker_engine_api/models/swarm_join_params.rb
Overview
Instance Attribute Summary collapse
-
#advertise_addr ⇒ String?
Externally reachable address advertised to other nodes.
-
#data_path_addr ⇒ String?
Address or interface to use for data path traffic (format: ‘<ip|interface>`), for example,
192.168.1.1, or an interface, likeeth0. -
#join_token ⇒ String?
Secret token for joining this swarm.
-
#listen_addr ⇒ String?
Listen address used for inter-manager communication if the node gets promoted to manager, as well as determining the networking interface used for the VXLAN Tunnel Endpoint (VTEP).
-
#remote_addrs ⇒ Array<String>?
Addresses of manager nodes already participating in the swarm.
Attributes included from Internal::Type::RequestParameters
Instance Method Summary collapse
-
#initialize(advertise_addr: nil, data_path_addr: nil, join_token: nil, listen_addr: nil, remote_addrs: nil, request_options: {}) ⇒ Object
constructor
Some parameter documentations has been truncated, see SwarmJoinParams for more details.
Methods included from Internal::Type::RequestParameters::Converter
Methods included from Internal::Type::RequestParameters
Methods inherited from Internal::Type::BaseModel
==, #==, #[], coerce, #deconstruct_keys, #deep_to_h, dump, fields, hash, #hash, inherited, inspect, #inspect, known_fields, optional, recursively_to_h, required, #to_h, #to_json, #to_s, to_sorbet_type, #to_yaml
Methods included from Internal::Type::Converter
#coerce, coerce, #dump, dump, inspect, #inspect, meta_info, new_coerce_state, type_info
Methods included from Internal::Util::SorbetRuntimeSupport
#const_missing, #define_sorbet_constant!, #sorbet_constant_defined?, #to_sorbet_type, to_sorbet_type
Constructor Details
#initialize(advertise_addr: nil, data_path_addr: nil, join_token: nil, listen_addr: nil, remote_addrs: nil, request_options: {}) ⇒ Object
Some parameter documentations has been truncated, see DockerEngineAPI::Models::SwarmJoinParams for more details.
|
|
# File 'lib/docker_engine_api/models/swarm_join_params.rb', line 53
|
Instance Attribute Details
#advertise_addr ⇒ String?
Externally reachable address advertised to other nodes. This can either be an address/port combination in the form 192.168.1.1:4567, or an interface followed by a port number, like eth0:4567. If the port number is omitted, the port number from the listen address is used. If AdvertiseAddr is not specified, it will be automatically detected when possible.
18 |
# File 'lib/docker_engine_api/models/swarm_join_params.rb', line 18 optional :advertise_addr, String, api_name: :AdvertiseAddr |
#data_path_addr ⇒ String?
Address or interface to use for data path traffic (format: ‘<ip|interface>`), for example, 192.168.1.1, or an interface, like eth0. If DataPathAddr is unspecified, the same address as AdvertiseAddr is used.
The DataPathAddr specifies the address that global scope network drivers will publish towards other nodes in order to reach the containers running on this node. Using this parameter it is possible to separate the container data traffic from the management traffic of the cluster.
31 |
# File 'lib/docker_engine_api/models/swarm_join_params.rb', line 31 optional :data_path_addr, String, api_name: :DataPathAddr |
#join_token ⇒ String?
Secret token for joining this swarm.
37 |
# File 'lib/docker_engine_api/models/swarm_join_params.rb', line 37 optional :join_token, String, api_name: :JoinToken |
#listen_addr ⇒ String?
Listen address used for inter-manager communication if the node gets promoted to manager, as well as determining the networking interface used for the VXLAN Tunnel Endpoint (VTEP).
45 |
# File 'lib/docker_engine_api/models/swarm_join_params.rb', line 45 optional :listen_addr, String, api_name: :ListenAddr |
#remote_addrs ⇒ Array<String>?
Addresses of manager nodes already participating in the swarm.
51 |
# File 'lib/docker_engine_api/models/swarm_join_params.rb', line 51 optional :remote_addrs, DockerEngineAPI::Internal::Type::ArrayOf[String], api_name: :RemoteAddrs |