Class: DockerEngineAPI::Models::SystemEventsParams
- Inherits:
-
Internal::Type::BaseModel
- Object
- Internal::Type::BaseModel
- DockerEngineAPI::Models::SystemEventsParams
- Extended by:
- Internal::Type::RequestParameters::Converter
- Includes:
- Internal::Type::RequestParameters
- Defined in:
- lib/docker_engine_api/models/system_events_params.rb
Overview
Instance Attribute Summary collapse
-
#filters ⇒ String?
A JSON encoded value of filters (a
map[string][]string) to process on the event list. -
#since ⇒ String?
Show events created since this timestamp then stream new events.
-
#until_ ⇒ String?
Show events created until this timestamp then stop streaming.
Attributes included from Internal::Type::RequestParameters
Instance Method Summary collapse
-
#initialize(filters: nil, since: nil, until_: nil, request_options: {}) ⇒ Object
constructor
Some parameter documentations has been truncated, see SystemEventsParams for more details.
Methods included from Internal::Type::RequestParameters::Converter
Methods included from Internal::Type::RequestParameters
Methods inherited from Internal::Type::BaseModel
==, #==, #[], coerce, #deconstruct_keys, #deep_to_h, dump, fields, hash, #hash, inherited, inspect, #inspect, known_fields, optional, recursively_to_h, required, #to_h, #to_json, #to_s, to_sorbet_type, #to_yaml
Methods included from Internal::Type::Converter
#coerce, coerce, #dump, dump, inspect, #inspect, meta_info, new_coerce_state, type_info
Methods included from Internal::Util::SorbetRuntimeSupport
#const_missing, #define_sorbet_constant!, #sorbet_constant_defined?, #to_sorbet_type, to_sorbet_type
Constructor Details
#initialize(filters: nil, since: nil, until_: nil, request_options: {}) ⇒ Object
Some parameter documentations has been truncated, see DockerEngineAPI::Models::SystemEventsParams for more details.
|
|
# File 'lib/docker_engine_api/models/system_events_params.rb', line 45
|
Instance Attribute Details
#filters ⇒ String?
A JSON encoded value of filters (a map[string][]string) to process on the event list. Available filters:
-
‘config=<string>` config name or ID
-
‘container=<string>` container name or ID
-
‘daemon=<string>` daemon name or ID
-
‘event=<string>` event type
-
‘image=<string>` image name or ID
-
‘label=<string>` image or container label
-
‘network=<string>` network name or ID
-
‘node=<string>` node ID
-
plugin=<string> plugin name or ID -
scope=<string> local or swarm -
‘secret=<string>` secret name or ID
-
‘service=<string>` service name or ID
-
‘type=<string>` object to filter by, one of
container,image,volume,network,daemon,plugin,node,service,secretorconfig -
‘volume=<string>` volume name
31 |
# File 'lib/docker_engine_api/models/system_events_params.rb', line 31 optional :filters, String |
#since ⇒ String?
Show events created since this timestamp then stream new events.
37 |
# File 'lib/docker_engine_api/models/system_events_params.rb', line 37 optional :since, String |
#until_ ⇒ String?
Show events created until this timestamp then stop streaming.
43 |
# File 'lib/docker_engine_api/models/system_events_params.rb', line 43 optional :until_, String |