Class: DockerEngineAPI::Models::Version::Component
- Inherits:
-
Internal::Type::BaseModel
- Object
- Internal::Type::BaseModel
- DockerEngineAPI::Models::Version::Component
- Defined in:
- lib/docker_engine_api/models/version.rb
Instance Attribute Summary collapse
-
#details ⇒ Object?
Key/value pairs of strings with additional information about the component.
-
#name ⇒ String
Name of the component.
-
#version ⇒ String
Version of the component.
Instance Method Summary collapse
-
#initialize(api_version: nil, arch: nil, build_time: nil, components: nil, experimental: nil, git_commit: nil, go_version: nil, kernel_version: nil, min_api_version: nil, os: nil, platform: nil, version: nil) ⇒ Object
constructor
Some parameter documentations has been truncated, see DockerEngineAPI::Models::Version for more details.
Methods inherited from Internal::Type::BaseModel
==, #==, #[], coerce, #deconstruct_keys, #deep_to_h, dump, fields, hash, #hash, inherited, inspect, #inspect, known_fields, optional, recursively_to_h, required, #to_h, #to_json, #to_s, to_sorbet_type, #to_yaml
Methods included from Internal::Type::Converter
#coerce, coerce, #dump, dump, inspect, #inspect, meta_info, new_coerce_state, type_info
Methods included from Internal::Util::SorbetRuntimeSupport
#const_missing, #define_sorbet_constant!, #sorbet_constant_defined?, #to_sorbet_type, to_sorbet_type
Constructor Details
#initialize(api_version: nil, arch: nil, build_time: nil, components: nil, experimental: nil, git_commit: nil, go_version: nil, kernel_version: nil, min_api_version: nil, os: nil, platform: nil, version: nil) ⇒ Object
Some parameter documentations has been truncated, see DockerEngineAPI::Models::Version for more details.
Response of Engine API: GET “/version”
118 119 120 121 122 123 124 125 126 127 128 129 130 131 132 133 134 135 136 137 138 139 140 141 142 143 144 145 146 147 148 149 150 |
# File 'lib/docker_engine_api/models/version.rb', line 118 class Component < DockerEngineAPI::Internal::Type::BaseModel # @!attribute name # Name of the component # # @return [String] required :name, String, api_name: :Name # @!attribute version # Version of the component # # @return [String] required :version, String, api_name: :Version # @!attribute details # Key/value pairs of strings with additional information about the component. # These values are intended for informational purposes only, and their content is # not defined, and not part of the API specification. # # These messages can be printed by the client as information to the user. # # @return [Object, nil] optional :details, DockerEngineAPI::Internal::Type::Unknown, api_name: :Details, nil?: true # @!method initialize(name:, version:, details: nil) # Some parameter documentations has been truncated, see # {DockerEngineAPI::Models::Version::Component} for more details. # # @param name [String] Name of the component # # @param version [String] Version of the component # # @param details [Object, nil] Key/value pairs of strings with additional information about the end |
Instance Attribute Details
#details ⇒ Object?
Key/value pairs of strings with additional information about the component. These values are intended for informational purposes only, and their content is not defined, and not part of the API specification.
These messages can be printed by the client as information to the user.
139 |
# File 'lib/docker_engine_api/models/version.rb', line 139 optional :details, DockerEngineAPI::Internal::Type::Unknown, api_name: :Details, nil?: true |
#name ⇒ String
Name of the component
123 |
# File 'lib/docker_engine_api/models/version.rb', line 123 required :name, String, api_name: :Name |
#version ⇒ String
Version of the component
129 |
# File 'lib/docker_engine_api/models/version.rb', line 129 required :version, String, api_name: :Version |