Class: DockerEngineAPI::Models::Volume::ClusterVolume::Info
- Inherits:
-
Internal::Type::BaseModel
- Object
- Internal::Type::BaseModel
- DockerEngineAPI::Models::Volume::ClusterVolume::Info
- Defined in:
- lib/docker_engine_api/models/volume.rb
Overview
Instance Attribute Summary collapse
-
#accessible_topology ⇒ Array<Hash{Symbol=>String}>?
The topology this volume is actually accessible from.
-
#capacity_bytes ⇒ Integer?
The capacity of the volume in bytes.
-
#volume_context ⇒ Hash{Symbol=>String}?
A map of strings to strings returned from the storage plugin when the volume is created.
-
#volume_id ⇒ String?
The ID of the volume as returned by the CSI storage plugin.
Method Summary
Methods inherited from Internal::Type::BaseModel
#==, ==, #[], coerce, #deconstruct_keys, #deep_to_h, dump, fields, hash, #hash, inherited, #initialize, inspect, #inspect, known_fields, optional, recursively_to_h, required, #to_h, #to_json, #to_s, to_sorbet_type, #to_yaml
Methods included from Internal::Type::Converter
#coerce, coerce, #dump, dump, inspect, #inspect, meta_info, new_coerce_state, type_info
Methods included from Internal::Util::SorbetRuntimeSupport
#const_missing, #define_sorbet_constant!, #sorbet_constant_defined?, #to_sorbet_type, to_sorbet_type
Constructor Details
This class inherits a constructor from DockerEngineAPI::Internal::Type::BaseModel
Instance Attribute Details
#accessible_topology ⇒ Array<Hash{Symbol=>String}>?
The topology this volume is actually accessible from.
198 199 200 |
# File 'lib/docker_engine_api/models/volume.rb', line 198 optional :accessible_topology, DockerEngineAPI::Internal::Type::ArrayOf[DockerEngineAPI::Internal::Type::HashOf[String]], api_name: :AccessibleTopology |
#capacity_bytes ⇒ Integer?
The capacity of the volume in bytes. A value of 0 indicates that the capacity is unknown.
207 |
# File 'lib/docker_engine_api/models/volume.rb', line 207 optional :capacity_bytes, Integer, api_name: :CapacityBytes |
#volume_context ⇒ Hash{Symbol=>String}?
A map of strings to strings returned from the storage plugin when the volume is created.
214 |
# File 'lib/docker_engine_api/models/volume.rb', line 214 optional :volume_context, DockerEngineAPI::Internal::Type::HashOf[String], api_name: :VolumeContext |
#volume_id ⇒ String?
The ID of the volume as returned by the CSI storage plugin. This is distinct from the volume’s ID as provided by Docker. This ID is never used by the user when communicating with Docker to refer to this volume. If the ID is blank, then the Volume has not been successfully created in the plugin yet.
223 |
# File 'lib/docker_engine_api/models/volume.rb', line 223 optional :volume_id, String, api_name: :VolumeID |