Class: DockerEngineAPI::Models::Volume::ClusterVolume::PublishStatus
- Inherits:
-
Internal::Type::BaseModel
- Object
- Internal::Type::BaseModel
- DockerEngineAPI::Models::Volume::ClusterVolume::PublishStatus
- Defined in:
- lib/docker_engine_api/models/volume.rb
Defined Under Namespace
Modules: State
Instance Attribute Summary collapse
-
#node_id ⇒ String?
The ID of the Swarm node the volume is published on.
-
#publish_context ⇒ Hash{Symbol=>String}?
A map of strings to strings returned by the CSI controller plugin when a volume is published.
-
#state ⇒ Symbol, ...
The published state of the volume.
Instance Method Summary collapse
-
#initialize(node_id: nil, publish_context: nil, state: nil) ⇒ Object
constructor
Some parameter documentations has been truncated, see PublishStatus for more details.
Methods inherited from Internal::Type::BaseModel
==, #==, #[], coerce, #deconstruct_keys, #deep_to_h, dump, fields, hash, #hash, inherited, inspect, #inspect, known_fields, optional, recursively_to_h, required, #to_h, #to_json, #to_s, to_sorbet_type, #to_yaml
Methods included from Internal::Type::Converter
#coerce, coerce, #dump, dump, inspect, #inspect, meta_info, new_coerce_state, type_info
Methods included from Internal::Util::SorbetRuntimeSupport
#const_missing, #define_sorbet_constant!, #sorbet_constant_defined?, #to_sorbet_type, to_sorbet_type
Constructor Details
#initialize(node_id: nil, publish_context: nil, state: nil) ⇒ Object
Some parameter documentations has been truncated, see DockerEngineAPI::Models::Volume::ClusterVolume::PublishStatus for more details.
|
|
# File 'lib/docker_engine_api/models/volume.rb', line 272
|
Instance Attribute Details
#node_id ⇒ String?
The ID of the Swarm node the volume is published on.
245 |
# File 'lib/docker_engine_api/models/volume.rb', line 245 optional :node_id, String, api_name: :NodeID |
#publish_context ⇒ Hash{Symbol=>String}?
A map of strings to strings returned by the CSI controller plugin when a volume is published.
252 253 254 |
# File 'lib/docker_engine_api/models/volume.rb', line 252 optional :publish_context, DockerEngineAPI::Internal::Type::HashOf[String], api_name: :PublishContext |
#state ⇒ Symbol, ...
The published state of the volume.
-
pending-publishThe volume should be published to this node, but the call to the controller plugin to do so has not yet been successfully completed. -
publishedThe volume is published successfully to the node. -
pending-node-unpublishThe volume should be unpublished from the node, and the manager is awaiting confirmation from the worker that it has done so. -
pending-controller-unpublishThe volume is successfully unpublished from the node, but has not yet been successfully unpublished on the controller.
268 269 270 |
# File 'lib/docker_engine_api/models/volume.rb', line 268 optional :state, enum: -> { DockerEngineAPI::Volume::ClusterVolume::PublishStatus::State }, api_name: :State |