Module: DockerEngineAPI::Models::Volume::ClusterVolume::PublishStatus::State
- Extended by:
- Internal::Type::Enum
- Defined in:
- lib/docker_engine_api/models/volume.rb
Overview
The published state of the volume.
-
pending-publishThe volume should be published to this node, but the call to the controller plugin to do so has not yet been successfully completed. -
publishedThe volume is published successfully to the node. -
pending-node-unpublishThe volume should be unpublished from the node, and the manager is awaiting confirmation from the worker that it has done so. -
pending-controller-unpublishThe volume is successfully unpublished from the node, but has not yet been successfully unpublished on the controller.
Constant Summary collapse
- PENDING_PUBLISH =
:"pending-publish"- PUBLISHED =
:published- PENDING_NODE_UNPUBLISH =
:"pending-node-unpublish"- PENDING_CONTROLLER_UNPUBLISH =
:"pending-controller-unpublish"
Method Summary
Methods included from Internal::Type::Enum
==, ===, coerce, dump, hash, inspect, to_sorbet_type, values
Methods included from Internal::Util::SorbetRuntimeSupport
#const_missing, #define_sorbet_constant!, #sorbet_constant_defined?, #to_sorbet_type, to_sorbet_type
Methods included from Internal::Type::Converter
#coerce, coerce, #dump, dump, inspect, #inspect, meta_info, new_coerce_state, type_info